#
# spec file for package calibre
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        EBook Management Application
License:        GPL-3.0
Group:          Productivity/Other
Name:           calibre
Version:        2.69.0
Release:        2.1
Url:            http://calibre-ebook.com
Source0:        http://download.calibre-ebook.com/%{version}/calibre-%{version}.tar.xz
Source2:        %{name}.desktop
Patch2:         calibre-setup.install.py.diff
# PATCH-FIX-OPENSUSE: disabling Autoupdate Searcher
Patch3:         calibre-no-update.diff
# PATCH-FIX-TO-UPSTREAM: use reproducible list order
Patch4:         reproducible.patch
# The following patches are from upstream and needs to be removed with update to 2.70
Patch10:        Fix-editing-color-schemes.patch
Patch11:        Update-amazon-store-plugin.patch
Patch12:        Update-db-version-kobo-driver.patch
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files

# A note on BuildRequires and Requires:
#
# Requires should always be a subset of BuildRequires. If there are packages
# that are only Required
# * there is no way to check whether these packages are available in the given
#   repositories unless you install the package (the build environment only
#   contains packages from the given repositories and the project
# * the project's repository might become inconsistent, because Required
#   packages do not block a build. So a package might get published, although
#   a Required package does not build
# For those reasons put Requires also in the BuildRequires list below
BuildRequires:  chmlib-devel >= 0.40
BuildRequires:  dbus-1-python >= 1.2.0
BuildRequires:  libQt5Core-private-headers-devel >= 5.3.2
BuildRequires:  libQt5Gui-private-headers-devel >= 5.3.2
BuildRequires:  libQt5PlatformSupport-private-headers-devel >= 5.3.2
BuildRequires:  libicu-devel >= 4.4
BuildRequires:  libmtp-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpodofo-devel >= 0.8.2
BuildRequires:  libpoppler-devel >= 0.20.2
BuildRequires:  libwmf-devel >= 0.2.8
BuildRequires:  poppler-tools
BuildRequires:  python-Pillow
BuildRequires:  python-apsw
BuildRequires:  python-beautifulsoup >= 3.0.5
BuildRequires:  python-cherrypy
BuildRequires:  python-cssselect >= 0.7.1
BuildRequires:  python-cssutils >= 0.9.9
BuildRequires:  python-dateutil >= 1.4.1
BuildRequires:  python-devel >= 2.7.9
BuildRequires:  python-dnspython >= 1.6.0
BuildRequires:  python-genshi
BuildRequires:  python-lxml >= 3.2.1
BuildRequires:  python-mechanize >= 0.1.11
BuildRequires:  python-netifaces
BuildRequires:  python-odfpy
BuildRequires:  python-pypdf
BuildRequires:  python-qt5-devel >= 5.3.1
BuildRequires:  python-setuptools
BuildRequires:  sqlite3-devel
BuildRequires:  xdg-utils >= 1.0.2
# calibre no longer depends on ImageMagick
# but keept BuildREquires to convert icon to several sizes
BuildRequires:  pkgconfig(ImageMagick) >= 6.5.9

Requires:       chmlib >= 0.40
Requires:       dbus-1-python
Requires:       libicu >= 4.4
Requires:       libmtp9
Requires:       libwmf >= 0.2.8
Requires:       optipng >= 0.7.5
Requires:       podofo >= 0.8.2
Requires:       poppler-tools
Requires:       python >= 2.7.9
%if 0%{?suse_version} > 1320 
Requires:       python-Pygments >= 2.0.1
%endif
Requires:       python-Pillow
Requires:       python-apsw
Requires:       python-beautifulsoup >= 3.0.5
Requires:       python-cherrypy
Requires:       python-cssselect >= 0.7.1
Requires:       python-cssutils >= 0.9.9
Requires:       python-dateutil >= 1.4.1
Requires:       python-dnspython >= 1.6.0
Requires:       python-genshi
Requires:       python-lxml >= 3.2.1
Requires:       python-mechanize >= 0.1.11
Requires:       python-netifaces
Requires:       python-odfpy
Requires:       python-pypdf
Requires:       python-qt5 >= 5.3.1
Requires:       python-setuptools
Requires:       sqlite3
Requires:       xdg-utils >= 1.0.2
%requires_eq    libQt5Core5
%requires_eq    libQt5Gui5

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}
# http://lists.opensuse.org/opensuse-packaging/2009-08/msg00110.html

%description
Calibre is an ebook library manager. It can view, convert and catalog
ebooks in most of the major ebook formats. It can also talk to a few
ebook reader devices. It can go out to the internet and fetch
metadata for your books. It can download newspapers and convert them
into ebooks for convenient reading. It is cross platform, running on
Linux, Windows and OS X.

%prep
%setup -q
%patch2 -p1
%patch3 -p1 -b .no-update
%patch4 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1

# dos2unix newline conversion
sed -i 's/\r//' src/calibre/web/feeds/recipes/*

# remove shebangs
sed -i -e '/^#!\//, 1d' src/calibre/*/*/*/*/*.py
sed -i -e '/^#!\//, 1d' src/calibre/*/*/*/*.py
sed -i -e '/^#!\//, 1d' src/calibre/*/*/*.py
sed -i -e '/^#![ ]*\//, 1d' src/calibre/*/*.py
sed -i -e '/^#!\//, 1d' src/calibre/*.py
sed -i -e '/^#!\//, 1d' src/templite/*.py
sed -i -e '/^#!\//, 1d' src/tinycss/*.py
sed -i -e '/^#!\//, 1d' src/tinycss/*/*.py
sed -i -e '/^#!\//, 1d' resources/default_tweaks.py
sed -i -e '/^#!\//, 1d' resources/catalog/section_list_templates.py

# remove the executable flag from files
find src/calibre -name "*.py" -type f  | xargs chmod -x
chmod -x recipes/*

# remove bundled beautifulsoup
rm -f src/calibre/ebooks/BeautifulSoup.py
find "." -type f -name \*.py -exec \
    sed -e 's/calibre.ebooks.BeautifulSoup/BeautifulSoup/' -i {} +

cp -v %{SOURCE2}  .

%build
LANG="en_US.UTF8" \
CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags}" \
OVERRIDE_CFLAGS="%{optflags}" \
python setup.py build

%install
python setup.py install \
   --prefix=%{_prefix} \
   --root=%{buildroot}%{_prefix} \
   --staging-bindir=%{buildroot}%{_bindir} \
   --staging-libdir=%{buildroot}%{_libdir} \
   --staging-sharedir=%{buildroot}%{_datadir} \
   --staging-mandir=%{buildroot}%{_mandir} \
   --libdir=%{_libdir}

# GENERATE AND INSTALL HIRES ICONS INTO HICOLOR DIR (PRESENT ICON LOOKS BLURRED ON HiDPI)
for i in 24 32 48 64 128 256 512
do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps
  convert -strip icons/calibre.png \
          -resize ${i}x${i} %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

%suse_update_desktop_file -i -n calibre Office Viewer

%fdupes %{buildroot}

# packages aren't allowed to register mimetypes like this
rm -f %{buildroot}%{_datadir}/applications/defaults.list

# these are provided as separate packages
rm -rf %{buildroot}%{_libdir}/%{name}/{odf,cherrypy,pyPdf,encutils,cssutils}
rm -rf %{buildroot}%{_libdir}/%{name}/cal/utils/genshi
rm -rf %{buildroot}%{_libdir}/%{name}/cal/trac
# Also the Liberation fonts are provided as separate package
rm -rf %{buildroot}%{_datadir}/%{name}/fonts/liberation

# add shebangs
sed -i -e '1i#!/usr/bin/python' %{buildroot}%{_libdir}/%{name}/chardet/*.py

# appdata file references calibre-gui.desktop, and .appdata.xml file should necessarily have matching name with .desktop file in order for the app to show up in Software Centres
mv %{buildroot}%{_datadir}/applications/calibre.desktop %{buildroot}%{_datadir}/applications/calibre-gui.desktop

# Remove all appdata.xml files but the main one, we do not install the corresponding .desktop files
rm %{buildroot}%{_datadir}/appdata/calibre-ebook-{edit,viewer}.appdata.xml

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
# -f %%{name}.lang  -f iso639.lang
%defattr(-,root,root)
%{_bindir}/*
%exclude %{_bindir}/calibre-uninstall
%{_datadir}/applications/%{name}-gui.desktop
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/%{name}/
%{_libdir}/%{name}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}-gui.appdata.xml
%{_datadir}/bash-completion/completions/%{name}
/usr/lib/python2.7/site-packages/init_calibre.py

%changelog
* Thu Oct 13 2016 cornelis@solcon.nl
- Added Fix-editing-color-schemes.patch to fix dialog for editing
  color-schemes (lp#1629294)
- Added Update-amazon-store-plugin.patch because of Amazon website
  changes
- Added Update-db-version-kobo-driver.patch to make sure calibre is
  working correctly with kobo firmware
* Fri Sep 30 2016 cornelis@solcon.nl
- Update to 2.69.0:
  * Devices:
  - Kobo driver: Support for firmware version 4.1 and Overdrive
    books on the device
  - Kobo driver: Fix delete of empty collections
  - Kobo driver: Fix book previews being sometimes detected as
    actual books
  * Fix downloading of metadata from ozon.ru, which broke due to
    website changes
  * For details see http://calibre-ebook.com/whats-new
* Fri Sep 16 2016 cornelis@solcon.nl
- Update to 2.68.0:
  * For details see http://calibre-ebook.com/whats-new
* Thu Sep  8 2016 cornelis@solcon.nl
- Update to 2.67.0:
  * Devices:
  - Kobo driver: Add support for firmware version 4 available on
    the new Kobo Aura One
  * For details see http://calibre-ebook.com/whats-new
* Fri Sep  2 2016 cornelis@solcon.nl
- Update to 2.66.0:
  * Devices:
  - Driver for the PocketBook Tourch HD (lp#1618962)
  - Kobo driver: Add suport for firmware version 3.20
  * Improvemens for high DPI screens
  * For details see http://calibre-ebook.com/whats-new
* Fri Aug 26 2016 cornelis@solcon.nl
- Update to 2.65.1:
  * Devices:
  - Driver for Kobo Aura One and Aura Edition 2
  - Kobo driver: Add an option to ignore some collections on the
    device. The specified collections will not be touched by the
    driver.
  * For details see http://calibre-ebook.com/whats-new
* Thu Aug 25 2016 cornelis@solcon.nl
- Remove calibre-appdata-add-name-summary.patch (upstreamed)
* Thu Aug 25 2016 cornelis@solcon.nl
- Update to 2.64.0:
  * For details see http://calibre-ebook.com/whats-new
* Wed Aug 24 2016 tchvatal@suse.com
- Remove 2nd part of the update disabling as it breaks with new code
  now user can click and get the notification, but still it won't
  be at least done automatically bnc#993644
  * calibre-no-update.diff
* Tue Jul 26 2016 cornelis@solcon.nl
- Update to 2.63.0:
  * For details see http://calibre-ebook.com/whats-new
* Mon Jul 25 2016 badshah400@gmail.com
- Fix calibre-appdata-add-name-summary.patch so that description
  paragraphs do not show up elsewhere (boo#990425).
* Fri Jul 15 2016 badshah400@gmail.com
- Make calibre show up in Software Centres:
  + Appdata file references calibre-gui.desktop; besides
    .appdata.xml filename should necessarily match that of
    .desktop file for the app to show up in Software Centres.
    Rename .desktop file to achieve this.
  + Remove all appdata.xml files but the main one, we do not
    install the corresponding .desktop files, so these are vetoed
    by appstream-builder anyway.
  + Own appdata dir (/use/share/appdata) to prevent build failures
    on openSUSE <= 13.2.
- Add calibre-appdata-add-name-summary.patch to add summary and
  name fields to the appdata, calibre does not show up in software
  centres otherwise.
* Fri Jul  8 2016 cornelis@solcon.nl
- Update to 2.62.0:
  * Improved support for EPUB 3
  * Recognize the newest Kindle model (SY69JL) (lp#1599970)
  * Fix KoboTouch configuration migration not working for older
    settings (lp#1598017).
  * For details see http://calibre-ebook.com/whats-new
* Sun Jul  3 2016 cornelis@solcon.nl
- Update to 2.61.0:
  * Driver for FNAC (re-branded Bq) with new firmware (lp#1595924).
  * Edit Book: Check Book: Add an auto fix action to remove all
    links to a missing resource (such as a deleted stylesheet)
    automatically (lp#1596048).
  * Kobo driver: Fix a regression in the last release that broke
    connecting to older devices (lp#1596801).
  * For details see http://calibre-ebook.com/whats-new
* Fri Jun 24 2016 cornelis@solcon.nl
- Update to 2.60.0:
  * For details see http://calibre-ebook.com/whats-new
* Wed Jun 22 2016 cornelis@solcon.nl
- Update to 2.59.0:
  * For details see http://calibre-ebook.com/whats-new
* Fri Jun  3 2016 cornelis@solcon.nl
- Update to 2.58.0:
  * For details see http://calibre-ebook.com/whats-new
* Thu Jun  2 2016 cornelis@solcon.nl
- Replace Build and BuildRequires python-imaging with python-Pillow,
  which has long replaced python-imaging.
* Tue May 24 2016 cornelis@solcon.nl
- Dropped calibre-2.57.1-pillow.patch (came originally from fedora
  to fix issues with python-pillow, but has been dropped since then)
- Removed Suggests: python-pillow
* Sun May 22 2016 cornelis@solcon.nl
- Update to 2.57.1:
  * For details see http://calibre-ebook.com/whats-new
- Update calibre-0.9.38-pillow.patch to calibre-2.57.1-pillow.patch
- Remove ImageMagick from Requires, because calibre no longer
  depends on it (but keep it as BuildRequires because "convert" is
  used in the spec file).
* Fri Apr 29 2016 cornelis@solcon.nl
- Update to 2.56.0:
  * For details see http://calibre-ebook.com/whats-new
* Fri Apr 15 2016 cornelis@solcon.nl
- Update to 2.55.0:
  * For details see http://calibre-ebook.com/whats-new
* Fri Mar 11 2016 cornelis@solcon.nl
- Update to 2.53.0:
  * New feature: Edit Book: A new tool to transform book styling
    using easy to create rules.
  * For other changes, see http://calibre-ebook.com/whats-new
* Tue Mar  8 2016 bwiedemann@suse.com
- Add reproducible.patch and drop png timestamps to fix build compare
* Fri Feb 26 2016 cornelis@solcon.nl
- Update to 2.52.0:
  * For details, see http://calibre-ebook.com/whats-new
* Fri Feb 12 2016 cornelis@solcon.nl
- Update to 2.51.0:
  * Minor changes and bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Fri Jan 29 2016 cornelis@solcon.nl
- Update to 2.50.0:
  New Features
  * Change the way that devices are detected on Windows. This fixes
    device detection problems on some Windows 10 computers.
  * Edit Book: When inserting images, add an option to insert the
    image as a full page image.
  * DOCX Input: Add support for framed text created by setting the
    same border style on neighboring paragraphs (lp#1526663).
  * Update PocketBook 650 driver for latest firmware revision
    (lp#1535801).
  Bug Fixes
  * DOCX Input: Fix empty paragraphs with borders being rendered
    with an empty line inside the borders.
  * ODT Input: Fix fallback PNG images generated by LibreOffice 4.x
    for SVG images not being ignored.
  * Fix restore library failing on some windows systems with non-
    ascii library paths.
  * Edit Book: Fix error when merging an empty HTML document or one
    that contains only text and no tags (lp#1535427).
  * Fix failure to add FB2 files that contain published dates
    (lp#1535007).
  * Use a private certificate when downloading plugins via HTTPS.
    This fixes errors on some windows machines that have missing
    root certificates.
  * Fix tag editor not working correctly for comma-separated custom
    columns.
  * Fix existing rating not being removed when using Polish Books
    or Embed Metadata tools on EPUB files (lp#1534597).
  Improved news sources
  * New Scientist
  * FAZ.net
  * Scientific American
  * Business World Magazine
  * Houston Chronicle
* Fri Jan 15 2016 cornelis@solcon.nl
- Update to 2.49.0:
  * A new tool to easily export and import all calibre data --
    books, settings and plugins.
  * Get Books: Add plugins for Amazon Australia and Amazon India.
    Also restore the Amazon EU plugins (lp#1526089).
  * PDF Input: Fix conversion of PDF documents that contain ASCII
    control codes in their outlines not working (lp#1527697).
  * Driver for Energy Ereader Screenlight (lp#1529108).
  * E-book viewer: Add an option to allow only a single book to be
    viewed at a time. Trying to view a second book will cause it to
    replace the currently viewed book (lp#1526504).
  * Kobo driver: Add support for the new firmware 3.19.5761.
  * Get Books: Update plugins for various Polish language book stores
    to handle changes to the website.
  * Amazon metadata download: Handle a change in the amazon website
    that prevented review metadata from being downloaded.
  * Download calibre plugins securely using HTTPS.
  * MOBI Output: Try to autofix corrupted PNG images in the input
    document (lp#1531738).
  * Nook Glowlight Plus: Send files by default to the NOOK/My Files
    folder (lp#1531394).
  * E-book viewer: Fix failure to view comic files that contain
    non-ASCII characters int heir internal filenames (lp#1530517).
  * And more, for details see http://calibre-ebook.com/whats-new
* Wed Dec 16 2015 cornelis@solcon.nl
- Require python-Pygments only for factory: the version in Leap is
  not high enough.
* Mon Dec 14 2015 cornelis@solcon.nl
- Updated BuildRequires and Requires to the latest requirements
  (this should prevent bugs like #boo935943).
* Sun Dec 13 2015 cornelis@solcon.nl
- Update to 2.46.0:
  * PDF Input: Add support for PDF outlines (bookmarks), if
    present, they are used as the metadata Table of Contents.
  * Add tool to compress images losslessly.
  * Add support for new Kobo firmware 3.19.
  * Disable the Amazon EU stores, at Amazon's request.
  * And more, for details see: http://calibre-ebook.com/whats-new
* Sat Nov 28 2015 cornelis@solcon.nl
- Update to 2.45.0:
  * Improved handling of covers.
  * And more, for details see: http://calibre-ebook.com/whats-new
* Sat Nov  7 2015 cornelis@solcon.nl
- Update to 2.43.0:
  * Driver for the new NookGlowlight Plus. This device only allows
    sending of files inside the NOOK folder, so calibre now
    follows that limitation.
  * When converting AZW4 files to PDF, skip the conversion and
    simply unwrap the PDF file already embedded inside the AZW4
    file.
  * Edit Book: Add a 'Smart Comment' tool to easily comment/
    uncomment text.
  * Tag mapper: Add new rule types to upper-case, lower-case or
    capitalize tags.
  * Amazon metadata download: Fix for website change at amazon.com
    that prevented ratings from being downloaded.
  * And more, for details see: http://calibre-ebook.com/whats-new
* Fri Oct 16 2015 cornelis@solcon.nl
- Update to 2.41.0:
  * Edit Book: Allow editing an unzipped EPUB (a folder) as a book
  * Edit Book: Allow easily removing items from the popup menu for
    the 'Insert tag' button.
  * Make Tag Browser more useable with keyboard shortcuts.
    Configure the keyboard shortcuts in Preferences->Keyboard->Tag
    Browser.
  * ToC editor: Add context menu item to change selected entries to
    upper case.
  * Bugfixes and improved news sources.
  * For details see http://calibre-ebook.com/whats-new
* Fri Oct  2 2015 cornelis@solcon.nl
- Update to 2.40.0:
  * A new tool to apply Tag mapper rules to existing books in the
    library. To use it, go to Preferences->Toolbars and add the
    tool to the toolbar.
  * Kindle driver: Detect books in Amazon's new KFX format present
    on e-ink kindles (this only detects KFX books and allows to
    delete, nothing more).
  * For details see http://calibre-ebook.com/whats-new
* Wed Sep 30 2015 cornelis@solcon.nl
- Update to 2.39.0:
  * Implement tag mapping to automatically filter/transform tags
    when adding books or downloading metadata.
  * Kobo driver: Support for newly firmware version 3.18.
  * Edit Book: Add a setting to control icon size for the toolbars
    (Preferences->Toolbars).
  * For details see http://calibre-ebook.com/whats-new
* Fri Sep 11 2015 cornelis@solcon.nl
- Update to 2.38.0:
  * Add support for Kobo Touch 2.
  * Edit Book: Add a tool to check external links (links pointing
    to websites). Can be accessed via Tools->Check external links.
  * For details see http://calibre-ebook.com/whats-new
* Tue Sep  8 2015 cornelis@solcon.nl
- Update to 2.37.1:
  * Driver for the Lark Freebook reader device.
  * A redesigned busy spinner.
  * When merging book records, show more information about the
    target book record.
  * A new icon theme 'Dark Blue' (Preferences->Look & Feel->Change
    icon theme).
  * Add a check box to control copying ebook files when
    duplicating book records via the Add Empty Book dialog.
  * Bugfixes
  * For details see http://calibre-ebook.com/whats-new
* Fri Aug 28 2015 cornelis@solcon.nl
- Update to 2.36.0:
  Most important changes since 2.32.1:
  * Driver for SONY DPT-S1
  * Added support for amazon.nl
  * Added support for Kobo firmware 3.17 and 3.17.3
  * Icon themes are not configurable
  * Driver for the Unusual Sapiens V2 and Adlibris Letto readers
- For details see http://calibre-ebook.com/whats-new
* Thu Jul 23 2015 cornelis@solcon.nl
- Update to 2.32.1:
  New Features:
  * E-book viewer: Automatically save the current reading position
    every ten seconds. Prevents loss of reading position on crash/
    forced shutdown.
  * Edit Book: Check Book: Add checks for missing OPF version and
    toc references and for text placed directly inside the <body>
    tag.
  * calibredb: Add a new search sub-command that can be used to
    generate a list of book ids from a search expression.
  * Tag Editor: Place the keyboard focus on the last edited field.
  * Edit metadata dialog: When clicking Next and Previous preserve
    the current tab of the edit comments widget.
  * Linux: Various fixes to make calibre work when compiled
    against the latest versions of Qt and PyQt.
  * Edit Book: Allow drag and drop of files onto dock icon on OS X
  Bug Fixes
  * Fix error in template dialog when using {id} in send to device
    preferences.
  * Edit Book/Book polishing: Fix EPUB books with opf files that
    use a non-default namespace for the OPF namespace being
    corrupted.
  * OS X: Workaround for Qt 5 regression that causes any errors
    during startup to be hidden behind the splash screen.
  * Conversion: Fix incorrect relative URLs being generated when
    an HTML or CSS file is placed higher in the folder hierarchy
    than the opf file.
  * FB2 Output: Fix error when using the sectionize with toc
    option and the input documents Table of Contents contains
    multiple items pointing to the same HTML file.
  * Conversion: Fix error when input document contains a font size
    exactly one point away from the base size.
  * Device drivers: Handle devices with undecodeable filenames in
    their filesystem. Simply ignore those files.
  * Fix Cmd+Left/Right keyboard shortcut not working when editing
    items in the book list on OS X.
  * Fix corrupted text in the jobs list on some non-English
    windows installs.
  * Edit Book: Workaround for a Qt regression that caused 'See
    what changed' after a search and replace on OS X causing the
    application to become unresponsive.
  * Edit Book: Fix smarten punctuation not working for books with
    non-ascii characters in internal file names on OS X.
  New news sources
  * Slate Star Codex by Ned Letcher
  * Hurriyet by Adrian Tennessee
  Improved news sources
  * Harvard Business Review
  * Psychology Today
  * NRC Handelsblad
  * Entrepeneur Magazine
  * 20 minutes
  * Economia
  * Accountancy Age
  * Jakarta Post
  * Foreign Affairs
  * Spectator Magazine
  * Daily Express
  * The Onion AV Club
  * Metro UK
* Mon Jul  6 2015 badshah400@gmail.com
- Generate the application icon in different sizes and install
  into hicolor-icon-theme dir; improves icon look on HiDPI
  displays.
- Use post(un) scripts to update desktop database (needed when
  installing a .desktop entry) and icon-theme cache (for hicolor
  icon-theme).
- Drop external .png image and corresponding installed icon from
  /usr/share/pixmaps; no longer needed.
* Sun Jun 28 2015 cornelis@solcon.nl
- Update to version 2.31.0:
  * New Features:
  - E-book viewer: Make the search engine used for searching for
    selected text configurable (in the Miscellaneous section of
    the viewer preferences).
  * Bug Fixes:
  - E-book viewer: Fix dragging to select text with the mouse
    causing the page to slide sideways in paged mode, if the
    mouse leaves the text area.
  - E-book viewer: Fix transitioning between full screen mode and
    normal mode sometimes causing current position to not be
    preserved.
  - AZW3 Input: Ignore incorrect text encoding (incorrectly
    encoded bytes are now replaced by placeholders) instead of
    erroring out.
  - Get Books: Update Legimi and CDP store plugins for website
    changes.
  - Fix Cybook Nolimbook not being detected in linux and OS X.
  - DOCX Output: Fix internal hyperlinks being ignored when they
    point to a HTML file whose <body> element has an id.
  - Edit Book: Fix groups in replace template being interpreted
    backwards when search direction is up.
  - Searching: When search as you type is active, do not change
    automatically change focus to the book list when searching,
    unless the user presses Enter.
  - Font subsetting: Fix subsetting removing some needed
    ligatures when subsetting some Arabic fonts.
  - Prevent errors when testing email sending even if stderr on
    the host machine is broken.
  * New news sources:
  - Various Ukranian news sources by rpalyvoda
  * Improved news sources:
  - Baltimore Sun
  - El Mercurio Chile
  - Sydney Morning Herald
* Fri Jun  5 2015 cornelis@solcon.nl
- Update to version 2.30.0:
  * New Features:
  - An option to auto-convert a book on adding even if it is
    already in the output format (Preferences->Adding Books).
  - E-book viewer: If there are entries in the Table of Contents
    that are long enough to be truncated, display the full text
    in a popup menu when the mouse hovers over the item.
  - News download: Add support for turning off SSL certificate
    verification in individual recipes.
  - Kobo driver: Support for upcoming firmware version 3.16.
  * Bug Fixes:
  - DOCX Output: Fix aspect ratio of images being distorted when
    the input document specifies image width but not height or
    vice-versa.
  - DOCX Output: Fix extra page breaks being inserted in some
    situations.
  - LIT Input: Fix smarten punctuation not working for text (as
    opposed to HTML) based LIT files.
  - EPUB metadata: Fix extraction of cover image from EPUB 3
    files that do not use EPUB 2 backward compatible markup and
    that have incorrect cover page markup as well.
  - Book details panel: On windows use only \ as a path separator
    when copying file paths.
  - Edit Book: Fix Saved searches panel not working well with
    very long search/replace expressions.
  - OS X: Fix changing preferences causing 'Email to selected
    recipients...' appearing multiple times in the Connect/Share
    menu.
* Mon Jun  1 2015 cornelis@solcon.nl
- Added BuildRequires: libopenssl-devel to fix build
* Mon Jun  1 2015 cornelis@solcon.nl
- Update to version 2.29.0:
  * New Features:
  - Allow opening the full Tag Editor dialog directly from the
    book list by holding down the Shift key while starting an
    edit of a tag-like field. For example, click on the tags
    field for a book and press Shift-F2.
  - Tag Browser: Allow undoing the deletion of items in the
    Manage categories window.
  - calibredb add: Allow setting arbitrary identifiers, not just
    ISBN.
  - Add a 'Retry' button to the news download failed error
    message.
  * Bug Fixes:
  - DOCX Output: Detect the common idiom of placing centered
    images as inline images inside a containing centered block
    and render the resulting image as a floating centered image
    in the DOCX file.
  - DOCX Output: Fix incorrect handling of bold/italic in
    paragraphs where the majority of text is either bold or
    italic instead of normal.
  - Table of Contents editor: Fix save/load of settings in the
    XPath wizard not working across restarts.
  - Get Books: Update the Kobo Store plugin for website changes.
  * Improved news sources:
  - Popular Science
  - General Knowledge Today
  - Scientific American
  - Wired Magazine
* Thu May 28 2015 cornelis@solcon.nl
- Update to version 2.28.0:
  * New Features:
  - Conversion of all ebook formats to Microsoft Word (DOCX)
    files.
  - Add keyboard shortcuts (Ctrl+Right, Ctrl+Left) to switch
    between virtual library tabs.
  - When sending email using GMX pause for five minutes between
    books, to prevent GMX from blocking the account. The delay
    can be configured via Preferences->Tweaks.
  * Bug Fixes:
  - Open With: Fix application icons in XDG_DATA_HOME on linux
    not being found and fix unhandled error when choosing
    non-executable files as applications.
  - AZW3 Output: Remove duplicate anchors to workaround some
    Kindle renderers using the last occurrence of an anchor as
    the target instead of the first.
  - Fix language definition on body tag being ignored during
    conversion.
  - Edit book: When importing multiple files into the book,
    import them in the order sorted by their filenames instead
    of in random order.
  - E-book viewer: Fix print to pdf not working on some windows
    systems with non-ascii usernames and non-utf-8 system
    locales. Also make the print to pdf dialog a little easier
    to use.
  - Edit Book: Fix TOC editor window not remembering its last
    used size
  * Improved news sources:
  - Field and Stream
  - Linux Magazine
  - Brand Eins
  - Courrier International
  - Wired Magazine
  - The Onion
* Fri May  1 2015 cornelis@solcon.nl
- Update to version 2.27.0:
  * New Features:
  - Edit metadata dialog: Add a clear button for the publisher.
  - DOCX Input: Add option to not insert page breaks between
    endnotes.
  - calibredb list: Allow outputting the book languages as well.
  - Italian translation of Quick Start Guide.
  - Embed metadata: When embedding metadata fails for some books,
    add an option to show the failed books in the book list.
  - Animate the main toolbar when a device is connected/dis-
    connected, to indicate that the contents of the toolbar have
    changed.
  * Bug Fixes:
  - E-book viewer: When printing, print to a PDF file instead of
    directly to the printer. This fixes printing not working on
    some systems.
  - AZW3 Input: Handle kindlegen produced azw3 files that do not
    use normal HTML anchors for linking.
  - Fix too many open files errors that could occur in a few
    places on OS X.
  - Do not allow user to hide all columns in book list via the
    context menu, as restoring them becomes difficult.
* Mon Apr 27 2015 cornelis@solcon.nl
- Update to version 2.26.0:
  * New Features:
  - Driver for the soon to be released Kobo Glo HD.
  * Bug Fixes:
  - Do not use a separate process to draw the splash screen. This
    might fix the issue of calibre randomly freezing on startup
    on a few windows systems.
  - MOBI Ouput: Fix :first-letter applied to elements containing
    a comment causing conversion to fail.
  - Properly display names of libraries containing the ampersand
    character.
  - When sorting filenames in comics treat the file extension as
    a secondary sort key. Fixes xyz.jpg sorting before xyz_1.jpg.
  - Fix a regression in 2.25 that broke the search & replace
    wizard in the conversion dialog when converting a book with
    multiple formats.
  - Content server: Fix errors when library contains enough
    virtual libraries to cause grouping.
  - Manage tags dialog: Fix setting a tag to empty causes an
    unhandled error.
  - E-book viewer: Fix a regression that caused the viewer to
    occasionally skip the last page in a chapter when displaying
    more than one pages per screen and scrolling by screen.
  - Edit Book: Fix open OPF file not being refreshed when
    deleting items from the file browser.
  * New news sources:
  - Discover Magazine Monthly by Michael Marotta
  * Improved news sources:
  - WirtschaftsWoche Online
  - Wired
  - CNN
* Sat Apr 18 2015 cornelis@solcon.nl
- Update to version 2.25.0:
  * New Features
  - Edit Book: Make embedding fonts using the manage fonts dialog
    easier. You can now double click on a font family to see what
    faces for that family area available on your computer and
    install new fonts directly from the dialog.
  - Book Details panel: Allow deleting tags/series/publisher/etc.
    by right clicking on the link in the book details panel.
  - E-book viewer: Allow expanding/collapsing all items in the
    Table of Contents view by right clicking.
  - When using the View specific format action add an 'Open With'
    button to choose a specific program to view the specified
    format.
  - Fetch News: Add API to allow recipe writers to easily resolve
    internal links to point to the downloaded versions of
    articles.
  - DOCX Input: Add support for DOCX files created by Word 2013
    in 'Strict' mode.
  - When getting cover from comic files, use smart filename
    sorting to find the first filename, recognizing numbers
    inside the filenames.
  * Bug Fixes:
  - E-book viewer: When displaying multiple pages per screen fix
    whole screen scrolling so that it works as expected even at
    the end of the file, when their might be fewer pages left
    than would fill the screen.
  - DOCX Input: Automatically resize large images used as bullets
    in lists, to compensate for the fact that HTML renderers do
    not do this.
  - Book list: Prevent yes/no columns from making the minimum row
    height too large.
  - Template language: Fix raw_field() function returning
    incorrect values for lists
  - Edit book: Fix book locale changing when OPF edited if OPF
    contains a country code in addition to a language code.
  - Edit Book: Fix escaped HTML tags in the comments metadata
    being reported as mis-spelled words.
  - Edit Book: Fix regression that caused copying of non-breaking
    spaces to not work when using the keyboard shortcuts.
  - en With: Fix open with not working for programs from the
    Microsoft Office suite.
  * New news sources:
  - MIT Technology Review Magazine by Michael Marotta.
  - The Codeless Code by April King.
  * Improved news sources:
  - Die Zeit.
  - NZZ Webpaper.
  - Arcamax.
* Mon Apr 13 2015 cornelis@solcon.nl
- Update to version 2.24.0:
  * New features:
  - E-book viewer: Add an option to not save the bookmarks inside
    EPUB files, under the Miscellaneous section of the viewer
    preferences.
  - Manage User Categories: Allow restricting the visible items
    to only those present in the current Virtual Library (if
    any).
  - Book details panel: Allow copying full path to ebook files by
    right clicking on the format link.
  * Bug Fixes:
  - Edit Book: Fix GIF format images being corrupted when using
    the builtin image editor to make changes to them.
  - Edit Book: When dragging and dropping files to re-order them
    in the file browser, fix the final order being dependent on
    the order the files were selected in.
  - Conversion: Fix error when converting a document that
    contains an invalid function based CSS selector without
    parentheses.
  - Edit Book: Fix regression that caused pressing Alt+X to type
    unicode characters to not work.
  - Device view: Preserve position in list of books when deleting
    books from the device view.
  - Make the context menu for the book details popup window work
    the same way as for the book details panel.
  - Get Books: Update amazon store plugin for website changes.
  - PDF Metadata: When choosing between reading metadata from the
    Info dict and the XMP block, consider both the MetadataData
    and the ModifyDate in the XMP block, since there exist PDF
    metadata writing tools that update one and not the other.
  - Fix a regression that caused ebook viewer to remember the
    state of the Table of Contents panel when quitting on OS X.
  - Prevent Enter key on Manage authors/tags/etc. dialogs from
    closing the dialog.
  * Improved News Sources:
  - Le Temps
  - United Daily
  - Liberty Times
  - Apple Daily
  - China Times
  - House News
  - Providence Journal
  - Harvard Business Review
* Sat Apr  4 2015 cornelis@solcon.nl
- Update to version 2.23.0:
  * New features:
  - Allow adding an empty ebook in various formats to existing
    book records by right clicking the Add Books button.
  - Add ability to create additional empty formats to the 'Add
    empty book' command.
  - News download: Add API to cleanly abort the download of an
    article during the preprocess stage based on the article's
    contents.
  * Bug Fixes:
  - MOBI Input: Fix links not working in viewer for MOBI files
    that contain anchors placed on linebreak elements.
  - Book details panel: Fix copying Path link by right clicking
    on it not working.
  - Fix a regression that caused importing of a single book from
    a directory to fail if the directory has no ebook files in
    it.
  - Column Icons: Fix apostrophes in icon filenames causing
    errors.
  - Edit Book: Fix a regression that caused Remove unused CSS to
    fail on invalid CSS selectors, instead of ignoring them.
  * Improved news sources:
  - Esquire
  - Courrier International
  - CNET
  - Tageschau
* Sun Mar 22 2015 cornelis@solcon.nl
- Update to version 2.22.0:
  * New features:
  - Book List: When editing data in the book list directly,
    expand the editor widget to use all available width if the
    data does not fit inside the current column width
  - Edit Book: When re-opening a previously edited book, restore
    all open files and the cursor position. Can be disabled in
    Preferences->Main Window
  - Advanced search builder: Allow using days/weeks/months/years
    when building a date based search with number of days ago.
  - Amazon metadata download: Speedup metadata download from
    amazon.com when an ASIN is specified by trying the product
    page directly first instead of running a search.
  - Implement updating metadata in DOCX files
  * Bug fixes:
  - ODT Input: Add support for intra-document cross-references.
  - PDF Output: Fix incorrect encoding of ASCII control
    characters and some Chines characters in metadata and Table
    of Contents strings.
  - Amazon metadata download: Work around amazon server problems
    where it does not return Kindle Editions in search results
    when not logged in.
  - Fix Manage Authors dialog causing current search in the book
    list to be cleared.
  - Conversion: Fix a regression in 2.21 that caused conversion
    to fail for books with invalid pseudo-class CSS selectors.
  - Content server: Fix OPDS categories not showing books for
    composite column categories if the column contains a colon.
  - Single convert dialog: Only write metadata updates if
    metadata actually changed. Also show a nicer error message
    when a file is locked by another process.
  - Open With: Fix error when scanning for default programs on
    windows for some file types
  - Edit Book: Fix Preview panel sometimes not working when
    opening multiple html files one after the other very quickly
  * Improved News sources:
  - Wired Daily
* Mon Mar 16 2015 cornelis@solcon.nl
- Update to version 2.21.0:
  * New features:
  - Allow opening ebook files and covers in external applications by simply right clicking on them in the Book Details panel.
  - Tag Browser: Make rename and delete for items in the Tag Browser restrict themselves to the current Virtual Library (if any). There is also an additional menu entry you can use to rename and delete across all books while in a Virtual Library.
  - Conversion: Use a new (written from scratch) implementation of CSS Level 3 selectors that fixes various bugs in handling of the more advanced/uncommon CSS selectors such as nth-last-child()
  - Edit Book: Allow restoring of disabled confirmation prompts in preferences and add a confirmation when removing saved searches
  - Edit ToC button: Remember the last used ebook formats
  * bug fixes:
  - E-book viewer: Fix regression that prevented pasting of text with formatting from the viewer.
  - Table of Contents Editor: Fix selecting a location inside a file and then clicking on another file causes the previous location to be used in the new file.
  - DOCX Input: Fix incorrect bold font weight being used for heading styles even if the style definition does not specify bold.
  - AZW3 Input: Fix a bug that prevented conversion of AZW3 files that contained an empty CSS media block.
  - PDF Output: Fix incorrect rendering of text in elements that use font-variant:small-caps and also have children.
  - Get Books: Update Amazon Europe, Empik and CDP store plugins
  - PDF Output: Fix incorrect conversion of source document that specify dir='rtl' on the root element.
  - PDF Output: Ignore unparseable links instead of aborting the conversion on them.
  - Fix reading metadata from filenames tester not working for dates before 1900.
  - Linux binary install: Fix SSL CA certificates not being detected on Fedora based distributions
  - Books list: Fix column alignment incorrectly propagating when changing libraries
  - FB2 Input: Do not put a border around images
  - Fixes for various incompatibilities with (Py)Qt 5.4.1 which is used by some calibre distro packages on linux
  - Fix error when running calibredb backup_metadata on a library that contains book records with no path information
  - Edit Book: Fix extra search being hidden when removing a saved search
  - Fix a regression in 2.20 that prevented some changes to per-library preferences from being saved
  - Linux installer: Do not register application/octet-stream as one of the mimetypes calibre can handle
  * improved News sources:
  - Spektrum der Wissenschaft
  - New Musical Express
  - The Daily Mirror
  * new news sources:
  - Pando Daily
* Sat Feb 21 2015 cornelis@solcon.nl
- Update to version 2.20.0:
  * new features:
  - ODT Input: Add backlinks for footnotes/endnotes and improve their formatting.
  - Windows: When running on windows 8 and newer register with default programs so that users can more easily select calibre or its viewer/editor as the default program to launch ebook files.
  - Make publishers in the book details panel clickable.
  - Edit Book spell check: For mis-spelled words of the form one:two offer one: two as a suggested correction.
  * bug fixes:
  - Fix a regression that caused incorrect results when searching on numeric or date fields with relational operators.
  - DOCX Input: Fix regression in 2.19 that broke handling of text with leading or trailing non-breaking spaces/en-spaces/quad-spaces.
  - Amazon metadata download: Update plugin for website changes to Amazon Brazil.
  - E-book viewer: Fix footnote popup window not displaying entire footnote if footnote contains element with page-break-after set
  - Edit Book: Reports tool: Fix double clicking on an unused image causing an error
  - Tag Browser: Fix incorrect grouping of words starting with graphemes, such as ash.
  - Conversion: Ignore incorrectly URL encoded links instead of erroring out on them.
  - E-book viewer: Remove soft-hyphens when copying text to clipboard
  * improved news sources:
  - aktualne.cz
* Wed Feb 11 2015 cornelis@solcon.nl
- Update to version 2.19.0:
  * New Features:
  - Quick view window: Allow the quickview window to be docked into the main calibre window.
  - Add empty book: Allow setting the title as well as the author and series for the added empty book records.
  - Windows driver for Grammata Papyre 602.
  - Edit Book: Add an option to turn off auto-completion of closing tags.
  - Allow adding a description for custom columns.
  - Book Details panel: Allow any identifier of the form url+number to become a clickable link. For example: url1:http://example.com.
  * Bug Fixes
  - Conversion: Convert entities that reference non-BMP unicode codepoints on Windows and OS X correctly. Linux was not affected by this bug.
  - Edit Book: Do not autocomplete the closing tag wen typing the / key inside an existing tag.
  - Fix Booken Lev e-book reader not being detected in OS X and Linux.
  - DOCX Input: Change handling of sequences of space characters to more closely follow Microsoft Word.
  - Edit Book: Fix Table of Contents editor not remembering its saved state across calibre sessions.
  - Edit book: Disallow drag and drop of documents onto the preview panel to workaround crashing bug in Qt.
  - E-book viewer: Fix current page not being preserved when opening and then immediately closing the footnote window.
  - PDF Output: Fix incorrect encoding for some chinese characters in the PDF Outline (Table of Contents).
  * Improved news sources
  - FAZ.net
  - Indian Express
  - CNN
* Fri Jan 30 2015 cornelis@solcon.nl
- Update to version 2.18.0:
  * New features:
  - Edit Book: Add 'Style Classes' and 'Links' report pages to the Reports tool
  - Tag browser: Allow expanding all children of a node by right clicking and choosing 'Expand All'
  - Preferences: Re-arrange the controls to avoid needing to move the mouse from the top to the bottom of the dialog when closing the dialog after making some changes
  * Bug fixes:
  - Save to Disk: Fix a bug where when multiple books are being saved to disk, if the save to disk template results in identical filenames, the filenames were not being properly disambiguated.
  - Preferences: Use a dialog instead of a main window to workaround Qt's poor handling of full screen mode on OS X Yosemite
  * Improved news sources:
  - Al Jazeera in English
* Fri Jan 23 2015 cornelis@solcon.nl
- Update to version 2.17.0:
  * New features:
  - Edit Book: A new reports tool that shows a summary of files, images, words, characters and styles used in the book.
    _ Edit Book: Allow adding the 'Manage Snippets' action to the toolbar, for easy access.
  * Bugfixes:
  - Update Ozon.ru metadata download plugin for website changes.
  - E-book viewer: Fix regression in 'flow' mode that caused horizontal scrollbar to be rendered as vertical.
  - Fix a regression that prevented adding of books from sub-folders if the folder contained only an OPF file and no actual ebook files.
  * New and improved news sources.
  * For details, see http://calibre-ebook.com/whats-new
* Tue Jan 13 2015 cornelis@solcon.nl
- Update to version 2.16.0:
  * New features:
  - Edit Book: Add support for snippets -- small pieces of text
    that are often re-used.
  * Bug fixes:
  - Edit Book: When importing files and the book has an orphaned
    entry in the manifest for that file, but the file itself is
    not present, rename the file instead of erroring out.
  - Book Details panel: Fix author links with URL schemes other
    than http or file preventing context menu from working.
  - PDF Output: Make the minimum height for headers and footers
    scale with the base font size
  - Fix a typo that prevented the Cybook Muse from being detected
    on some computers.
  - Fix regression in 2.15 that broke calibre on OS X 10.7 and
    10.8
  * Improved news sources:
  - Various updated Turkish news sources
  - tyzden
  - Sueddeutsche Zeitung
  * New news sources:
  - title: Ajans Firat and Edebiyat Haber
    author: asalet_r
  * For details, see http://calibre-ebook.com/whats-new
* Wed Jan  7 2015 tchvatal@suse.com
- Update no-update patch to actually inverse the logic and let
  user override it:
  * calibre-no-update.diff
- Do not use bundled beautifulsoup
- No need to build without strict aliasing
* Wed Jan  7 2015 tchvatal@suse.cz
- Remove code that unpacks csselect directly as it was 12.2 only
  which is obsolete for quite time already
* Tue Jan  6 2015 cornelis@solcon.nl
- Removed liberation fonts from package (boo#911756)
* Sat Jan  3 2015 cornelis@solcon.nl
- Update to version 2.15.0:
  * Edit Book: Add auto-completion for links
  * Edit Book Function mode: Add builtin functions to change case of text, ignoring HTML tags in the matched text
  * Edit Book - Check Book: Allow auto-fixing of file not in spine errors
  * Driver for Papyre 624 ml
  * Conversion: Convert images encoded as data URIs in the input document into normal images, as some ebook reader software cannot handle data URIs
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Sat Dec 27 2014 cornelis@solcon.nl
- Update to version 2.14.0:
  * Metadata review dialog: Automatically insert series number when selecting a series from the completion dropdown. Also if the user does not specify a series number, use 1 as the default, instead of not setting the series.
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Wed Dec 24 2014 hrvoje.senjan@gmail.com
- Harden required Qt5Core and Qt5Gui library versions: Qt's private
  headers are not under BC guarantee, and can break it even with
  patch releases
* Fri Dec 19 2014 cornelis@solcon.nl
- Update to version 2.13.0:
  * Driver for the new CYBOOK MUSE ebook reader
  * Edit metadata dialog: Allow editing identifiers in a dedicated window by right clicking on the identifiers edit box.
  * Allow generating a cover from metadata by right clicking the cover are in the book details panel also.
  * Content server: Server KEPUB files with the extension kepub.epu when connecting to the browser on Kobo devices
  * Kobo driver: Add support for new firmware version 3.12
  * Edit metadata dialog: Add a keyboard shortcut to swap title and author [Alt+Down]
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Fri Nov 28 2014 cornelis@solcon.nl
- Update to version 2.12.0:
  * Edit Book: Automatically complete the closing tag in HTML/XML files when typing </
  * Edit Book: Implement auto-indent, now when pressing the Enter key to start a new line, the new line's indentation is automatically created Driver for the Verso E71b ebook reader
  * Redesigned the 'Add a custom news source' dialog to make it easier to use, with a more powerful python editor
  * Make translations of the User Manual available in many different languages (fully or partially translated). Click the 'Change Language' link in the sidebar of the manual to change the language
  * Edit Book: Search & Replace function mode: Add a new function annotation (replace.file_order) to control what order multiple files are processed in, when doing Replace All. See the User Manual for details.
  * Bugfixes
  * Additional news sources.
  * For details, see http://calibre-ebook.com/whats-new
* Sat Nov 22 2014 cornelis@solcon.nl
- Update to version 2.11.0:
  * Edit Book: Add a new 'function mode' for the Search and Replace tool
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Mon Nov 17 2014 cornelis@solcon.nl
- Update to version 2.10.0:
  * Driver for the PocketBook Lux 2 with latest firmware.
  * Review downloaded metadata: Add suggestions for the tags, authors, publishers and series fields. Suggestions will pop-up as you type.
  * Add Books: Improve performance when adding large numbers of books at once
  * Add Books: Allow adding books from multiple ZIP/RAR archives, each containing many books, by right clicking on the Add Books and choosing 'Add from Archive'
  * Metadata download: Prioritize results that have the same language as the current calibre user interface language
  * Edit Book: Make the CSS used for styling the generated HTML Table of Contents user customizable via http://manual.calibre-ebook.com/customize.html#overriding-icons-templates-et-cetera
  * Bugfixes (for details see, http://calibre-ebook.com/whats-new)
* Sat Nov  8 2014 cornelis@solcon.nl
- Updated calibre-no-update.diff
* Sat Nov  8 2014 cornelis@solcon.nl
- Update to version 2.9.0:
  * E-book viewer: Show footnotes in a separate popup windows
  * Cover Grid: Improve scroll wheel based scrolling
  * Get Books: Add the Bubok Portugal store
  * Performance improvement for large libraries that using custom columns built with templates
  * Review downloaded metadata dialog: Allow merging tags by long clicking the revert button
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Mon Nov  3 2014 cornelis@solcon.nl
- Update to version 2.8.0:
  * Get Books: Add a new store, Bubok (bubok.es)
  * Driver for Tolino Vision 2
  * Review downloaded metadata: Allow merging downloaded and current identifiers by long-clicking the revert button
  * Template language: New function user_categories() to return the list of User Categories for a given book (only works in the GUI)
  * E-book viewer: Add an option to prevent tapping on the page from turning pages
  * Bugfixes
  * For details, see http://calibre-ebook.com/whats-new
* Sun Oct 26 2014 cornelis@solcon.nl
- Update to version 2.7.0:
  * Support for new Kindle Voyage
  * Redesign notifications
  * Insert metadata as jacket page
  * For details, see http://calibre-ebook.com/whats-new
- Started cleaning up of BuildRequires and Requires
- Removed most shebangs reported by rpmlint
* Fri Oct 17 2014 cornelis@solcon.nl
- Update to version 2.6.0:
  * For changes see http://calibre-ebook.com/whats-new
* Tue Oct  7 2014 cornelis@solcon.nl
- Update to 2.5.0:
  * Switched to Qt 5
  * For details see http://calibre-ebook.com/whats-new
- Removed the obsolete Obsolete/Provides for calibre07 and calibre-icons-branding
- Updated BuildRequires for Qt 5
- Changed Requires: liberation-fonts into Recommends
* Sun Sep 21 2014 cornelis@solcon.nl
- Updated to 1.48.0 (last version for qt4):
  * For details see http://calibre-ebook.com/whats-new
- Update calibre-no-update.diff and add annotation for reason patch
* Fri May 16 2014 saigkill@opensuse.org
- updated to 1.37
- New features:
  o Edit Book: Live spell checking in the code view. Now spelling errors
    are highlighted in the code view for convenient correction as you
    type. This can be turned off via Preferences->Editor.
  o E-book viewer: When using the tap and hold gesture on a touchscreen,
    allow lookup of the word currently under the finger in the dictionary
    or online.
  o Edit Book: Allow putting the editor into replace mode by pressing the
    Insert key
  o Content server: Add more descriptive titles to the OPDS feeds, where
    possible.
  o Edit Book: Update the Table of Contents view automatically when the
    ncx file is edited.
  o Edit book: Insert tag button: Allow entering attributes along with the
    tag name to make it easy to repeatedly insert, for example, .
  o Windows driver for Woxter Scriba 190.
  o Edit Book: Add an entry to the context menu of the preview panel to
    open external URLs when a link is right clicked on
- Bug fixes:
  o Edit Book: Fix error in the Check Book tool when items in the opf have
    paths starting with a leading slash.
  o Book polishing: Fix publisher field in epub not being cleared when
    updating metadata.
  o Kobo driver: Update to handle changes to annotation processing in
    newer Kobo firmware.
  o DOCX Input: Handle docx files with index fields that have their field
    names incorrectly lower cased.
  o Edit book: Fix incorrect syntax highlighting on linux if the text
    contains non-BMP unicode characters.
  o Edit book: Fix regression that caused an error when trying to edit
    files with no defined syntax, such as plain .txt files.
* Sat May  3 2014 saigkill@opensuse.org
- updated to 1.35
- New features:
  o Edit Book: Redesign the syntax highlighter to improve performance for
    large documents and extended editing sessions.
  o Edit book: Make cursor movement smooth by not highlighting matching
    tags while the cursor is moving. Only match highlighting tags if the
    cursor stays still for a time.
  o Spellcheck dialog: Indicate whether a word is ignored in the
    Misspelled column
  o Spellcheck dialog: Pressing Ctrl+C on the words list copies only
    selected words, regardless of current cell
  o Add a copy to clipboard action to the context menu for the spell check
    dialog
  o Edit book: Fix save button incorrectly disabled after a failed save
- Bug fixes:
  o Edit Book: Fix an error when merging CSS stylesheets that contain
    @charset rules
  o Edit book: Fix extra invalid entries being generated in the manifest
    when editing an AZW3 file that has no images.
  o Edit book: Fix a hang when editing an HTML or XML file with text of
    the form  Fix regression that prevented the ebook editor from starting
    on linux systems with locale set to 'C'
  o DOCX Input: Fix formatting of the generated Index when the index is
    complex, i.e. with lots of references to the same item, multiple level
    of sub-items, etc.
  o Smarten punctuation: Fix a double quote preceded by a hyphen at the
    end of a sentence (before the start of the next tag) being converted
    into an opening quote instead of closing quote.
  o News download: Fix very long URLs for links to pages causing errors on
    windows because of max path length restrictions.
  o Edit book: Fix saved search dialog causing high CPU usage
  o Edit book: Fix importing of Lithuanian dictionary from OpenOffice,
    that does not specify a country code.
* Sun Apr 27 2014 saigkill@opensuse.org
- updated to 1.34
- New features:
  o E-book viewer: When in flow mode, handle swiping on the touchscreen
    differently. Swiping now scrolls line by line in flow mode instead of
    page by page. If you wish to scroll page by page in flow mode, tap
    instead of swiping.
  o Conversion: Preserve all guide entries that are of a type present in
    the EPUB 2.0 specification. These entries are used by newer Kindle
    readers to populate the Go To jump list
  o When adding MOBI files if the author name is in LN, FN format, auto
    change it to FN LN format, as the MOBI format has no author sort
    field. This behavior can be disabled by setting
  o Preferences->Tweaks->Author sort name algorithm to copy.
  o Spellcheck: When checking French text list all words that have the
    same stem as a single word. So j'aime and aime are listed as a single
    word.
  o Spell check: Add a context (right click) menu that allows for quick
    operations on all selected words
  o Manage user dictionaries: Add a button to import a list of words in
    bulk into the user dictionary
  o Spell check dialog: Allow sorting words case sensitively
- Bug fixes:
  o EPUB Input: Fix incorrect handling of obfuscated fonts using the IDPF
    obfuscation algorithm when the epub unique identifier starts with
    urn:uuid
  o Edit book: Fix obfuscated fonts in EPUB files not being handled
    correctly when editing the book (obfuscated fonts would get corrupted
    when making changes).
  o Edit book: Fix a bug that caused spell checking to fail when using the
    builtin spanish dictionary
  o Spell check: Fix replacing a word and then replacing the new word
    again not working without doing a refresh in between
  o Spell check: Fix language declarations not being respected for nested
    tags.
  o Spell check: Fix 'Show next occurrence' sometimes showing the word in
    an incorrect location, for example in an attribute where spell check
    is not performed.
  o Allow import of dictionaries that deviate from the spec in minor ways
  o Edit Book: Fix the Show next occurrence button in the spell check
    dialog sometimes failing to show next occurrence
  o OS X: Detect the users default interface language correctly. Also fix
    parsing of ambiguous dates in mm/dd vs dd/mm formats, based on the
    users locale settings in OS X.
* Sun Apr 20 2014 saigkill@opensuse.org
- updated to 1.33
- New features:
  o Edit book: Add a tool to check spellings, access it via Tools->Check
    spelling
  o Kobo driver: Support firmware version 3.3
  o Device driver for Tolino Vision on windows
- Bug fixes
  o Amazon metadata download: Fix Editorial Reviews not downloading into
    the comments section for some books
  o DOCX Input: Fix some text highlighting colors in the DOCX file not
    being correctly translated during conversion.
  o Wireless device driver: Fix incorrect syncing behavior when book
    matching is run for a second time while connected. This happens when
    the user changes the library or selects 'Update cached metadata on
    device'.
  o Searching: Fix searching by date not using the system locale to
    interpret dd/mm vs mm/dd dates on windows
* Sun Apr 13 2014 saigkill@opensuse.org
- Updated to 1.32
- New features:
  o Fetch news: Allow automatically creating custom news sources by
    importing OPML files. Many RSS news reader programs can export their
    list of RSS feeds in the OPML format.
  o Conversion: When inserting metadata as a jacket page, alter the font
    sizes in the jacket so that the sizes match the sizes used in the rest
    of the book. Also pretty print the generated jacket HTML.
  o Allow searching for books by id and uuid using the id: and uuid:
    prefixes
  o Allow specifying arbitrary colors for column coloring rules
- Bug fixes:
  o Update the version of openssl shipped in the binary builds (the
    version in the windows 64bit build was vulnerable to the Heartbleed
    bug)
  o Edit Book: Fix book being marked as modified even when no actual
    changes were done by various automated tools such as Smarten
    Punctuation, Subset Fonts, etc.
  o Fix ebook-device cp -f failing when destination file already exists
    Ensure that the rendered dates in the book list and edit metadata
    dialogs are always in the same language as the calibre interface,
    regardless of system language setting
  o Edit metadata dialog: Remember window size for the cover download
    window
  o DOCX Input: Dont fail on DOCX files that contain pages with zero
    effective width.
  o Content server: Fix page not found error when clicking on a category
    that has only a single item in it
  o Send books to the Books folder for the Tolino Vision, as it cannot
    find books placed outside this folder
  o Edit book: Fix error when beautifying HTML files that contain
    un-indented
* Sun Mar 23 2014 saigkill@opensuse.org
- Added download_tarball.sh for downloading the original tarball from
  download.calibre-ebook.com, updating versionnumber in the specfile
  and trigger osc vc
- New Features
  o Edit Book: Add support for saved searches. Click Search->Saved
    Searches to bring up a dialog where you can create and manage saved
    searches
  o Edit Book: New tool to specify semantics in EPUB books (semantics are
    items in the guide such as preface, title-page, dedication, etc.). To
    use it, go to Tools->Set Semantics
  o Edit Book: Preview panel: Add a copy selected text action to the
    context menu
  o Edit Book: When inserting hyperlinks, allow specifying the text for
    the hyperlink in the insert hyperlink dialog
- Bug fixes
  o Fix a regression in the previous release that broke downloading
    metadata for authors with a double initial such as R. A. Salvatore.
  o Edit book: When generating inline Table of Contents, mark it as such
    in the guide section of the OPF.
  o E-book viewer: Fix right margin for last page in a chapter sometimes
    disappearing when changing font size.
  o Edit Book: Fix saving of empty files not working
  o Edit book: Fix a regression in the previous release that broke saving
    a copy of the current book on linux and OS X
  o Edit book: Fix syntax highlighting in HTML files breaks if the closing
    of a comment or processing instruction is at the start of a new line.
  o Edit book: Fix check book failing in the presence of empty
  o Catalogs: Fix handling of tristate boolean custom columns when
    creating EPUB/MOBI catalogs.
  o Linux build: Workaround for systems that have broken libc
    implementations that change the behavior of truncate() on file
    descriptors with O_APPEND set.
* Sun Mar 16 2014 andreas.stieger@gmx.de
- change to unchanged upstream tarball for calibre and cssselect
- add source URLs
- remove generate-tarball.sh, the script did nothing but recreate
  the tarball since r145
- remove spec comments to that effect that are no longer in line
  with what the script is actually doing
- remove conditionals around Sources
* Sat Mar  8 2014 saigkill@opensuse.org
- update to 1.27.0
- New Features:
  * An option to add multiple books from inside a ZIP or RAR file. Right
    click the Add Books button and choose 'Add multiple books from
    archive'.
  * Database backend: Make the database backend more robust when the
    calibre library is placed on flaky filesystems. Now when an I/O error
    occurs while writing to the database, the connection to the database
    is closed and re-opened and the operation is retried.
  * DJVU Input: Speedup extraction of text from DJVU files by implementing
    the BZZ decoder algorithm in C
- New Bugfixes:
  * MOBI Input: Fix empty  tags not being handled correctly in rare cases
    when the markup is bad enough to be parsed only using the fallback
    HTML parser.
  * Edit book: Fix column number of cursor shown in the bottom right being
    one less than it should be.
  * Edit book: Fix names for non-BMP unicode character (Such as emoticons)
    not being displayed in the lower right corner. Also allow these
    characters to be searched for by name in the Insert special character
    tool.
  * Do not show system tray notification popups while analyzing books on
    device, as they can be slow on systems that display multiple messages
    serially instead of replacing the last message
  * Linux installer script: Do not use the filesystem to pass the
    downloaded tarball to tar as it is possible for malicious code running
    on the users computer to alter the download file between signature
    verification and calling tar to extract the files.
  * DJVU Input: When extracting embedded txt from TXTz sections in DJVU
    files, fix incorrect extraction of txt when the djvutxt external
    program is not present.
  * Edit Book: Fix import HTML file as new book not working on OS X
  * Wireless device driver: Fix a regression that prevented it form
    working with the Calibre Sync Android app.
  * Fix a regression in 1.26 that caused width and height attributes on
    tags to generate CSS width and height properties without a 'px' suffix
  * Linux binary installer: Fix an error when using proxies and python 3
    with the new installer script
  * Edit book: When exporting files, fill the choose filename popup with
    the name of the file being exported as the default name
  * Make the new Linux installer script compatible with python 2.6.
* Sun Mar  2 2014 saigkill@opensuse.org
- update to 1.26.0
- New Features:
  * Edit Book: Allow direct importing of HTML or DOCX files as new books
    without doing a full conversion. Use File->Import HTML or DOCX to
    import a file as a new EPUB book with minimal changes from the
    original.
  * Linux binary installer: Various improvements to the binary installer.
    It now creates an un-installer (calibre-uninstall) that will remove
    all files created by the installer. It also no longer asks for the
    installation directory. If you wish to change that, you need to
    specify it in the installation command itself. Also the installer is
    now downloaded securely via HTTPS from github and verifies the
    signature of the installed files. Finally, it can be used to create an
    isolated install, that only makes changes to files in the installation
    directory and does not require root privileges.
  * Metadata download: Add an option to merge the downloaded comments into
    existing comments, instead of overwriting (Preferences->Metadata
    download).
  * Edit book: Add an option to automatically beautify individual files
    whenever they are opened for editing. Look under 'Editor Settings' in
    the Edit Book Preferences.
  * Bulk metadata download: When reviewing downloaded metadata allow
    hiding the controls on the comments box by right clicking in the
    comments area. Useful on smaller screens.
  * E-book viewer: When displaying metadata for the book, also display
    custom column metadata
- Bug Fixes:
  * Smarten punctuation: Correct handling for decade abbreviations like
    '60s and measurements in feet and inches like 1' 2".
  * EPUB Output: If the output profile is set to one of the Nook profiles,
    do not use shorthand CSS properties as the Nook cannot handle them.
  * Conversion: Fix incorrect CSS being generated when converting files
    that have  tags with width or height attributes that contain
    fractional numbers.
  * Edit Book: When editing EPUB files, and a file is added in META-INF/
    do not automatically add it to the manifest. Also do not warn about
    unmanifested files inside META-INF/ since a few vendors (Apple)
    require non standard files in that location.
  * Fix Book details popup window not being updated when editing metadata
    in the main window
  * Edit book: Fix editor not marking the book as modified when doing a
    Replace All that does not affect any currently open files.
  * Windows: Use a separate worker process to move files to the recycle
    bin. Fixes the problem of the recycle bin icon not being updated when
    deleting books into an empty recycle bin. Also avoids the overhead of
    launching a new, short-lived worker process for every delete.
  * calibredb: When deleting books/formats wait for deleted files to be
    moved to recycle bin, before quitting
  * RTF Output: Fix invalid RTF being produced when the text contains a
    double backslash.
  * Edit book: Fix option to disable showing the character before cursor
    not working
  * Get Books: Update various store plugins to account for changes to the
    store websites
  * Fix virtual library names with ampersands in them not being displayed
    correctly in the virtual library menu and tab bar
* Mon Feb 10 2014 saigkill@opensuse.org
- update to 1.23.0
- added /usr/share/appdata to specfile
- New features:
  * Edit Book: Highlight the closest surrounding tag when editing HTML/XML
  * Edit Book: Add a tool to easily change the current paragraph (the
    paragraph containing the cursor) to a heading. Simply click the button
    with 'H1' on it and choose the heading level you want the current
    paragraph changed to.
  * Edit Book: When running Replace All add a button to the replaced
    message to show exactly what changes were done and allow them to be
    undone
  * Edit book: When checking book, detect case mismatches between links
    and the filenames of the files they point to and offer to auto-correct
    the links
  * Adding books: Implement a copy to clipboard button for when duplicates
    are found during the adding process. Useful if you wish to review the
    list of duplicates later.
  * Linux installer: Install appdata files for integration with software
    stores.
  * Edit book: Auto add a checkpoint when the book is first opened for
    editing
- Bug fixes
  * Edit Book: Fix a bug in AZW3 support that could cause images/fonts to
    get mixed up when saving and re-opening the book multiple times.
  * Edit Book: Fix individual find and replace not working in regex mode
    if the search expression uses lookbehind/lookahead operators
  * Compare books: Fix unchanged lines at the start of a change block
    being sometimes marked with a blue background, even though they
    contain no changes
  * Compare books: Fix incorrect scrolling when viewing all text and a
    large amount of text is present after the final change.
  * PDF Output: Fix a zero division error when the transformation matrix
    has a zero diagonal
  * calibredb add_custom_column: Fix a spurious error message when adding
    custom columns caused by the new db backend
  * calibredb list: Fix error if one of the requested fields is empty for
    all requested books
  * calibredb set_metadata: Fix setting series_index with the -f argument
    not working
  * Markdown input: Fix handling of very large files.
  * Edit book: Do not create savepoints when no changes are performed by
    automated tools such as smarten punctuation, remove unused css etc.
  * Edit Book: Fix a bug that would cause an error when a global operation
    like find/replace or polishing fails.
  * Metadata download: Workaround edelweiss.com no longer being able to
    search by author name. Search only by titles and filter the results
    returned by edelweiss to only include matching authors.
  * HTML 5 parser: Preserve non-core namespace declarations on the  tag
  * Workaround broken file chooser dialog on Ubuntu that does not
    auto-insert the specified extension.
  * Compare books: Fix error when previously different files become
    identical after beautifying
  * Edit Book: Fix subsetting embedded fonts not processing fonts included
    in a stylesheet that is itself referenced only by an @import rule
  * Edit Book: Fix the remove unused css tool changing the namespace
    prefix used for the XHTML namespace in the CSS sheet, if any
  * Conversion: Fix CSS selectors using the epub namespace being ignored
  * Compare books: Fix double clicking in the right panel not opening the
    correct file in the editor
* Fri Jan 31 2014 saigkill@opensuse.org
- update to 1.22.0
- New features:
  * A new tool to compare ebook files, showing the differences in their
    underlying text, styles and images side by side
  * Edit book: Add a tool to view the list of checkpoints and compare the
    current state of the book to the state at the specified checkpoint. To
    use it click View->Checkpoints
  * Edit book: Add a tool to compare the book being currently edited with
    another file. To use it go to File->Compare to other book
  * Allow comparing the ORIGINAL_EPUB version of a book to the EPUB
    version by right clicking on the ORIGINAL_EPUB format in the book
    details panel. And the same for ORIGINAL_AZW3 and AZW3 formats.
  * Edit Book: Add a button to show the changes after various automated
    tools are run such as: remove unused CSS, subset embedded fonts,
    smarten punctuation, etc.
  * Edit Book: Add check for spine items with incorrect media-type
    specified in the manifest
  * Edit Book: Enable editing of page map XML files
  * DOCX Input: Improve handling of text boxes. Text boxes are still not
    supported, but they no longer cause errors or duplicate content when
    embedded inside paragraphs.
  * Edit Book: Add check for links that point to directories in the book
    instead of files.
  * Edit Book: Show the filename of the currently edited file in the title
    bar.
- Bug fixes
  * Edit Book: Fix unused CSS removal tool inserting namespace declaration
    at the top of the stylesheet
  * Edit book: Fix cover not being updated from the current cover in the
    calibre library when using Edit Book. Note that you can turn off
    metadata updating via Preferences->calibre Integration in the Edit
    Book Preferences.
  * Conversion: Add support for
* Mon Jan 27 2014 saigkill@opensuse.org
- update to 1.21.0
- New features:
  * Edit book: Add a tool to automatically remove all unused CSS rules.
  * Useful for books created from templates that can have large numbers of
    CSS rules that dont match any actual content. Available via
    Tools->Remove unused CSS.
  * Edit book: Add a tool to split HTML files at multiple locations
    automatically. To use it, right click in the file and choose 'Split at
    multiple locations'. Useful if you want to split at all heading tags
    or all tags having a certain class and so on.
  * Book polishing: Add an option to automatically remove all unused CSS
    rules, works the same as the tool for Edit book, above.
  * Driver for ImCoSys imcoV6L
  * Edit book: Allow editing of .plist files as XML
- Bug fixes:
  * Metadata download: Fix downloading of metadata from Edelweiss not
    working because of website changes
  * Ebook viewer: Do not override the background color specified in the
    book if the user has not set a background color in the viewer
    preferences
  * Edit book: Handle EPUB files that erroneously list the OPF itself in
    the OPF manifest with an incorrect mime type
  * Edit book: Prevent arrange into folders tool from moving files inside
    the META-INF folder
* Sat Jan 18 2014 saigkill@opensuse.org
- update to 1.20.0
- New features:
  * Edit book: Add a new tool to automatically arrange all files in the
    book into folders based on their type. Access it via Tools->Arrange
    into folders.
  * Edit book: Add various validity checks for OPF files when running the
    Check Book tool.
  * Edit book: Add checks for duplicate ids in HTML/OPF/NCX files
  * Edit book: Add checks for filenames containing URL unsafe characters
    to the Check Book tool
  * Conversion: Allow getting text for entries in the Table of Contents
    from tag attributes.
- Bug fixes:
  * AZW3 Output: When converting EPUB files that include an HTML titlepage
    and no external cover is specified, ensure that the Go to cover action
    on the Kindle goes to the cover image and not the HTML titlepage.
  * Prevent setting an incorrect value for compression quality in the
    wireless driver causing an error
  * Show a busy cursor while calibre is working on matching books on the
    device to books in the library, which can take a while if the user has
    a lot of books on the device.
  * iTunes driver: Retry automatically a few times when failing to send
    multiple book to iTunes.
  * HTML Input: Fix UTF-16/32 encoded files that are linked to from the
    parent file not being properly processed.
  * EPUB Output: Fix splitting of large HTML files removing all child tags
    from inside tags.
  * Edit book: Fix tab characters not being identified in the lower right
    corner.
* Fri Jan 10 2014 saigkill@opensuse.org
- update to 1.19.0
- New features
  * Edit book: A new tool to insert special characters into the text,
    available via Edit->Insert special character. Supports all unicode
    characters (over 60,000 of them). See
    http://manual.calibre-ebook.com/edit.html#inserting-special-characters
  * Edit book: When searching for text in the editor, center the found
    text on screen
  * Driver for teXet TB-146SE.
  * Edit book: Show tooltips in the File Browser for 'special' files, such
    as the cover, opf, ncx, etc.
  * Edit book: When checking book, check for entries in the OPF whose
    mimetype does not match the file extension.
- Bug fixes
  * Edit book: Fix marking a file as titlepage not working if the opf does
    not contain a  section.
  * Edit book: Fix errors when working on HTML files that parse as valid
    XML, but do not have the correct XHTML namespace.
  * Fix typing non-English characters using an input method (key
    composing) in the author/tags/etc fields in the metadata dialog not
    working.
  * Edit book: Fix error when merging html files that include a currently
    opened file and a non-html file is also open
  * Fix unnecessary error popup during shutdown if the wireless device
    driver is running and mdns de-registration fails.
  * Add L´ and D´ as recognized articles when automatically computing sort
    strings for French.
  * Edit book: Fix changing mimetypes in the opf file not being detected
    when closing the opf file or running any automated tool like Check
    Book
* Sat Jan  4 2014 saigkill@opensuse.org
- updated to 1.18.0
- New features
  * Add an option to control how completion works when editing
    authors/tags/series/etc.
  * Edit book: Add a check for too large HTML files when running the check
    book tool.
  * Conversion: Sort the CSS rules in the output stylesheet using a
    'natural' sort algorithm, so that calibre2 sorts before calibre10.
  * Cybook Orizon driver: Upload cover thumbnails in the correct format
    and add an option to control what directory books are sent to on the
    SD card
  * Portable installer: Do not ask the user for confirmation when
    upgrading an existing installation during an automated install
    Linux/OS X driver for Trekstor Pyrus LED
  * Driver for Tagus Lux
- Bug fixes
  * MOBI Output: When text indent is specified as a percentage in the
    input document, prevent the generated MOBI from having too large an
    indent if the user chooses a large output profile like tablet.
  * Edit book: Fix live replacement of entities not working on some non-US
    keyboard layouts.
  * Fix titlecasing of words not capitalizing the first letter, if the
    first letter is not an English character.
  * Edit book: Ensure that multiple edit book windows are grouped in a
    separate group from viewer windows in the Windows 7 taskbar. Also
    change the icon color to blue to more easily distinguish it from the
    viewer icon
  * Edit book: Fix a bug in the regex engine that calibre uses that could
    cause various incorrect results in some special circumstances.
  * Edit book: Replace buggy Qt supplied actions in the context menu for
    the editor widget with properly implemented ones
  * Book list: Fix sorting on fields that are not viewable as columns not
    being restored on calibre restart. Also fix sorting on the Title field
    via the right click menu not being restored.
  * Windows 64bit build: Fix corrupted images in MOBI files causing crash.
  * Edit book: Prettify html in newly created books.
  * AZW3 Input: Handle azw3 files that contain some empty individual HTML
    files
  * Comic Input: Fix a regression to comic input in 1.15 that could cause
    some comics to be rendered as black or white pages.
* Mon Dec 30 2013 saigkill@opensuse.org
- updated to 1.17.0
- New features
  * Merry Christmas everyone! Early release this week, as I will be
    travelling.
  * Edit book: Allow drag and drop of images onto the image editor
  * Edit book: Allow import of multiple files at once, via File->Import
    files into book
  * Edit book: Show the name of the current character to the left of the
    cursor in the status bar. Can be turned off via Preferences.
  * Edit book: Automatically replace HTML entities as they are typed. This
    can be turned off in the Preferences.
  * ToC Editor: Allow bulk renaming of items. Simply select the items you
    want to rename, right click and choose bulk rename. Useful if, for
    instance, you want to rename all the items to be Chapter 1, Chapter 2
    and so on.
  * Edit book: Allow linking of stylesheets into HTML files automatically.
  * Right click on the selected HTML files in the File browser and choose
    'Link stylesheets' to have the  tags for the sheets automatically
    inserted.
  * Edit book: When deleting files, automatically remove all entries that
    refer to them from the ToC
- Bug Fixes
  * ToC Editor: When auto-generating the table of contents from headings
    or XPath, if an element is at the top of the file, link only to the
    file instead of to the element.
  * Edit book: When splitting files, name the newly created file with a
    _split suffix.
  * Edit book: Fix position syncing incorrect when in HTML files that
    contain  tags with charset encoding declarations over more than a
    single line
  * Edit book: Automatic correction of font family names not quoting
    family names with spaces in them if the original, incorrect family
    name did not have a space.
  * Title casing: Fix presence of some non-English characters or smart
    punctuation causing all-caps text to not be properly titlecased
  * Edit book: Fix a bug preventing marking an image as cover in a book
    that previously had no cover
  * Edit book: Fix a typo causing the preferences for which windows occupy
    which corners to not work
  * Edit book: Fix crash that happens sometimes when deleting multiple
    files.
  * Edit book: Handle EPUB files which contain opf files with no  tags
  * Edit book: Fix deleting a file that is currently open in an editor,
    not auto-closing the editor
  * DOCX Input: Fix error when converting DOCX file that contains only
    image based links and no text based links.
* Sat Dec 21 2013 saigkill@opensuse.org
- updated to version 1.16.0
- New features:
  * Edit book: Add a tool to browse all images in the book with their
    thumbnails. Useful for visually locating an image. To launch it, use
    View->Browse images in book.
  * Edit book: Allow creation of new, empty books via File->Create new
    book
  * Edit book: Add buttons to easily create formatting such as
    bold/italic/colors/etc. when editing HTML files
  * Edit book: Add button to easily insert  tag while editing HTML
  * Edit book: Add options to change the default font families/sizes for
    the preview panel
  * Edit book: Allow customizing which dockable windows occupy the four
    dock corners via Edit->Preferences. You can now also choose to have
    more than one row of windows in a given dock area.
  Bug fixes:
  * Edit book: When editing AZW3 files with no images in them, do not
    incorrectly display a number of binary records from the AZW3 file as
    'unknown' miscellaneous files
  * Edit book: Fix marking image as cover not working for AZW3 files if
    the file did not previously have a cover
  * AZW3 Output: Do not refuse to create the ToC if it has only a single
    entry
  * Edit book: Fix crashes when processing some books that contain
    malformed markup on OS X and windows 64bit machines
  * Edit book: Fix error when renaming the html file currently displayed
    in the preview panel and that file is not the file being currently
    edited
  * Edit book: Fix crash when editing books that have links to absolute
    paths.
  * Edit book: Fix book not being marked as modified after editing the ToC
  * Edit book: When syncing the position of the preview panel to the
    cursor in the editor and the cursor is at or before the  tag set the
    position of the preview panel to the top of the file, so that the top
    margin of the body tag is seen easily.
  * Edit book: Fix trying to import an html file/css file via the add new
    file button always resulting in a blank file
  * Edit book: Fix replacing a file with another file with exactly the
    same filename causing an error.
  * Edit book: Have the ToC view refresh itself after any major operation
    on the book
  * Edit book: Fix pasting in the image editor not working
* Sat Dec 14 2013 saigkill@opensuse.org
- updated to version 1.15.0
- New features:
  o A new book editor, capable of editing files in the EPUB and AZW3
    (Kindle) formats
  o Edit metadata dialog: In the tag editor, allow easy filtering of the
    lists of available and applied tags.
  o Driver for Onyx Boox C65.
- Bug fixes:
  o Kobo driver: Fix book covers not showing for sideloaded kepubs on the
    book details screen, with newer Kobo firmware.
  o Content server: Popup a more useful error when clicking on the cover
    of a book that has no formats to view.
  o Cover grid: Fix text showing 'None' for rating fields for books with
    no rating
  o Cover grid: Set text color based on the background color/image being
    used.
  o Metadata editor: Fix removing formatting for comments not removing
    background colors.
  o EPUB Output: Remove name attribute from  tags (replacing with id) to
    keep the asinine epubcheck happy
* Mon Dec  9 2013 alinm.elena@gmail.com
- updated to version 1.14.0
- New features:
  o Edit metadata dialog: Add the ability to trim covers manually,
    if automatic trimming is not satisfactory.
    Closes tickets: 1256054
  o You can now show any metadata field below the covers in the
    cover grid view, not just title. To change the displayed field
    go to Preferences->Look & Feel->Cover Grid.
  o Allow searching for plugins by name in the install new
    plugins dialog
  o Kobo driver: Allow sending kepubs to older kobo devices as well,
    also add support for firmware 3.10
    Closes tickets: 1257972, 1257143
  o Allow viewer plugins to customize the viewer's user interface
- Bug Fixes:
  o Table of Contents Editor: Handle generating ToC from headings
    if the first heading level in the document is not h1 or the
    document skips some intermediate heading levels
  o Update the metadata download and Get Books plugins for ozon.ru
  o Fix sending by email not working on computers with non-ascii hostnames.
    Closes tickets: 1256549
  o Wireless driver: Fix launching programs from within calibre causing
    the wireless driver port to remain in use even after calibre is shutdown.
    Closes tickets: 1256198
- Improved news sources
  o Kommersant
  o Pocket
  o Heraldo de Aragon
  o National Geographic Magazine
  o Los Angeles Times
  o Boerse Online
  o Reuters-
* Sun Dec  1 2013 saigkill@opensuse.org
- updated to version 1.13
- New features:
  o Edit metadata dialog: Facilitate editing the authors for books that
    have a large number of authors, by using a dedicated 'Edit authors'
    tool, which you can launch by right clicking the authors in the edit
    metadata dialog and selecting 'Edit authors'.
  o Conversion: Fix specifying shorthand properties in filter css not
    working. Now all shorthand properties automatically filter out all the
    properties they are shorthand for.
  o Kobo driver: support new firmware version 3.0.1
  o Wireless device driver: Cache metadata on a per device basis.
-Bug fixes:
  o Metadata download: Update code to get covers via google image search
    to handle changes to the google website.
  o Searching: When searching for identifiers, fix searching for values
    that contain colons not working. Also fix escaped parentheses not
    being parsed correctly.
  o Match books on device: Fix parentheses in book titles not being
    escaped when searching for matches.
  o Match books on device: Fix thumbnail in device metadata cache not
    being updated when matching books.
  o File open dialogs; If the previously used initial directory, no longer
    exists, use a directory one level up.
  o EPUB Output: Strip -- from inside comments, as some ebook reading apps
    cannot handle them.
  o Fix a regression in the previous release that broke the Kobo third
    party plugins
  o Fix QuickView windows not staying on top on some linux systems
  o Fixes for website changes for various Get Books Polish language stores
  o Metadata download dialog: Fix current cover not copyable to clipboard
  o Fix an incorrect translation of the language 'Polish'
* Sun Nov 24 2013 saigkill@opensuse.org
- updated to version 1.12
- New features:
  o Auto adding: Option to add files of all types, not just ebooks. You
    can now tell calibre to auto add all file types, instead of just known
    ebooks via Preferences->Adding books->Automatic adding.
  o Quick view: Show the title/author/series columns in the same order as
    in the main book list.
  o Update Kobo driver to allow sending kepubs
  o Allow right clicking on covers to copy them in the metadata cover
    download dialog.
- Bug fixes:
  o Titlecase: Fix incorrect title casing for some non-English words.
  o Kobo driver: Fix errors when using rating or numerical custom columns
    to create shelves.
  o E-book viewer: Allow searching to work with hyphenation enabled,
    provided you are searching for whole words. Searching for partial
    words may still not work. For robust searching, turn off hyphenation
    in the viewer preferences.
  o Get books: Update the B&N UK store plugin to handle changes to the B&N
    UK website
  o Apply changes being edited when clicking apply in the email
    preferences list.
  o Fix crash on linux systems whose fontconfig configuration includes
    paths to in an undecodable encoding.
  o Fix editing custom column values in the book list not allowing change
    of case.
  o Kobo driver: Fix latest firmware update for Kobo Wifi causing calibre
    to not recognize it.
  o Content server: Fix virtual libraries with an ampersand in their names
    not working
* Sun Nov 10 2013 Sascha Manns <saigkill@opensuse.org>
- added Suggests: python-Pillow
* Sat Nov  9 2013 saigkill@opensuse.org
- added a python-pillow patch for calibre
* Sat Nov  9 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.10
- New features
  o Conversion: Treat .docm the same as .docx files, ignoring any macros
    in the file.
  o EPUB Output: Auto convert CMYK images to RGB. Works around the
    inability of Adobe Digital Editions to display CMYK images.
  o Quickview: Add a checkbox to lock the quickview window so that it does
    not change while moving around in the main book list
- Bug fixes
  o Fix number of marked books shown in the drop down menu of the Mark
  o Books action not being updated when marked books are deleted (as
    opposed to being unmarked).
  o Book list: Preserve the current column when using Ctrl+Home or
    Ctrl+End shortcuts
  o Booklist: Fix using Page Up/Down keys moving book list by one row too
    many.
  o Metadata download: Do not auto trim downloaded covers as trimming can
    sometimes have undesirable effects.
  o Template language: Fix zero valued series indices not formatting
    correctly
  o Fix a regression in 1.9 that broke bibtex catalog creation
  o Quickview: Auto-close the quickview window when changing libraries.
    You have to open it again in the new library.
  o Linux binary build: Update the bundled version of zlib to fix library
    compatibility on some newer linux distros that have libpng16 compiled
    to require newer zlib versions
* Fri Nov  1 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.9
- New features
  o Drivers for the new Nook Glowlight, Lenovo IdeaPad and Kindle Fire HDX
    (linux)
  o Add an option to check for duplicates (books with the same
    title/author) when copying between libraries. Option is under
  Preferences->Adding books.
  o Content server: Display book title on details page. Also put the most
    important fields (authors/series/tags) at the top.
  o When developing recipes using the command line, allow specifying the
    number of feeds and articles when using the --test parameter.
  o PDF Output: Option to control title of generated Table of Contents
  o PDF metadata: If one of the keywords in the PDF is a valid ISBN, use
    it as the ISBN for the book
- Bug fixes
  o Amazon metadata download: Fix spurious ratings being returned for
    unrated books.
  o Bulk metadata edit: Only clear series if the clear series checkbox is
    checked. Also add a clear checkbox for publishers, so that publishers
    can be removed.
  o Use for the inserted Table of Contents title for the MOBI and PDF formats
    as well as the EPUB and AZW3 formats.
  o Fix comments editor in review metadata becoming too small on small
    screens.
  o DOCX Input: Fix hyperlink showing as underlined even if the hyperlink
    style in word is set to not show underlines.
  o E-book viewer: Remember the size of the 'Inspect' window used to
    examine the book's code.
  o Wireless driver: Fix bug that prevented different formats of the same
    book on the device from being recognized
  o Bulk metadata download: When downloading only covers and some covers
    fail, do not show the failed books while reviewing downloaded
    metadata.
  o BibTeX catalogs: Strip unmatched braces to prevent generation of
    invalid .bib file.
* Sun Oct 27 2013 Sascha Manns <saigkill@opensuse.org> - 1.8.0
- updated to 1.8
- New Features:
  o DOCX Input: Support linked (as opposed to embedded) images, if the
    linked image is found on the local computer.
  o FB2 Input: Add support for note and cite back references. Link pairs
    of type="note" and type="cite" now automatically generate the correct
    back reference.
  o When automerging books during during an add, include the author as
    well as the title in the report of merged books.
  o OS X Mavericks (10.9) breaks connecting to iTunes and iBooks on iOS
    devices. For more details see:
    http://www.mobileread.com/forums/showthread.php?t=215624
- Bug Fixes:
  o OS X: Fix system tray notifications causing crashes on some OS X 10.9
    (Mavericks) systems (those that had Growl installed at some point).
  o OSX: Fix font size in completion popups too small on Mavericks (I
    hope)
  o PDF Output: Fix rendering of some semi-transparent images. All
    semi-transparent images are now rendered using soft masks.
  o MOBI Output: Fix text marked with white-space:pre-wrap causing the
    Kindle to break lines at arbitrary points inside words.
  o FB2 Input: Fix a regression that broke conversion of FB2 files with
    paragraphs having both a style and an id attribute.
  o TXT Input: Ensure that
* Mon Oct 21 2013 Sascha Manns <saigkill@opensuse.org> -1.7.0
- updated to 1.7
- New Features:
  o Cover grid: Allow using images as the background for the cover grid.
  o To choose an image, go to Preferences->Look & Feel->Cover Grid.
  o An option to mark newly added books with a temporary mark. Option is
    in Preferences->Adding books.
  o Edit metadata dialog: Allow turning off the cover size displayed in
    the bottom right corner of the cover by right clicking the cover and
    choosing 'Hide cover size'. It can be restored the same way.
- Bug Fixes:
  o Conversion: If both embed font family and the filter css option to
    remove fonts are set, do not remove the font specified by the embed
    font family option.
  o Fix a few remaining situations that could cause formats column to show
    an error message about SHLock
  o Make deleting books to recycle bin more robust. Ensure that the
    temporary directory created during the move to recycle bin process is
    not left behind in case of errors.
  o Windows: Check if the books' files are in use before deleting
  o Fix custom device driver swap main and card option not working. Also
    fix swapping not happening for a few devices on linux
  o Edit metadata dialog: The Edit metadata dialog currently limits its
    max size based on the geometry of the smallest attached screen. Change
    that to use the geometry of the screen on which it will be shown.
  o HTMLZ Output: Fix
* Thu Sep 26 2013 Sascha Manns <saigkill@opensuse.org> - 1.5.0
- updated to 1.5
- New Features
  o Driver for Woxter Scriba
  o Bulk metadata edit: Allow setting the comments for all selected books
    and also allow cloning the covers. Cloning covers means that the cover
    of the first selected book will be set for all other selected books.
- Bug Fixes
  o Windows: Improved device ejection code. Eject individual drives before
    trying to eject the device. This fixes incomplete ejection with the
    Nook devices.
  o Catalogs: fix exclude tags rules not working in non-English locales
    when creating catalogs in EPUB/MOBI formats.
  o Kobo driver: Fix reading status being cleared when connecting to a
  o Kobo with older firmware and metadata management set to automatic.
  o Content server: Sort virtual libraries by name
  o DOCX Input: Convert tabs in the docx file into non-breaking spaces in
    the output document. Note that custom tab stops are not supported.
  o Conversion: Handle the style attribute on the  tag
  o Handle databases with invalid ratings link tables
  o DOCX Input: Handle DOCX files with missing referenced styles
  o Update amazon metadata download plugin for changes to the Amazon
    website
* Sat Sep 21 2013 Sascha Manns <saigkill@opensuse.org> - 1.4.0
- removed make linux_mount_helper from spec because it is removed from
  upstream with patch 7d54d25844efebfb3d6de2bb2b9af77dbf72d8b8
* Fri Sep 20 2013 Sascha Manns <saigkill@opensuse.org> 
- updated to 1.4
- New Features
  o Column icons: Allow the use of multiple icons with column icon rules.
  o Kobo driver: Add support for new cover handling in Kobo Aura with
    updated firmware
  o Driver for Icarus Essence
  o Show a warning when attempting to copy books between libraries that do
    not have the same set of custom columns.
  o EPUB/AZW3 Output: Use shorthand forms for margin, padding and border
    CSS properties, where possible
  o Allow colons in identifier values, needed for using URIs as
    identifiers
  o Comments editor: Allow treating arbitrary URLs as images
  o Show full path of library under mouse in status bar when
    switching/renaming/deleting libraries via the calibre library button.
  o DOCX Input: Add support for embedded EMF images that are just wrappers
    around an actual raster image.
- Bug Fixes
  o Conversion: Fix font subsetting not working for large fonts with more
    than 4000 glyphs, such as CJK fonts
  o HTML Input: Fix a regression that broke processing of HTML files that
    contain meta tags with dc: namespaced attribute values.
  o Fix switching to an empty virtual library not blanking the book
    details panel
  o Keep position when deleting tags in the tag editor
  o Book details panel: Render custom comments fields the same as the
    builtin comments field. In particular this fixes problems caused by
    wide text and images in custom comments fields.
  o Metadata jackets: Do not error out when using a custom template with
    some custom fields that are not present.
  o AZW3 Output: Dont choke on invalid (undecodable) links in the input
    document
  o Cover grid: Respect the double click on library view tweak
  o Fix covers set by drag and drop or pasting in the edit metadata dialog
    showing compression artifacts due to aggressive jpeg compression
  o Conversion: Fix a bug that could cause incorrect border values to be
    used when cascading, shorthand border CSS is present.
  o Fix regression in 1.3 that caused the book list to not track the
    current book when using Next/Previous in the edit metadata dialog.
* Thu Sep 19 2013 toddrme2178@gmail.com
- Clean up spec file formatting
- Make sure BuildRequires and Requires are consistent
- Remove python-sip(api) = 9.2 dependency, it cannot be satisfied
  anymore and is apparently no longer necessary anyway
- Remove redundant imagesdir
- Add version for icon provides/obsoletes to avoid self-conflict
* Sat Sep 14 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.3
- New Features
  o When doing searches or switching between virtual libraries in the main
    book list, preserve the current book. The currently selected book will
    remain visible if it is present in the results of the search or the
    selected virtual library.
  o Drivers for Oppo Find 5 and PocketBook Mini 515
- Bug Fixes
  o DOCX Input: Handle numbered paragraphs where the numbering is
    specified in the paragraph style, instead of on the paragraph
    directly. Also support the use of arbitrary, styled text for bullets.
  o DOCX Input: Fix a single line break at the end of a paragraph not
    being rendered as a blank line.
  o DOCX Input: Fix extra top/bottom margins around headings when the
    heading style in word does not specify any top/bottom margins.
  o DOCX Input: Handle images in footnotes and endnotes.
  o ODT Input: Only treat the first image as a cover if it is of suitable
    size, instead of any image in the document.
  o Book polishing: Do not leave behind the old comments when updating
    metadata if the comments have been deleted in calibre.
  o PDF Output: Fix non-breaking space characters incorrectly rendered in
    PDF outline.
  o Content server: Fix error in opds feed after using virtual libraries
    in the main server.
  o Do not scroll the book list horizontally after editing metadata.
  o New database backend: Handle databases that contain multiple
    tags/series/publishers/etc. that differ only in case.
* Sat Sep  7 2013 Sascha Manns <saigkill@opensuse.org>
- reintegrated upstream icons into the main package. Because the other
  iconset doesn't work correctly.
* Fri Sep  6 2013 Sascha Manns <saigkill@opensuse.org>
- update to 1.2
- New Features
  o Conversion: Add support for the CSS3 rem font size unit
  o MTP devices, such as Android tablets/phones: Allow ignoring any folder
    on the device, not just top level folders. For newly connected
    devices, also scan /Android/data/com.amazon.kindle for books by
    default (newer versions of the Kindle app place downloaded files
    there).
  o Speed up sorting when the book list is showing a restricted set of
    books, such as when the results of a search are displayed or a virtual
    library is used.
  o Edit metadata dialog: Add an undo option for the Trim cover button.
- Bug fixes
  o Amazon metadata download: Update to handle website changes at
    amazon.com
  o PDF Output: Workaround a bug in the library calibre uses to render
  o HTML to PDF that caused text in some documents that used small-caps
    fonts to not render correctly.
  o Kobo driver: When a sideloaded kepub is added from a Kobo device to
    the calibre library, it is added as an epub, but the file copied is
    corrupt.
  o Fix changing the user interface language in the welcome wizard causing
    some parts of the interface to remain in the old language until
    calibre is restarted.
  o Fix regression in 1.0 that broke setting author names with the |
    character in them.
  o Content server: When running from inside the main calibre program, do
    not restrict the books shown based on the current virtual library in
    the main program. If you wish to restrict the books shown in the
    content server, use Preferences->Sharing over the net.
  o Output dates in the local timezone instead of UTC when generating CSV
    catalogs
  o Library maintenance: When doing a check library instead of dumping the
    database to SQL and restoring it, run a VACUUM. This works around
    various bugs in the dump and restore capabilities of apsw.
  o Edit metadata dialog: Fix adding an image to an empty comments block
    not working
  o Conversion: Fix font declarations with invalid font-family values
    causing conversion to abort when subsetting is enabled.
  o MOBI Output: Fix conversion of some super/sub scripts failling if they
    are the first or last element in a paragraph.
  o New database backend: Various improvements to make the backend more
    robust against databases with invalid/corrupt data in them.
* Tue Sep  3 2013 jw@suse.com
- suggestion from bnc#831983#c12 added:
  Requires: python-sip(api) = 9.2
* Mon Sep  2 2013 jw@suse.com
- added Requires: python-apsw (and as BuildRequires too, to catch the errors early)
* Sat Aug 31 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.1
- New Features
  o Rewrite the HTML metadata parser to make it faster and more robust.
  o Book list: When sorting on a currently unsorted column, use the last
    applied sort for that column, instead of always sorting in ascending
    order.
  o PocketBook driver: Scan for books files in the entire device not just
    in the 'books' folder
-Bug Fixes
  o Fix a regression in 1.0 that could cause the dates in custom date-type
    columns to change in some timezones when using the edit metadata
    dialog to make unrelated changes.
  o When replacing formats in a book with a very long title+authors on
    windows, calibre could leave behind the old format file, because the
    filename shortening algorithm has changed. Handle that case.
  o Fix content server giving an error if you return to the top level page
    after using the virtual libraries.
  o Fix calibredb not updating the running calibre instance properly in
    1.0
  o Fix a regression in 1.0 that broke splitting of multiple valued field
    like tags into many items during a rename.
  o Fix a regression in 1.0 that caused an error when trying to set values
    for tags with the same item repeated, with different case.
  o Fix a regression that broke downloading news when output format is set
    to PDF
  o Creating a catalog with an already existing catalog in the library
    would cause a temporary duplicate entry in the book list. Also fix the
    author sort for catalogs generated in the AZW3 format not being
    correct.
  o EPUB metadata: When changing the title in an EPUB 2.0 file that has
    multiple titles, remove the extra titles.
  o Fix a regression in 1.0 that caused Search and Replace in the bulk
    metadata edit dialog to be much slower than before
  o Fix a regression in 1.0 that caused incorrect sorting and searching on
    some composite columns (columns built from other columns).
  o Fix a regression in 1.0 that prevented the moving of libraries inside
    calibre
  o Virtual Library tabs: If the user activates a hidden tab via the
  o Virtual Library button, change the name of the All Books tab to
    reflect the hidden virtual library.
  o Ignore text records in the database that are damaged, instead of
    erroring out. Lets the rest of the data be used.
  o Fix regression that broke calibredb catalog when sorting on the id
    field.
  o HTML Input: Handle malformed OPF files when converting.
  o Ensure that the Formats custom column (if present) is updated when a
    new format is created as a result of a conversion.
  o Fix a bug in 1.0 that broke the Check Library function on computers
    with non-English locales.
  o Content server: Fix blank username causing error on startup.
  o Fix sorting of book list by multi-valued fields like tags not correct
    in the new backend.
* Sat Aug 24 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 1.0
- New Features
  o A new 'cover grid' view of the books in your calibre library
  o A new, faster database backend
  o For a summary of the major changes in calibre between 0.9 and 1.0, see
    http://calibre-ebook.com/new-in/ten
  o RTF Input: Add option to ignore WMF images iinstead of replacing them
    with a placeholder.
  o Content server: Make virtual libraries available as searches from the
    start page. They work just like saved searches, clicking on a virtual
    library will show you all the books in that virtual library.
- Bug Fixes
  o Remove extra, useless 'language' entry in metadata download
    configuration dialog
  o Kobo driver: Display device collections even if the driver is
    configured to not manage shelves on the device.
  o Fix typo in calibre.desktop file on linux
  o Edit metadata dialog: Disable OK button while results are being
    downloaded.
  o In OS X 10.8 Apple stopped redirecting stdout/stderr to Console.app
    for applications launched by launch services. Re-enable the
    redirection, useful for debugging.
  o Fix virtual library tabs not being updated when using VL button
* Sat Aug 17 2013 Sascha Manns <saigkill@opensuse.org>
- Updated to 0.9.44
- New Features
  o Add an option to display all virtual libraries as tabs above the book
    list.
  o An improved cover trimming algorithm to automatically detect and
    remove borders and extra space from the edge of cover images. To try
    it use the 'Trim' button in the edit metadata dialog. This can
    sometimes remove too much so if you dont like the result, just click
    cancel. You can make the algorithm more or less aggressive via
    Preferences->Tweaks
  o Allow customizing the comic metadata reader plugin via
    Preferences->Plugins to read the series index from either the volume
    or the issue number of the comic.
  o Linux MTP driver: Add ids for some newer devices.
  o Add a trim cover option to the bulk metadata edit dialog
  o Make the book information dialog user resizable, with a splitter
    between the cover and the info panel. Also change the background of
    the cover panel for books that have been marked using the Temp marker
    plugin.
  o Driver for Samsung Galaxy Young Android phone
-Bug Fixes
  o PDF Output: Do not abort conversion if the document being converted
  has an HTML cover (found in some broken EPUB files).
  o RTF Input: When converting RTF files with no codepage, use the input
  encoding setting as the codepage.
* Fri Aug  9 2013 Sascha Manns <saigkill@opensuse.org>
- Updated to 0.9.43
- New Features
  o TXT Input: Allow using various markdown extensions for more features
    when converting markdown formatted txt files. See
    http://pythonhosted.org/Markdown/extensions/index.html for details.
  o Sending by email: Allow sending by email to an arbitrary combination
    of email address. Access it via the 'Select recipients' menu entry in
    the Email To menu.
  o A new 'Sort By' action for the right click menu. This allows sorting
    on all columns in the library, not just the visible columns. To use it
    go to Preferences->Toolbars and add it to 'The context menu for books
    in the calibre library'
  o Allow adding images into the comments field, by clicking on the insert
    link button in the comments editor in the edit metadata dialog.
  o Allow skipping the confirm bulk reconvert dialog
  o EPUB Input: If the EPUB file identifies an actual cover image in
    addition to the titlepage html file, use the cover image instead of
    rendering the titlepage. This is faster and has the advantage that an
  o EPUB to EPUB conversion preserves internal cover structure.
  o Get Books: Improve searching by removing punctuation from
    title/authors before matching.
- Bug Fixes
  o Conversion: Fix empty inline tags that are the second child of a
    paragraph causing text change location.
  o Fix book count in tooltip of choose library button not updating
  o Kobo driver: When deleting shelves that have been synced, the Activity
    entry for the shelf was not being deleted. This left a tile for the
    shelf on the home screen of the Glo and AuraHD.
  o Comments editor: The Insert Link button has no effect until the user
    clicks inside the comments box, therefore disable it until it is
    ready, to prevent confusion.
  o Get Books: Update various Polish store plugins
* Fri Aug  2 2013 Sascha Manns <saigkill@opensuse.org>
- Updated to 0.9.42
- New Features
  o When downloading metadata from Amazon, convert the amazon categories
    into tags. You can turn this off by going to Preferences->Metadata
    download and configuring the Amazon source.
  o Kobo driver: Add an option to modify the styling in books being sent
    to the device, based on a template on the device.
  o Get Books: Add support for two more Polish ebook stores: cdp.pl and
    ebooki.allegro.pl
  o calibredb: Add a new clone command to create clones of libraries with
    the same custom columns, virtual libraries, etc. as the current
    library.
- Bug Fixes
  o MOBI metadata: Do not fail to set metadata in MOBI files if they have
    EXTH fields with NULL pointers to a cover or thumbnail.
  o Fix editing of book metadata failing when its timestamp is out of
    range for the system.
  o Fix renaming a user category to the same name it already has erases
    the user category.
  o Fix drag 'n drop of cover onto conversion dialog not working
  o Device drivers: Explicitly fsync() all files when writing to devices,
    to reduce chances of file corruption if the device is disconnected
    while jobs are running
  o Fix calibre not appearing in Ubuntu's 'Open with..' menu
* Fri Jul 19 2013 Sascha Manns <saigkill@opensuse.org>
- New Features
  o EPUB Output: Add an option to insert an inline Table of Contents into
    the main text.
  o Driver for LG Android phone
  o When matching books in the library against the device manually,
    pre-fill the search field with the book title
- Bug Fixes
  o PDF Input: Fix a regression that caused some images to be flipped when
    converting PDF files that use image rotation operators.
  o Fix regression that caused incorrect font size in dropcaps generated
    by the DOCX input plugin
  o Get Books: Fix searching for title and author returning some extra
    matches, if the title starts with an article like the, a or an.
  o PDF Output: Fix extra blank page being inserted at the start of the
    chapter when converting some epub files from feedbooks
  o PDF Output: Workaround bug in WebKit's getBoundingClientRect() method
    that could cause links to occasionally point to incorrect locations.
  o E-book viewer: Fix a bug that could cause the reported position to be
    incorrect immediately after opening a previously opened book. This
    also fixes the Back button not working if a link is clicked on the
    page immediately after opening the book.
  o Fix memory card not being detected for Elonex 621 on Windows
  o Fix regression in last release that broke auto-conversion of ebooks
    when sending to device/sending by email.
  o Get Books: Update amazon plugins for website changes
  o Allow using non-ascii chars in email passwords.
* Sat Jul  6 2013 Sascha Manns <saigkill@opensuse.org>
- New Features
  o Book polishing: Add option to embed all referenced fonts when
    polishing books using the 'Polish Books' tool.
  o DOCX Input: Add support for clickable (hyperlinked) images
  o DOCX Input: Insert page breaks at the start of every new section
  o Drivers for Trekstor Pyrus Maxi and PocketBook Surfpad 2
  o DOCX Input: Add support for horizontal rules created by typing three
    hyphens and pressing enter.
- Bug fixes
  o Fix detection of SD Card in some PRS-T2N devices
  o MOBI Input: Fix a regression that broke parsing of MOBI files with
    malformed markup that also used entities for apostrophes.
  o Get Books: Update Woblink store plugin
  o Metadata download dialog: Prevent the buttons from being re-ordered
  when the Next button is clicked.
  o PDF Output: Fix links that point to URLs with query parameters being
    mangled by the conversion process.
  o DOCX Input: Fix links pointing to locations in the same document that
    contain multiple, redundant bookmarks not working.
  o EPUB/AZW3 Output: Fix splitting on page-break-after with plain text
    immediately following the split point causing the text to be added
    before rather than after the split point.
  o DOCX Input: handle bookmarks defined at the paragraph level
  o DOCX Input: Handle hyperlinks created as fields
* Wed Jun 26 2013 Sascha Manns <saigkill@opensuse.org>
- New Features
  o DOCX Input: Support for Table of Contents created using the Word Table
    of Contents tool. calibre now first looks for such a Table of Contents
    and only if one is not found does it generate a ToC from headings.
  o DOCX Input: Add support for images used as bullets in lists
  o DOCX Input: If a large image that looks like a cover is present at the
    start of the document, remove it and use it as the cover of the output
    ebook. This can be turned off under the DOCX Input section of the
    conversion dialog.
  o When dropping files onto the Book Details panel, ask for confirmation
    before adding the files to the book. The confirmation can be disabled.
  o News download: Add the 'downloaded from' link at the bottom of every
    article when using a touchscreen output profile (like the Tablet
    profile).
  o E-book viewer: Change the bookmark button to always popup a menu when
    clicked, makes accessing existing bookmarks easier.
  o After a bulk metadata download, focus the review button on the popup
    notification, instead of the OK button.-
- Bug Fixes
  o DOCX Input: Hide text that has been marked as not being visible in the
    web view in Word.
  o DOCX Input: When converting docx files with large numbers of unnamed
    images, do not crash on windows.
  o DOCX Input: Add support for the Word setting 'No space between
    paragraphs with the same style'.
  o MOBI Output: Fix rendering of SVG images that embed large raster
    images in 64bit calibre installs.
  o HTMLZ Output: Fix handling of images with URL unsafe filenames.
  o Fix unable to change the case of a previously used search because of
    the search history.
  o When searching allow use of uppercase location names, such as AUTHOR
    instead of author, automatically lowercasing them.
  o DOCX metadata: When reading covers from DOCX files use the first image
    as specified in the actual markup instead of just the first image in
    the container.
  o Kobo driver: Fix a regression when deleting empty shelves on Kobo
    devices with older firmware.
  o Do not show builtin plugins in the get new plugins dialog If a builtin
    plugin with the same name as a third party plugin exists, then the
  o builtin plagin was displayed in the get new plugins dialog as
    installed (happened with the new DOCX Input plugin).
  o Apple driver: When in synchronous mode (direct to iBooks), disable PDF
    transfers, as we can't update metadata in iTunes. Not sure when this
    started, but as of iTunes 11.0.4 it's broken.
  o Get Books: Fix error when using internal browser on some systems
* Fri May 10 2013 Sascha Manns <saigkill@opensuse.org>
- New Features
  o Kobo driver: Add support for showing 'Archived' books on the device.
  o Also up the supported firmware version to 2.5.3.
  o Driver for Blackberry 9790
  o Add a tweak to turn off the highlighting of the book count when using
    a virtual library (Preferences->Tweaks)
  o Add a button to clear the viewer search history in the viewer
  o Preferences, under Miscellaneous
  o Add keyboard shortcuts to clear the virtual Library and the additional
    restriction (Ctrl+Esc and Alt+Esc). Also use Shift+Esc to bring
    keyboard focus back tot he book list. Can be changed under
    Preferences->Keyboard
  o Docx metadata: Read the language of the file, if present
- New bugfixes
  o Kobo driver: Fix unable to read SD card on OS X/Linux
  o Content server: Fix unable to download ORIGINAL_* formats
  o Fix regression that broke searching for terms containing a quote mark
  o Fix regression that broke conversion of txt files when no input
    encoding is specified
  o When changing to a virtual library, refresh the Book Details panel.
  o Fix regression that caused searching for user categories to break.
  o Fix error when downloading only covers and reviewing downloaded
    metadata.
  o MOBI metadata: Strip XML unsafe unicode codepoints when reading
    metadata from MOBI files.
  o Txt Input: Use the gbk encoding for txt files with detected encoding
    of gb2312.
  o When pressing Ctrl+Home/End preserve the horizontal scroll position in
    the book list
* Fri Apr 26 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.28
- New features
  o Virtual Libraries: Easily partition your large calibre library into
    smaller 'virtual' libraries
  o Book details panel: Allow copying of links in the book details panel
    by right clicking on them.
  o Kobo driver: Add support for the new Kobo Aura HD and firmware version
    2.5.0
  o Metadata download: When showing downloaded covers, allow right
    clicking on a cover to view a full size version.
  o Driver for Easy player cyber book e touch and Droid 4
  o Edit ToC: Allow the size of the panels in the location view to be
    adjusted
  o When copying to a library by path, make it more efficient to choose
    between moving and copying
  o When checking if a zip/rar file is a comic or contains a single ebook
    to be auto-extracted, ignore thumbs.db files inside the archive
- Bug fixes
  o EPUB Input: Fix handling of EPUB files that contain images with
    non-ascii filenames.
  o Device driver: Detect Laser EB720 with newer firmware.
  o Fix bug in Danish translation causing books with language Ingush being
    incorrectly translated as Engelsk
  o PDF Output: Fix hyperlinks not working when converting an EPUB whose
    individual files have names with URL unsafe characters.
  o Book polishing: Fix inserting cover into an epub with no cover could
    lead to incorrect guide entry if the opf is not at the root of the
    epub.
  o ZIP Output: Fix links containing backslashes on windows
  o Fix polishing of AZW3 files not working on OS X.
  o Polishing books: Fix polishing erroring out if the book being polished
    has no cover
  o RTF Input: Add partial support for hyperlinks to web resources.
  o Fix book details panel showing incorrect info after deleting books
    from a connected device
* Tue Apr  2 2013 Sascha Manns <saigkill@opensuse.org>
- New features
  o Automatic adding: When checking for duplicates is enabled, use the
    same duplicates found dialog as is used during manual adding.
  o ToC Editor: Allow searching to find a location quickly when browsing
    through the book to select a location for a ToC item
  o ToC Editor: Add a button to quickly flatten the entire table of
    contents
  o Conversion: When converting a single book to EPUB or AZW3, add an
    option to automatically launch the Table of Contents editor after the
    conversion completes. Found under the Table of Contents section of the
    conversion dialog.
- Bug fixes
  o calibredb: Nicer error messages when user provides invalid input
  o News download: Always use the .jpg extension for jpeg images as
    apparently Moon+ Reader cannot handle .jpeg
  o Fix Book Details popup keyboard navigation doesn't work on a Mac
  o Fix a regression that caused the case of the book files to not be
    changed when changing the case of the title/author on case insensitive
    filesystems
* Sat Mar 23 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.24
- New Features:
  o ToC Editor: Allow auto-generation of Table of Contents entries from
    headings and/or links in the book
  o EPUB/MOBI Catalogs: Allow saving used settings as presets which can be
    loaded easily later.
  o Indicate which columns are custom columns when selecting columns in
    the Preferences
  o News download: Add an option recipe authors can set to have calibre
    automatically reduce the size of downloaded images by lowering their
    quality
- Bug Fixes:
  o News download: Fix a regression in 0.9.23 that prevented
    oldest_article from working with some RSS feeds.
  o Conversion: handle the :before and :after pseudo CSS selectors
    correctly
  o AZW3 Output: Handle the case of the  reference to a ToC containing an
    anchor correctly.
  o BiBTeX catalogs: Fix ISBN not being output and the library_name field
    causing catalog generation to fail
  o Conversion: Add support for CSS stylesheets that wrap their rules
    inside a @media rule.
  o Cover browser: Fix scrolling not working for books after the 32678'th
    book in a large library.
  o Linux: Update bundled libmtp version
  o Clear the Book details panel when the current search returns no
    matches.
  o Fix a regression that broke creation of advanced column coloring rules
  o Amazon metadata download: Handle cover images loaded via javascript on
    the amazon.de site
  o Nicer error message when exporting a generated csv catalog to a file
    open in another program on windows.
  o Fix ebook-convert -h showing ANSI escape codes in the windows command
    prompt
* Mon Mar  4 2013 Sascha Manns <saigkill@opensuse.org>
- fixed bnc#805421 (hope it)
- commented out the removing of the font folder
* Sun Mar  3 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.21
- New Features:
  o Content server: When browsing random books, add a button to the book
    page to get another random book.
  o Kobo driver: Update cover uploading for Kobo firmware 2.3.1 and later.
  o Add a tweak under Preferences->Tweaks to try to recoginze numbers
    inside text fields like title when sorting. This will cause Book 2 to
    sort before Book 100. However, it is slower and can have trouble when
    the text starts with a number. If you want numeric sorting you should
    use the series field for it.
  o Get Books: Update the Amazon and Foyles store plugins
  o Add a setting in Preferences->Tweaks that controls the sorting of the
  o Copy to Library and Quick Switch menus. If the number of libraries is
    larger than the set value, the lists are sorted alphabetically instead
    of by frequency of use.
  o Driver for Iriver Story EB12.
  o Edit metadata dialog: When pasting in copied text into the comments
    area, you can now choose to discard all formatting. Right click on the
    comments area and select 'Paste and Match style' which will paste the
    copied text as plain text formatted in the current style.
  o Book polishing: Make updating cover a separate option, so you can now
    update metadata without updating the cover.
  o Linux build: Install zsh completion for the calibre command line
    utilities
- Bug Fixes:
  o Conversion: Do not rescale fonts sizes/adjust line heights for text
    based drop caps defined using a separate  tag (drop caps defined using
    :first-letter were already handled correctly)
  o E-book viewer: Fix clicking links going to slightly incorrect
    locations in some books.
  o E-book viewer: Fix rendering of pages for right-to-left text in paged
    mode is reversed.
  o E-book viewer: Fix bug in rendering prefixed svg tags in the cover
    pages of some EPUB files.
  o PDF Output: Do not error out when embedding a font that calibre cannot
    subset, instead embed the full font
  o Book polishing: Fix bug that caused the ORIGINAL_EPUB format to be
    replaced by the EPUB format when polishing a book with both
    ORIGINA_EPUB and EPUB
  o Polishing books: Ignore unsupported fonts instead of erroring out on
    them.
  o Make bulk edit of custom columns respect the "apply changes" checkbox
    even if the value to set has not changed
* Sat Feb 23 2013 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.20
- New Features:
  o Book polishing: Add an option to smarten punctuation in the book when
    polishing
  o Book polishing: Add an option to delete all saved settings to the load
    saved settings button
  o Book polishing: Remember the last used settings
  o Book polishing: Add a checkbox to enable/disable the detailed
    polishing report
  o Add a separate tweak in Preferences-Tweaks for saving backups of files
    when polishing. That way you can have calibre save backups while
    converting EPUB->EPUB and not while polishing, if you so desire.
  o Content server: Allow clicking on the book cover to download it.
  o Useful on small screen devices where clicking the Get button may be
    difficult
  o Driver for Energy Systems C4 Touch.
- Bug fixes:
  o E-book viewer: Fix a bug that could cause the back button in the
  o viewer to skip a location
    When tweaking/polishing an azw3 file that does not have an identified
    content ToC, do not auto-generate one.
  o Book polishing: Use the actual cover image dimensions when creating
    the svg wrapper for the cover image.
  o Book polishing: Do not error out on epub files containing an
    iTunesMetadata.plist file.
  o Book polishing: Fix trying to polish more than 5 books at a time not
    working
  o Content server: Add workaround for bug in latest release of Google
  o Chrome that causes it to not work with book lists containing some
    utf-8 characters
  o E-book viewer: When viewing EPUB files, do not parse html as xhtml
    even if it has svg tags embedded. This allows malformed XHTML files to
    still be viewed.
  o Bulk metadata edit Search & recplace: Update the sample values when
    changing the type of identifier to search on
  o Fix recipes with the / character in their names not useable from the
    command line
  o News download: Fix regression that broke downloading of images in gif
    format
  o EPUB/AZW3 Output: When splitting the output html on page breaks,
    handle page-break-after rules correctly, the pre split point html
    should contain the full element
  o Fix stdout/stderr redirection temp files not being deleted when
    restarting calibre from within calibre on windows
  o E-book viewer: When viewing epub files that have their cover marked as
    non-linear, show the cover at the start of the book instead of the
    end.
  o EPUB Input: Fix handling of cover references with fragments in the
    urls
* Wed Feb 13 2013 Sascha Manns <saigkill@opensuse.org>
- added Prefer: calibre-icons-branding-upstream
* Thu Jan 31 2013 Sascha Manns <saigkill@opensuse.org>
- removed hardcoded *-icons-branding-upstream. Used instead
  * -icons-branding
* Tue Jan 29 2013 Sascha Manns <saigkill@opensuse.org>
- Hardcoded Requires: 0.9.16 for icons subpackage
* Tue Jan 29 2013 Sascha Manns <saigkill@opensuse.org>
- added BuildArch: noarch to calibre-icons-branding-upstream
- defined _bversion right before accessing the subpackage
* Mon Jan 28 2013 Sascha Manns <saigkill@opensuse.org>
- Set calibre-icons-branding-upstream Version to 1.0 (like the faenza
  one)
* Mon Jan 28 2013 Sascha Manns <saigkill@opensuse.org>
- added Requires: calibre-icons-branding
* Mon Jan 28 2013 Sascha Manns <saigkill@opensuse.org>
- splitted the GUI-Icons into calibre-icons-branding-upstream. Also
  created a calibre-icons-branding-faenza.
  So Users can choose their prefered icons.
* Fri Jan 25 2013 Sascha Manns <saigkill@opensuse.org>
- Updated to 0.9.16
- New Features:
  o News download: Add support for logging in to sites that require
    javascript for their logins.
  o News download: Do not convert all downloaded images to JPG format.
  o This fixes the problem of PNG images with transparent backgrounds
    being rendered with black backgrounds
  o CHM Input: Support hierarchical table of contents. Do not generate an
    inline table of contents when a metadata table of contents is present.
  o Also correctly decode the text in the table of contents
  o Get Books: Add the beam-ebooks.de store
  o Make custom yes/no columns using icons put text values under the
    icons.
  o Driver for LG E400 and SayCoolA710
  o Speed up device connection when there are lots of books on the device
    by not generating cover thumbnails unless they are actually needed.
  o Have the metadata download dialog remember its last used size.
- Bug fixes:
  o Fix deleting a custom column that was used in a column coloring rule
    makes the column coloring preferences panel unusable
  o Store caches outside the config directory for non-portable calibre
    installs
  o PDF Output: Dont crash if the user has a font on his system that is
    missing the OS/2 table
  o Conversion: Do not error out because of an error in user supplied
    search replace rules.
  o Conversion: Replace all non-ascii characters in CSS class names, as
    they cause problems with some broken EPUB renderers.
  o Do not choke when reading metadata from MOBI files with incorrectly
    encoded metadata fields
  o Conversion: Preserve ToC entries that point nowhere instead of causing
    them to point to a non-existent file
  o E-book viewer: Allow entries in the Table of Contents that do not
    point anywhere, instead of just ignoring them.
  o Content server: Fix the 'Previous' link in the mobile version of the
    content server webpage skipping an entry
* Tue Jan 22 2013 tchvatal@suse.com
- I am unable to trigger bugs with sip 4.14 so removing the
  restriction. Also just triggering rebuild in obs should fix the
  issue I think.
* Fri Jan 18 2013 tchvatal@suse.com
- Add dependency over python-cssselect wrt bnc#788151.
* Tue Jan 15 2013 toms@opensuse.org
- Added Requires and BuildRequires for poppler-tools as suggested
  by Ciaran. Thanks!
* Mon Jan 14 2013 jw@suse.com
- Symlinked /usr/share/fonts/truetype, so that fonts are found.
  Workaround for https://bugs.launchpad.net/ubuntu/+source/calibre/+bug/1037168
- added Requires: python-sip <= 4.13.2, because 4.14 triggers another bug:
  http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=616372
* Thu Jan 10 2013 toddrme2178@gmail.com
- Add  buildrequires which is not a hard dependency
- Cleaned up spec file formatting with spec-cleaner
- Fixed shebangs on python files (rpmlint warning)
- Provide obsoleted calibre07 (rpmlint warning)
- Make sure optflags are set properly
* Fri Jan  4 2013 Sascha Manns <saigkill@opensuse.org>
- update to 0.9.13
- New Features:
  o Complete rewrite of the PDF Output engine, to support links and fix
    various bugs
  o Show disabled device plugins in Preferences->Ignored Devices
  o Get Books: Fix Smashwords, Google books and B&N stores. Add Nook UK
    store
  o Allow series numbers lower than -100 for custom series columns.
  o Add mass storage driver for rockhip based android smart phones
  o Add a clear ratings button to the edit metadata dialog
- Bug Fixes:
  o PDF Output: Fix custom page sizes not working on OS X
  o PDF Output: Fix embedding of many fonts not supported (note that
    embedding of OpenType fonts with Postscript outlines is still not
    supported on windows, though it is supported on other operating
    systems)
  o PDF Output: Fix crashes converting some books to PDF on OS X
  o HTML Input: Handle entities inside href attributes when following the
    links in an HTML file.
  o Content server: Fix custom icons not used for sub categories
  o Force use of non-unicode constants in compiled templates. Fixes a
    problem with regular expression character classes and probably other
    things.
  o Kobo driver: Do not error out if there are invalid dates in the device
    database
  o Content server: Fix for non-unicode hostnames when using mDNS
* Tue Dec 25 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.9.11
- New Features:
  o Merry Christmas and Happy Holidays to all ☺
    When connecting to MTP devices such as the Kindle Fire HD or the Nook
    HD, speed up the process by ignoring some folders.
  o Allow changing the icons for categories in the Tag Browser. Right
    click on a category and choose 'Change category icon'.
  o Allow setting the color of all columns with a single rule in
  o Preferences->Look & Feel->Column Coloring
  o MOBI: When reading metadata from mobi files, put the contents of the
  o ASIN field into an identifier named mobi-asin. Note that this value is
    not used when downloading metadata as it is not possible to know which
    (country specific) amazon website the ASIN comes from.
- Bug Fixes:
  o Windows build: Fix a regression in 0.9.9 that caused calibre to not
    start on some windows system that were missing the VC.90 dlls (some
    older XP systems)
  o Kobo driver: Workaround for invalid shelves created by bugs in the
    Kobo server
  o Metadata download: Fix cover downloading from non-US amazon sites
    broken by a website change.
* Fri Dec 14 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.9.10
- New Features:
  o Drivers for Nextbook Premium 8 se, HTC Desire X and Emerson EM 543
- Bug Fixes:
  o Fix rich text delegate not working with Qt compiled in debug mode.
  o When deleting all books in the library, blank the book details panel
  o Conversion: Fix malformed values in the bgcolor attribute causing
    conversion to abort
  o Conversion: Fix heuristics applying incorrect style in some
    circumstances
  o Possible fix for 64bit calibre not starting up on some Windows systems
* Sun Dec  9 2012 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.9
- New Features:
  o Content server: Make the identifiers in each books metadata
    clickable
- Bug Fixes:
  o EPUB Input: Fix an infinite loop while trying to recover a damaged
    EPUB file.
  o KF8 Input: Fix handling of links in files that link to the obsolete
    tags instead of tags with an id attribute.
  o Conversion: Fix a bug in removal of invalid entries from the spine,
    where not all invalid entries were removed, causing conversion to
    fail.
  o KF8 Input: Ignore invalid flow references in the KF8 document instead
    of erroring out on them.
  o Fix command line output on linux systems with incorrect LANG/LC_TYPE
    env vars.
  o KF8 Input: Fix page breaks specified using the data-AmznPageBreak
    attribute being ignored by calibre.
  o PDF Output: Fix custom size field not accepting fractional numbers as
    sizes
  o Get Books: Update libre.de and publio for website changes
  o Wireless driver: Increase timeout interval, and when allocating a
    random port try 9090 first
* Fri Nov 30 2012 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.8
- New Features:
  o Add an option to show the cover size in the book details panel on the
    right. Option is in Preferences->Look & Feel->Book Details
  o Kobo driver: Add support for firmware 2.2. Also add an option to send
    series information to the device.
  o Catalogs: Allow using custom columns as the source for Genres when
    generating catalogs
  o When the user asks calibre to convert a book, show a small animation
    to make highlight that the convert job has been queued to run in the
    background
  o Add support for the notification center in OS X 10.8
  o calibredb: Add an option to specify the cover to use when adding books
    with calibredb add.
  o EPUB Input: Add support for EPUB files with broken central directory
    records *and* data descriptors
  o Comic metadata: Support reading metadata from cbr files. Also read the
  o comments and published date info from the metadata.
  o Speed up processing of RAR and CBR files by avoiding an extra file
    copy
  o Add driver for Nexus 10 on linux.
- Bug Fixes:
  o KF8 Input: Handle invalid KF8 files with links pointing to
    non-existent locations and incorrect values in the div table.
  o Viewer: Fix handling of empty self closing tags.
  o Fix use of {formats} in save to disk templates. Fix some formatter
    functions causing plugboards to not validate.
  o Fix calibre quitting when minimized to system tray and an update
    available message is shown and then closed.
  o Viewer: Fix vertical margin at the top of the first page of a chapter
    incorrect in a certain rare circumstance (first child of body being an
    empty paragraph).
  o E-book viewer: Fix bug that caused the default language for
    hyphenation to be ignored for books that do not specify a language
* Mon Nov 26 2012 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.7
- New Features:
  o Edit metadata dialog: Show the size of the current book cover in the
    edit metadata dialog.
  o Get Books: Allow easy searching by title and author in addition to any
    keyword, to prevent large numbers of spurious matches.
  o An option to automatically convert any added book to the current
    output format, found under Preferences->Adding books
  o E-book viewer: Allow viewing tables in a separate popup window by
    right clicking on the table and selecting 'View table'. Useful for
    reference books that have lots of large tables.
  o Catalogs: Add the current library name as an available field when
    generating catalogs in csv/xml format.
  o Enable colored text in the output from the command line tools on
    windows
  o E-book viewer: Add an option to hide the help message when entering
    full screen mode
  o E-book viewer: Add an option to always start the viewer in full screen
    mode
  o E-book viewer: Add many more controls to the context menu,
    particularly useful in full screen mode
  o E-book viewer: Allow easy searching of the selected word or phrase in
    google via the context menu
  o Add a new type of FileType plugin, postimport, that runs after a book
    has been added to the database.
  o Get Books: Remove Gandalf store, add Publio store. Update the Legimi
    store plugin for website changes
- Bug Fixes:
  o Conversion: Correctly handle values of left and right for the
    deprecated align attribute of images, mapping them to the CSS float
    property instead of to text-align.
  o MOBI Output: When generating joint MOBI6/KF8 files do not set
    incorrect display CSS values for tables in the KF8 part
  o Connect to iTunes: Ignore AAC audio files.
  o E-book viewer: Fix restoring from fullscreen not respecting maximized
    window state
  o Fix rows in the device books view sometimes being too high
  o Catalogs: Fixed a problem occurring when merging comments with a
    custom field whose type is a list.
  o Linux binary: Use exec in the wrapper shell scripts that are used to
    set env vars and launch calibre utilities.
  o E-book viewer: Fix blank pages after every page when viewing some
    comic files in paged mode
  o E-book viewer: When printing, respect the specified page range.
  o Font subsetting: Parse the GSUB table for glyph substitution rules and
    do not remove any glyphs that could act as substitutes. Keep zero
    length glyphs like the glyphs for non printable characters when
    subsetting TrueType outlines.
  o Smarten punctuation: Fix self closing script tags causing smarten
    punctuation to fail
* Tue Nov  6 2012 cedric.devillers@gmail.com
- Add conditionals for bnc#788151 fix. This should only be done for opensuse 12.2
  Earlier versions are not affected and the later should have it fixed by proper packaging of dependencies.
* Mon Nov  5 2012 cedric.devillers@gmail.com
- Add cssselect as private code to fix bnc#788151
* Mon Nov  5 2012 Sascha Manns <saigkill@opensuse.org>
- updated to 0.9.5
- New Features:
  o Font embedding: Add support for the CSS 3 Fonts module, which means
    you can embed font families that have more that the usual four faces,
    with the full set of font-stretch and font-weight variations. Of
    course, whether the fonts actually show up on a reader will depend on
    the readers' support for CSS 3.
  o Sharing by email: Allow specifying an 'alias' or friendly name by
    which to identify each email recipient.
  o Embedding fonts: Allow adding ttf/otf font files to calibre directly
    to be used for embedding. That way the fonts do not have to be
    installed system wide. You can add a font to calibre via the 'Add
    fonts' button in the font chooser dialog for embedding fonts.
  o E-book viewer: Add the ability to rotate images to the popup image
    viewer.
  o Generate cover: Speedup searching the system for a font that can
    render special characters
  o A new custom font scanner to locate all fonts on the system. Faster
    and less crash prone that fontconfig/freetype
  o Font family chooser: Show the faces available for a family when
    clicking on the family
- Bug fixes
  o Get Books: Fix eHarlequin and Kobo stores.
  o Kobo driver: Fix a bug that could cause the on device book matching to
    fail in certain circumstances.
  o Kobo driver: When using a SD card do not delete shelves that contain
    on books on the card (there might be books in the shelf in the main
    memory).
  o Workaround for bug in the windows API CreateHardLink function that
    breaks using calibre libraries on some networked filesystems.
  o Template editor: Use dummy metadata instead of blank/unknown values
  o Windows: abort setting of title/author if any of the books' files are
    in use. Results in less surprising behavior than before, when the
    title/author would be changed, but the on disk location would not.
* Sat Oct 27 2012 Sascha Manns <saigkill@opensuse.org>
- Updated to 0.9.4
- New Features:
  o Conversion: Add an option to embed a font family into the book.
  o When changing the title/author of a book, use hard links instead of
    copying the books' files, for a large speedup. Only works on
    filesystems that support hardlinks.
  o Linux installer: Resume interrupted downloads and verify the SHA-512
    signature of the downloaded file before installing it.
- Bug Fixes:
  o Windows: Check if any of the files of a book are in use before
    changing the title/author, this prevents the creation of duplicate
    files if one of the files is open in another program
  o Kobo driver: Fix the ondevice status for some books getting lost.
  o Catalogs: Fix regression that broke use of prefix rules.
  o Tag Browser: Fix sorting incorrect for accented letters
  o Make the bundled Liberation fonts available on all platforms for
    embedding
  o Use mimetype for fonts from the EPUB 3 specification
  o Get Books: Handle website change that broke the SONY Store plugin
  o Generate cover: If the default font cannot render characters in the
    metadata (for example for east asian languages) try to automatically
    find a font on the system that is capable of rendering the characters
  o Fix regression that broke certain types of CSS selectors.
  o Use font-weight:bold instead of font-weight:bolder for the  and  tags
    as ADE cant handle bolder when embedded fonts are used
* Tue Oct 23 2012 Sascha Manns <saigkill@opensuse.org>
- added: export LANG="en_US.UTF8" to %%%%build section cause of trouble
  since the regular build
* Sun Oct 21 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.9.3:
- New features:
  o Conversion: Add support for CSS 3 selectors by switching to the new
    cssselect module
  o Drivers for the WayteQ xBook and the Topwise Android tablet
  o Add an output profile for the Kindle PaperWhite
  o Kobo driver: Improve performance when a large number of shelves are
    created on the device.
  o Catalogs: Put catalog sections at top level of ToC for EPUB/AZW3
    catalogs.
  o Adding books: When duplicates are found, show the list of possible
    duplicates in calibre with title and author.
- Bug fixes:
  o KF8 Input: Fix conversion/viewing of KF8 files generated with the
    unreleased? kindlegen 2.7.
  o Kindle driver: Increase the size of the cover thumbnails sent by
    calibre to the device. This fixes the problem of cover thumbnails not
    showing up on the PaperWhite
  o MTP driver: Fix sorting on the title column of the device view.
  o Catalogs: Fix regression that caused authors and titles to be be
    incorrectly listed under symbols on OSX < 10.8.
  o Catalogs: Fix error when generating catalog in non English locale and
    the user has specified a prefix rule using a Yes/no column.
  o E-book viewer: Remove the reload entry from the context menu as it is
    not supported in paged mode.
* Sat Oct 13 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.9.2:
- New features:
  * Wireless driver: Speed up deleting of multiple books
  * E-book viewer: Add options to hide the scrollbar and show reading
    position in full screen mode.
  * News download: Add a field to allow recipe authors to tell calibre to
    remove duplicate articles that a re present in more than one section
    from the download.
  * Metadata download: Turn off the use of the published date for the
    earliest edition a book as the published date. The earliest edition
    was identified via worldcat.org, which has rather poor data, leading
    to the occasional incorrect result. If you want this feature back, you
    can turn it on again via Preferences->Metadata download.
- Bug fixes:
  * ODT Input: More workarounds for the image positioning markup produced
    by newer versions of LibreOffice.
  * Metadata download dialog: Fix selected cover being changed when covers
    are re-sorted after download completes
  * MTP driver: Ignore errors when getting the driveinfo.calibre file from
    the device and simply regenerate it
  * E-book viewer: Use the system locale settings to display the 24/12
    hour clock in full screen mode
  * Content Server: Make OPDS initial page respect the fields to display
    tweak
  * Fix regression that caused calibre to not use OPF files when adding
    books recursively from directories with multiple books per directory
  * KF8 Output: Fix handling of input documents that have URL unsafe
    characters in the file names of their images.
  * Fix enumeration type custom column not being merged.
* Sat Sep 29 2012 Sascha Manns <saigkill@opensuse.org>
- update 0.9.0
- new features:
  o For a summary of the major changes in calibre between 0.8 and 0.9, see
    http://calibre-ebook.com/new-in/nine
- bug fixes:
  o KF8 Output: Fix handling of & < and > entities in the text. They were
    sometimes being incorrectly unescaped.
  o Calibre portable: Add a manifest to the portable installer exe to
    prevent the application compatibility wizard from warning about a
    possible failed installation on windows 7. Also fixes installer
    requiring admin privileges on some computers
  o EPUB metadata: Fix book producer not being set when updating EPUB
    metadata
  o EPUB metadata: Fix incorrect namespace on the role attribute of  tags
    when updating the metadata in EPUB
  o Get Books: Fix incorrect price retrieval from ebooks.com.
  o MTP windows driver: Fix main memory and storage card sometimes swapped
  o PDF Output: On windows, remove any embedded fonts before generating
    the PDF as on windows, Qt generates image based PDFs when embedded
    fonts are present.
  o MTP windows driver: Do not try to connect to unsuitable devices such
    as the iPhone.
  o KF8 Input: Handle files that use non ascii paths/anchor names in the
    guide entries.
* Tue Sep 25 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.8.70
- new features:
  o Support for connecting MTP (non disk based) devices via USB, such as
    the Nexus 7 and the Kindle Fire HD (Windows Vista and newer and Linux
    only)
  o Calibre Portable: Create a new installer that does not require
    manually unzipping the Calibre Portable folder. Instead just run the
    installer and point it to the location you want to install to.
  o Calibre Portable: Add support for multiple libraries created inside
    the 'Calibre Portable' folder.
  o In the main book list when editing a blank published date, use a
    default value of Jan 2000 so that changing the date it easier
  o Template language: Add function approximate_formats() to get list of
    formats saved in the db for a book as opposed to the formats that
    actually exist on disk
  o Template language: Add a couple of new functions to get the path to
    individual book formats and the calibre library as a whole
  o Drivers for HTC Flyer and Trekstor 4ink
- bug fixes:
  o Conversion: Do not error out when tags have unparseable color
    attributes.
  o AZW3 Output: Do not error out if the input document contains embedded
    fonts of less than 1040 bytes.
  o Catalogs: Fix AZW3 output not properly indexed
  o Get Books: Remove Beam Books due to lack of response to issues with
    the store.
  o Windows: Ignore drives A: and B: when scanning for the drives
    belonging to a device
  o Kindle driver: Fix generation of apnx files for newer kindle firmware.
  o News download: If the output format is set to azw3, generate
    periodicals in mobi format as amazon does not support azw3
    periodicals.
* Mon Sep 10 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.8.68
- New features
  o Drivers for the Nokia N9, Viewsonic 7e, Prestigio PER3274B and Coby
    Kyros 7035
  o Add a tutorial on creating catalogs to the User Manual and a link to
    it in the create catalogs dialog
  o Wireless device connections: Add an option to force calibre to listen
    on a particular IP address. Access it by customizing the plugin in
    Preferences->Plugins
  o Android driver: Add an extra customization option to configure the
    directory to which ebooks are sent on the storage cards.
  o Add an option under Preferences->Look & Feel->Book Details to hide the
    cover in the book details panel
  o The Calibre Companion Android app that allows wireless connection of
    Android device to calibre is out of beta. See
    https://play.google.com/store/apps/details?id=com.multipie.calibreandroid
- Bug fixes
  o Fix sorting by author not working in the device view in calibre when
    connected to iTunes
  o Fix using the 'configure this device' menu action not validating
    settings
  o Device drivers: Ignore corrupted entries in metadata.calibre, instead
    of raising an error
  o PDF Output: Do not error out when generating an outline which points
    to pages that have been removed.
  o PDF Output: Fix incorrect page numbers being generated in the outline
    when converting some books
  o PDF Output: Reduce memory consumption when writing out the PDF file,
    by using a stream
  o EPUB metadata: When there are multiple  tags use the one with the
    earliest date as the published date
* Sat Sep  1 2012 Sascha Manns <saigkill@opensuse.org>
- update to 0.8.67
- New Features
  o PDF Output: Generate a PDF Outline based on the Table of Contents of
    the input document
  o Conversion: Add an option under Structure Detection to set the 'Start
    reading at' metadata with an XPath expression.
  o Speed up changing the title and author of files with books larger than
    3MB by avoiding an unnecessary extra copy.
  o Wireless device driver: Make detecting and connecting to devices
    easier on networks where mdns is disabled
  o PDF Output: Allow choosing the default font family and size when
    generating PDF files (under PDF Options) in the conversion dialog
  o Metadata dialog: Comments editor: Allow specifying the name of a link
    when using the insert link button.
  o Remove the unmaintained pdfmanipulate command line utility. There are
    many other tools that provide similar functionality, for example,
    pdftk and podofo
- Bug Fixes
  o Catalogs: Fix regression that broke sorting of non series title
    before series titles
  o PDF Output: Do not create duplicate embedded fonts in the PDF for
    every individual HTML file in the input document
  o Fix regression that broke DnD of files having a # character in their
    names to the book details panel
  o PDF Output: Allow generating PDF files with more than 512 pages on
    windows.
  o Fix minor bug in handling of the completion popups when using the
    next/previous buttons in the edit metadata dialog
* Sat Aug 25 2012 Sascha.Manns@open-slx.de
- update to 0.8.66
- New Features:
  o Ebook viewer: Support the display of mathematics in e-books. Supports both
    embedded TeX and MathML
  o Drivers for SONY PRS-T2, Freelander PD10 and Coolreader Tablet
  o Wireless device connections: Use a streamed mode for improved
    networking performance leading to much less time spent sending
    metadata to/from the device. Also make it easier to specify a fixed
    port directly in the dialog used to start the connection.
  o Get books: Add ebooksgratuitis.com
- Bug Fixes:
  o PDF Output: Handle input epub documents with filenames starting with a
    dot. Also do not hang if there is an unhandled error.
  o Get Books: Update B&N plugin to handle changes to the B&N website
  o Content server: Fix regression that caused the port being advertised
    via BonJour to be incorrect if the user changed the port for the
    server.
* Sat Aug 18 2012 Sascha.Manns@open-slx.de
- update to 0.8.65
- New Features:
  o A new wireless device driver. This allows connecting wirelessly to a
    device running a 'smart' calibre client
  o MOBI Output: Add an option to control the type of MOBI file produced,
    to the MOBI Output conversion options. You can now generate an old
  o MOBI6, a new KF8 or a joint MOBI6/KF8 file. By default, MOBI6 files
  are generated. This replaces the previous use of a tweak.
  o E-book viewer: Make paged mode the default. You can go back to the old
    flow mode by clicking the button with the yellow scroll in the top
    right corner of the viewer.
  o Driver for COBY kYROS MID7042 and Samsung Galaxy Ace S5839i
- Bug Fixes:
  o Update version of poppler bundled with calibre to fix reading covers
    from some PDF files
  o Get Books: Fix clicking of results from Diesel books when there is
    only a single result not working
  o Improve detection of system language on first run of calibre
    When finding the next series index and the last series index is a
    fractional number, use the next largest integer, instead of just
    adding 1
  o Fix exception when saving a search/replace when no saved
    search/replace had been opened previously in the bulk search/replace
    dialog
  o Fix restore database not restoring entries for the original_* formats
  o Fix first run wizard not allowing empty email sending settings
  o Do not error out when setting the cover for a book that has no folders
    in the library.
  o Conversion pipeline: Ignore unparseable values in the color attribute
    of font tags, instead of erroring out on them.
  o Catalogs: Fix regression that broke creation of catalogs while a
    device is connected
  o Fix --with-library=/whatever not working for calibredb list
* Sun Aug 12 2012 Sascha.Manns@open-slx.de
- update to 0.8.64
- New Features:
  o E-book viewer: Allow viewing images in the book in a separate pop-up
    window by right clicking on the image. Useful if you want to keep some
    image, like a map to the side while reading the book.
  o Catalogs: Allow generation of catalogs in AZW3 format. Also add more
    powerful configuration options to exclude books and set prefixes. See
    http://www.mobileread.com/forums/showthread.php?t=187298 for details.
  o Generate a PDF version of the User Manual
- Bug Fixes:
  o News download: Fix broken handling of nesting for HTML 5 tags when
    parsing with BeautifulSoup
  o EPUB: Handle files in the EPUB that have semi-colons in their file
    names. This means in particular using URL escaping when creating the
    NCX as ADE cannot handle unescaped semi-colons in the NCX.
  o Conversion pipeline: Ignore unparseable CSS instead of erroring out on
    it.
  o When setting up a column coloring rule based on the languages column,
    allow entry of localized language names instead of only ISO codes
  o Catalogs: Generate cover for mobi/azw3 catalogs
  o Update the last modified column record of a book, whenever a format is
    added to the book.
  o E-book viewer: Fix line scrolling stops at breaks option not working
    in paged mode
  o MOBI Output: Fix ToC at start option having no effect when converting
    some input documents that have an out-of-spine ToC.
  o Catalog Generation: When generating EPUB/MOBI catalogs add more
    flexible rules for excluding books. Also add rules to customize the
    prefix characters used.
  o Make setting published date using metadata search/replace more robust.
  o Tag Browser: Flatten the display of sub-groups when sort by is not set
    to 'name'.
  o Fix isbn:false not matching if other identifiers are attached to the
    book.
* Sat Aug  4 2012 Sascha.Manns@open-slx.de
- update to 0.8.63
- New Features:
  o E-book viewer: Allow quick saving and loading of viewer settings as
    'themes'.
  o Ebook-viewer: Add a restore defaults button to the viewer preferences
    dialog
  o E-book viewer: Add simple settings for text and background colors
  o Add an entry to save to disk when right clicking a format in the book
    details panel
  o ODT metadata: Read first image as the metadata cover from ODT files.
    Also allow ODT authors to set custom properties for extended metadata.
  o E-book viewer and PDF Output: Resize images that are longer than the
    page to fit onto a single page
- Bug fixes:
  o KF8 Output: Fix bug where some calibre generated KF8 files would cause
    the Amazon KF8 viewer on the Touch to go to into an infinite loop when
    using the next page function
  o News download: Add support for  tags that link to SVG images.
  o Update podofo to 0.9.1 in all binary builds, to fix corruption of some
  o PDFs when updating metadata.
  o Catalog generation: Handle authors whose last name is a number.
  o KF8 Input: Handle html entities in the NCX toc entries correctly
  o Fix a calibre crash that affected some windows installs
  o MOBI Output: Normalize unicode strings before writing to file, to
    workaround lack of support for non-normal unicode in Amazon's MOBI
    renderer.
  o EPUB Input: Handle files that have duplicate entries in the spine
  o Fix regression in Kobo driver that caused the on device column to not
    be updated after deleting books
* Sun Jul  8 2012 Sascha.Manns@open-slx.de
- update to 0.8.59
- New Features
  o Drivers for Samsung SGH-T989 and Sony Ericsson Sola
  o Conversion pipeline: When removing the first image, also remove the
    html file the image is found in, if that file has no other content.
  o Allows this option to be used to remove covers from EPUB files without
    leaving behind a blank page.
  o Content server: Add a navigation panel at the bottom of each page.
  o calibredb: Add a backup_metadata command to manually run the backup to
    opf from the command line
  o User defined driver: Add option to swap main memory and card a.
  o Add new option to the series_index_auto_increment tweak, no_change,
    that causes calibre not to change the series_index when the series is
    changed
- Bug Fixes
  o PDF Output: Resize large images so that they do not get off at the
    right edge of the page.
  o On linux ensure that WM_CLASS for the main calibre GUI is set to
    'calibre-gui' to match the name of the calibre-gui.desktop file. This
    is apparently required by the GNOME 3 shell.
  o Update ICU in all builds to version 49.1
  o Tag browser: Fix regression that broke drag and drop between user
    categories in the tag browser
    When copying to library and deleting after copy, do not place deleted
    files in recycle bin, as this is redundant and slow (they have already
    been copied into another library)
  o Fix yes/no fields with value of No not showing up in the book details
    panel
  o Catalogs: Better sorting for non English languages
  o Get Books: Fix Foyles UK, Weightless books, ebooks.com and ozon.ru
  o CHM Input: Fix handling of chm files that split their html into
    multiple sub-directories.
* Sat Jun 30 2012 Sascha.Manns@open-slx.de
- update to 0.8.58
- New Features
  o Add some texture to calibre generated covers
  o Drivers for Sogo SS-4370, HTC G2 and Lenovo ThinkPad Tablet
  o Add search to the Manage tags/series/etc. dialogs
  o News download: Add support for images embedded in the HTML
  o calibre -s now waits for calibre to shutdown
- Bug Fixes
  o Workaround for iTunes breaking scripting with version 10.6.3 on OS X.
  o EPUB Input: When there are multiple elements of the same type in the
  o OPF guide, use the first rather than the last element.
  o Windows: Disable the new UI style if the color depth of the desktop is
    less than 32 bits per pixel
  o ISBNDB metadata plugin: Return results even though they have no
    comments
  o More robust handling of EINTR during IPC
  o Metadata download: Support for amazon's new results page markup
  o EPUB Output: Fix a bug that could cause corrupted output when doing an
    EPUB/OEB to EPUB conversion if the input EPUB had multiple files with
    the same name
  o KF8 Output: Fix a couple of bugs that could lead to generation of
    invalid KF8 files.
* Fri Jun 22 2012 Sascha.Manns@open-slx.de
- update 0.8.57
- New Features
  o PDF Output: Full pagination support. No more cutoff bottom line.
  o calibredb add now prints out the ids of added books
  o Kobo Vox driver: Add support for new Google Play firmware
  o Driver for Prestigio PMP5097PRO
  o Add option to disable tooltips in the book list under
    Preferences->Look & Feel
  o When customizing builtin recipes download the latest version of the
    recipe to customize instead of using the possibly out of date bundled
    version
- Bug fixes
  o PDF Output: Use the cover from the input document when no cover is
    specified during a conversion
  o E-book Viewer: Printing now has proper pagination with top and bottom
    margins no lines partially cut-off at the bottom and full style
    retention
  o KF8 Input: Handle files with incorrectly encoded guide type entries.
  o E-book viewer: Disable hyphenation on windows xp as Qt WebKit barfs on
    soft hyphens on windows XP
  o Handle OS X systems with invalid palette colors.
  o Tag Browser: Fix regression that broke partitioning of hierarchical
    categories.
  o LRF Output: Handle negative page margins
  o Template language: Fix arithmetic functions to tolerate the value
    'None' as returned by raw_field()
  o Fix custom title sort set in the edit metadata dialog getting reset by
    the conversion dialog
* Sat Jun 16 2012 Sascha.Manns@open-slx.de
- update to 0.8.56
- New Features
  o Make the new calibre style default on Windows and OS X.
  o Get Books: Add the new SONY Reader store
  o Read metadata from .docx (Microsoft Word) files
  o Allow customizing the behavior of the searching for similar books by
    right clicking the book. You can now tell calibre to search different
    columns than the traditional author/series/publisher/tags/etc. in
    Preferences->Searching
  o Add option to restore alternating row colors to the Tag Browser under
    Preferences->Look & Feel->Tag Browser
  o Update to Qt 4.8.2 on windows compiled with link time code generation
    for a small performance boost
- Bug Fixes
  o Get Books: Update plugins to handle website changes at ebooks.com,
    project gutenberg, and virtualo
  o AZW3 Output: Fix TOC at start option not working
  o AZW3 Output: Close self closing script/style/title/head tags
    explicitly as they cause problems in webkit based renderers like the
    Kindle Fire and calibre's viewers.
  o Fix the current_library_name() template function not updating after a
    library switch
  o AZW3 Output: Handle the case of a link pointing to the last line of
    text in the document.
  o Fix regression in 0.8.55 that broke highlighting of items matching a
    search in the Tag Browser
  o News download: Handle query only relative URLs
* Tue Jun 12 2012 coolo@suse.com
- update to 0.8.55
- New Features
  Add a new 'Calibre style' interface look that is more modern than the
  default look. You can select it via Preferences->Look & Feel->User
  interface style.
  New, subtler look for the Tag Browser
  Driver for Trekstor Pyrus and Pantech Android Tablet
  Closes tickets: 1008946 , 1007929
  Conversion pipeline: Handle guide elements with incorrectly cased hrefs.
  Also handle guide elements of type coverimagestandard and thumbimagestandard.
  Allow user to customize trekstor plugin to send books into sub directories.
  Closes tickets: 1007646
  EPUB Input: Add support for EPUB files that use the IDPF font obfuscation algorithm.
  Closes tickets: 1008810
  Save single format to disk: Only show the format available in the selected books.
  Closes tickets: 1007287
  Bug Fixes
  MOBI Output: When using the insert metadata at start of book option,
  do not use a table to layout the metadata, as the Kindle Fire crashes
  when rendering the table.
  Closes tickets: 1002119
* Sun May 27 2012 Sascha.Manns@open-slx.de
- updated to 0.8.53
- New Features
  o Kindle Touch/4 driver: Upload cover thumbnails when sending books to
    device by USB to workaround Amazon bug of not displaying covers for
    sync-enabled books
  o Support for updating metadata in FB2 files
  o Set a different background color when choosing formats to not delete
    as opposed to choosing format to delete.
  o E-book viewer: Add an option to prevent the up and down arrow keys
    from scrolling past page breaks
  o Get Books: Remove ebookshoppe.com at the website's request
- Bug Fixes
  o PDF Input: Support image rotation commands in PDF files. Fixes the
    long standing problem of some images being flipped when converting
    from PDF in calibre.
  o Fix a regression in 0.8.51 that caused conversion to HTMLZ to not have
    any CSS
  o Get Books: Fix website change at kobo.com causing prices not to be
    found
  o Edit the time in the 24 hour clock when calibre's interface language
    is set to German.
  o MOBI Output: When generating joint KF8/MOBI6 .mobi files set the text
    length field in the MOBI 6 header correctly.
  o ODT Input: More workarounds for LibreOffice 3.5's habit of inserting
    pointless margin:100%% directives everywhere.
  o Fix regression that broke smarten punctuation when quotes were next to
    html tags.
  o Fix published date from ozon.ru wrong in some timezones
  o Catalogs: Handle the use of custom columns with non-ascii names
    correctly
  o Conversion pipeline: Remove the attempt to detect and autocorrect if
    text will go off the left edge of the page, as it was a rather crude
    heuristic. Also do not remove fake margins if the book uses negative
    text indents on the margined elements.
  o KF8 Output: Set offsets to tags in the skeleton the same way kindlegen
    does. Also linearize non linear ToCs to ensure section to section
    jumping works.
  o Conversion pipeline: Use correct default value of 'inherit' for
    font-family and font-size when normalizing the shorthand font
    property.
  o When running python scripts via calibre-debug ensure that user plugins
    are loaded
* Tue May 22 2012 idonmez@suse.com
- Add calibre-poppler-0.20.patch to fix build with poppler 0.20
* Mon May 21 2012 mail@philipp-wagner.com
- Require python-cssutils 0.9.9+
  (see http://www.mobileread.com/forums/showthread.php?t=177318)
* Sun May 20 2012 Sascha.Manns@open-slx.de
- updated to 0.8.52
- New Features
  - EPUB Input: When setting the cover for a book that identifies its
    cover image, but not the html wrapper around the cover, try to detect
    and remove that wrapper automatically.
  - When deleting books of a specific format, show the number of books
    with each format available
  - Linux install: No longer create MAN pages as all utilities have more
    comprehensive command line --help anyway
  - Add a tweak Preferences->Tweaks to control the default choice of
    format for the Tweak Book feature
  - Conversion: Allow setting negative page margins. A negative page
    margin means that calibre will not specify any page margin in the
    output document (for formats that support this)
- Bug Fixes
  - Tweak book: Fix handling of covers when tweaking KF8 books
  - KF8 Output: Handle input documents with out of sequence ToC entries.
  - Note that currently section jumping in the KF8 output produced by
    calibre for such files does not work.
  - Edit metadata dialog: Fix the edit values button for custom tag-like
    columns showing a unneeded warning about changed values
  - EPUB Output: Be a little more conservative when removing  tags. Only
    remove them if they have actual forms inside.
  - EPUB Input: Correctly update the Cover entry in the ToC even when the
    entry has a fragment reference.
  - Update ImagMagick DLLs in all calibre binary builds to fix security
    vulnerabilities in ImageMagick
  - Advanced search dialog: Fix equals and regex matching not being
    applied for custom column searches.
  - RTF Input: Handle old RTF files that have commands without braces.
  - Get Books: Diesel, fix results not showing when only a single match is
    found
  - Get Books: Fix DRM status indicators for Kobo and Diesel stores. Fix
    smashwords not returning results.
  - Fix regression in 0.8.51 that broke viewing of LIT and some EPUB files
* Sun May 13 2012 Sascha.Manns@open-slx.de
- updated to 0.8.48
- New Features
  - When switching libraries preserve the position and selected books if
    you switch back to a previously opened library.
  - Conversion pipeline: Filter out the useless font-face rules inserted
    by Microsoft Word for every font on the system
  - Driver for Motorola XT875 and Pandigital SuperNova
  - Add a colour swatch the the dialog for creating column coloring rules,
    to ease selection of colors
  - EPUB Output: Consolidate internal CSS generated by calibre into
    external stylesheets for ease of editing the EPUB
  - List EPUB and MOBI at the top of the dropdown list fo formats to
    convert to, as they are the most common choices
- Bug Fixes
  - E-book viewer: Improve performance when switching between normal and
    fullscreen views.
  - Edit metadata dialog: When running download metadata do not insert
    duplicate tags into the list of tags
  - KF8 Input: Do not error out if the file has a few invalidly encoded
    bytes.
  - Fix download of news in AZW3 format not working
  - Pocketbook driver: Update for new PB 611 firmware.
  - ebook-convert: Error out if the user prvides extra command line args
    instead of silently ignoring them
  - EPUB Output: Do not self close any container tags to prevent artifacts
    when EPUBs are viewed using buggy browser based viewers.
  - Fix regression in 0.8.50 that broke the conversion of HTML files that
    contained non-ascii font-face declarations, typically produced by
    Microsoft Word
* Sat Apr 28 2012 Sascha.Manns@open-slx.de
- update to 0.8.48
- Features
  * Experimental support for generating Amazon's new KF8 format MOBI files
  * Upgrade to using cssutils 0.9.9 for CSS parsing. Improved speed and
    robustness.
  * Show cover size in a tooltip in the conversion dialog
  * Driver for Nook Simple Touch with Glow Light
- Bugfixes
  * Heuristics: When italicizing words do not operate on words not in
    between HTML tags.
  * Fix (I hope) the bulk metadata download process crashing for some
    people on OS X when clicking the Yes button to apply the updates.
  * Fix tooltip not being updated in the book details panel when pasting
    in a new cover
  * Cover Browser: Wrap the title on space only, not in between words.
  * Edit metadata dialog: If a permission denied error occurs when
    clicking the next or prev buttons, stay on the current book.
  * Fix heuristics not removing unnecessary hyphens from the end of lines.
* Sat Apr 21 2012 Sascha.Manns@open-slx.de
- update to 0.8.48
- New Features
  * Conversion: The search and replace feature has been completely
    revamped.
  * Support for the new '.azw3' files that Amazon recently started
    generating. calibre will now detect them as ebooks. It can also
    view/convert them, if they are DRM free.
  * Drivers for Samsung Galaxy ACE GT-S5830L and HTC One X
- Bug Fixes
  * Get Books: Support the new website design of Barnes & Noble
  * T1 driver: Fix books sent to SD card sometimes resulting problems when
    deleted.
  * Do not allow author names to be set to blank via the Manage authors
    function. Blank authors are now automatically set to 'Unknown'
  * MOBI Output: Handle background color specified on  and  in addition to
    tags.
  * MOBI Output: Fix underline style applied to parent element not getting
    inherited by  children.
* Fri Apr  6 2012 Sascha.Manns@open-slx.de
- added Patch calibre-no-update.diff for disabling Autoupdate Searcher
* Fri Apr  6 2012 Sascha.Manns@open-slx.de
- update to 4.8.46
- New Features:
  * Auto adding: When automatically adding files from a folder,
    automatically convert the files to the current output format after
    adding. This can be turned off via Preferences->Adding
    Books->Automatic Adding.
  * E-book viewer: When reading a MOBI file that is actually a KF8 book,
    show the format as being KF8
  * Content server: Workaround for android stock browser not support HTTP
    AUTH.
  * Edit metadata dialog: Change the remove unused series button to a
  * clear series button (as the remove unused series function is now
    automatic)
  * Driver for PocketBook 622.
- Bug Fixes:
  * Run metadata downloads in a separate process to workaround memory
    leaks in third party plugins. Also removes the need to break up bulk
    metadata downloads into 100 book batches.
  * Make tag browser filtering work when capital letters are entered.
  * EPUB metadata: Ignore urn:isbn: prefix from ISBN declaration when
    reading metadata
  * Get books: Fix feedbooks store not showing all available formats
  * KF8 Input: When the KF8 book has no metadata ToC, try to extract the
    ToC from the HTML instead.
  * Fix regression that broke access to Preferences via the Preferences
    item in the calibre menu on OS X
  * Fix bug that ignored metadata specified on the command line when using
    calibredb add
* Sat Mar 31 2012 Sascha.Manns@open-slx.de
- update to 0.8.45
* Mon Mar 12 2012 Sascha.Manns@open-slx.de
- update to 0.8.42
- New Features
  - Support for reading Amazon's new KF8 format
  - Add a tweak to Preferences->Tweaks to control the font size used in
    the book details panel
  - Allow specifying a list of file types to exclude when automatically
    adding files from a folder
  - Show ratings in the book details panel as stars. Also allow the user
    to change the alignment of the ratings column in the main books list.
    No longer display the stars in blue, instead their color can be
    customized via the column coloring rules, like any other column
    When setting metadata in EPUB ensure that the  tag has its name
    attribute first. Needed for the Nook.
  - Drivers for Novo 7, LG G2x and Zenithink T-280
  - Update linux binaries to Qt 4.8.0
- Bug Fixes
  - Fix some rar files causing crashes on OS X (updated libunrar.dylib in
    the OS X build)
  - MOBI Output: Ignore the Table of Contents pointed to by the guide, if
    it contains no links
  - ODT Input: Ignore margin declaration in ODT styles if more specific
    margin-* declarations are present
  - Conversion pipeline: Fix @import rules in CSS stylesheets that have
    comments on their first few lines being ignored.
  - EPUB Input: When extracting the contents of epub files on windows, do
    not error out if one or more of the components in the epub file have
    filepaths containing characters that are invalid for the windows
    filesystem, instead, just replace those characters, since those
    entries are likely to be errors in the zip container anyway.
  - Textile output: Fix issue with blockquotes and sentences getting
    removed.
  - MOBI Output: When using the prefer author sort conversion option,
    handle multiple authors better.
  - Fix regression in 0.8.41 that broke direct connection to iDevices in
    windows
  - Fix the download bulk metadata completed popup causing a crash if the
    Esc key is pressed.
  - Fix rating values doubled in CSV/XML catalogs
  - EPUB Input: Remove non markup documents from the spine automatically,
    instead of erroring out
    When formatting ratings in templates, etc., do not have an unnecessary
    .0
  - Calibre portable: Do not allow calibre portable to run if it is placed
    in a location whose path is too long. Also hide the library location
    setup in the welcome wizard when running the portable build.
  - Fix regression in 0.8.41 that broke calibre if the TMP or TEMP
    environment variable is set to the root of a drive.
  - Fix display of ratings type custom fields in the content server
* Sun Mar  4 2012 Sascha.Manns@open-slx.de
- update to 0.8.41
- New Features
  * Driver for Sony Experia Play 4G Closes tickets: 938831 [External link]
  * News download system: Allow use of __future__ in recipes, and do
  not change line numbers of code in the recipe when compiling it
  * Use the My Documents folder as the default location for the
  Calibre Library folder on first start in windows Closes tickets: 934840 [External link]
  * Add a tweak to Preferences->Tweaks to control the order in which
  categories appear in the Tag Browser
  * Tag Browser: Add an entry to the right click menu to quickly
  delete tags Closes tickets: 934509 [External link]
  * Amazon metadata download: Try to scrape series information from
  the amazon details page. Note that currently very few books have
  series info available. Often the page for hardcover will have series,
  but the Kindle edition will not. In such cases calibre may or may not
  find the series, depending on which page it ends up using.
  * Content server: Add favicon to OPDS feeds. Closes tickets: 934731 [External link]
- Bug Fixes
  * RTF Input: Fix some WMF images embedded in RTF files being
  distorted on conversion. Closes tickets: 934167 [External link]
  * Fix long standing bug preventing calibre from working on east
  asian windows installs when the user name in windows has non-ascii
  characters Closes tickets: 937389 [External link]
  * Get Books: Fix Baen Webscription and O'Reilly stores. Fix price
  detection for Google Books
  * MOBI Output: When the same anchor is present more than once in the
  input document, use the first occurrence rather than the last one. Closes tickets: 934031 [External link]
  * Use the 'default cover font' tweak when generating default
  masthead images as well Closes tickets: 939256 [External link]
  * Fix content server does not correctly display custom field of type
  'rating' Closes tickets: 938303 [External link]
  * Fix welcome wizard does not save send-from email info unless
  send-to field is filled Closes tickets: 937087 [External link]
  * When reading metadata from odt files, use initial-creator in
  preference to creator for setting the author field Closes tickets: 934564 [External link]
  * Fix conversion erroring out when the input document has very long
  and thin images Closes tickets: 935234 [External link]
- New news sources
  * La pausa caffe by faber1971
  * Various Polish news sources by fenuks
- Improved news sources
  * The Sun
  * Various Polish news sources
  * Mediapart
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Feb 11 2012 Sascha.Manns@open-slx.de
- New Features:
  * Auto-adding: Add an option to check for duplicates when auto adding.
  * Content server: Export a second record via mDNS that points to the
    full OPDS feed in addition to the one pointing to the Stanza feed. The
    new record is of type _calibre._tcp.
  * Allow specifying a set of categories that are not partitioned even if
    they contain a large number of items in the Tag Browser. Preference is
    available under Look & Feel->Tag Browser
  * Allow setting a URL prefix for the content server that run embedded in
    the calibre GUI as well.
  * Allow output of identifiers data in CSV/XML/BiBTeX catalogs
  * Driver for Motorola Droid XT910, Nokia E71 and HTC EVO 3D.
  * Cut down the time taken to launch worker processes by 40%%
  * You can now configure the calibre settings for the currently connected
    device by right clicking on the device icon in the toolbar, instead of
    having to go through Preferences->Plugins
- Bug Fixes:
  * Auto-adding: Do not add incomplete files when files are downloaded
    directly into the auto add folder.
  * When running multiple delete from device jobs, fix the device view
    sometimes marking the wrong books as being deleted, after the first
    delete job completes.
  * MOBI Input: Handle files that have spurious closing  and/or  tags in
    their markup.
  * RTF Input: Strip out false color specifications, as they cause
    artifacts when converted to MOBI
* Fri Feb  3 2012 Sascha.Manns@open-slx.de
- New Features:
  * Implement the ability to automatically add books to calibre from a
    specified folder.
  * Conversion: When automatically inserting page breaks, do not put a
    page break before a
    or
    tag if it is immediately preceded by another
    or
    tag.
  * Driver for EZReader T730 and Pint-of-View PlayTab Pro
- Bug Fixes:
  * Fix device entry not visible in menubar even when it has been added
    via Preferences->Toolbars.
  * Fix metadata plugboards not applied when auto sending news by email
  * Fix regression in 0.8.34 that broke recipes that used skip_ad_pages()
    but not get_browser().
  * Restore device support on FreeBSD, by using HAL
  * Get books: Show no more than 10 results from the Gandalf store
  * Content server: Fix metadata not being updated when sending for some
    MOBI files.
  * Heuristic processing: Fix the italicize common patterns algorithm
    breaking on some HTML markup.
  * When trying to find an ebook inside a zip file, do not fail if the zip
    file itself contains other zip files.
  * EPUB Input: Handle EPUBs with duplicate entries in the manifest.
  * MOBI Input: Handle files that have extra  tags sprinkled through out
    their markup.
* Fri Jan 20 2012 toms@opensuse.org
- Fixed generate-tarball.sh
- updated to 0.8.35 (20 Jan, 2011):
  * New Features
    . Decrease startup time for large libraries with at least one
    composite custom column by reading format info on demand
    . When automatically deleting news older than x days, from the
    calibre library, only delete the book if it both has the tag
    News and the author calibre. This prevents accidental deletion
    of books tagged with News by the user.
    . Driver for Infibeam Pi 2
    . Add a Tag Editor for tags like custom columns to the edit metadata dialog
  * Bug Fixes
    . E-book viewer: Fix regression in 0.8.35 that caused viewer to
    raise an error on books that did not define a language
    . Content server: Fix grouping for categories based on custom columns.
    . Closes tickets: 919011
    . Edit metadata dialog: When setting the series from a format or
    via metadata download, ensure that the series index is not automatically
    changed, when closing the dialog.
    . Closes tickets: 918751
    . When reading metadata from Topaz (azw1) files, handle non ascii metadata correctly.
    . Closes tickets: 917419
    . CHM Input: Do not choke on CHM files with non ascii internal
    filenames on windows.
    . Closes tickets: 917696
    . Fix reading metadata from CHM files with non-ascii titles
    . Fix HTML 5 parser choking on comments
    . If calibre is started from a directory that does not exist, automatically
    use the home directory as the working directory, instead of crashing
    . Fix iriver story HD Wi-Fi device and external SD card swapped
    . Closes tickets: 916364 [External link]
    . Content server: Fix ugly URLs for specific format download in the book
    details and permalink panels
    . When adding FB2 files do not set the date field from the metadata in the file
* Mon Dec 26 2011 Sascha.Manns@open-slx.de
- updated to 0.8.32
- New Features
  - Linux: When deleting books, send them to the recycle bin, instead
    of permanently deleting. This is the same behavior as on Windows and
    OS X.
  - Add a checkbox to allow users to disable the popup that asks if
    books should be auto-converted before sending to device
  - Drivers for Droid Razr, Samsung GT-I9003 and Bookeen Odyssey
    Closes tickets: 906356 [External link] , 906056 [External link] ,
    905862 [External link]
  - Allow passing multiple filenames as command line arguments to
    calibre, to add multiple books. Closes tickets: 907968 [External link]
- Bug Fixes
  - MOBI Output: Fix regression in 0.8.30 that caused the use of
    hidden heading elements for the TOC to generate links in the wrong
    place.
    Closes tickets: 907156 [External link]
  - EPUB Output: Ensure directories have the correct permissions bits
    set when unzipping an epub with unzip on Unix
  - Fix bottom most shortcuts in keyboard shortcuts for viewer not
    editable
  - EPUB Output: Fix handling of self closing <audio> tags.
    Closes tickets: 906521 [External link]
  - MOBI Input: Map invalid <o:p> tags to <p> tags before parsing, to
    handle broken nesting.
    Closes tickets: 905715 [External link]
  - Conversion pipeline: HTML5 parsing: Fix handling of XML
    namespaces. Fixes regression in 0.8.30 that caused some articles in
    some news downloads to appear blank when viewed in Adobe Digital
    Editions based readers
  - Get Books: Gandalf store, fix price and cover detection
  - EPUB Output: Fix the Flatten filenames option in EPUB Output
    causing duplicated manifest ids in rare cases.
    Closes tickets: 905692 [External link]
  - When adding books via ISBN, show the user the list of invalid
    ISBNs that will be ignored, if any, before starting the add operation.
    Closes tickets: 905690 [External link]
  - Fix unsmarten punctuation conversion option broken in 0.8.31.
    Closes tickets: 905596 [External link]
  - Fix broken evaluation of composite columns in save-to-disk
* Tue Nov 15 2011 toms@suse.de
- updated to 0.8.26
  * New Features
    . Tweak to control sorting of date type columns. You can choose
    to have them sorted only by displayed fields
    . Driver for the Trekstor 3.0
    . Performance improvements when evaluating templates, and in
    particular general program mode templates
  * Bug Fixes
    . ODT Input: When converting to EPUB improve handling of large
    images placed inside small frames, to prevent them from obscuring text.
    . Closes tickets: 860272, 884759
    . EPUB Input: Automatically strip entries of type application/text from
    the spine. Apparently there are EPUB production tools out there that create them.
    Closes tickets: 884792
    . Keep the startup splash screen visible until the GUI has fully completed initializing.
    Closes tickets: 885827
    . ODT Input: Fix handling of span tags containing only whitespace.
    Closes tickets: 887311
    . On windows when changing title or author via the main book list, handle the
    case of one of the books files being open in another program more gracefully.
    Closes tickets: 880585
    . When adding a format to an existing book record, ensure that no changes are
    made to the database until after the file operations have succeeded.
    . Fix bug that prevented configuring which fields to download metadata for when
    adding books by ISBN
    Closes tickets: 856076
    . Fix Japanese characters not being crrectly displayed on index pages in news
    downloads for the SONY T1
    Closes tickets: 888029
    . Get Books: Fix booleans in search expressions not working in non-English
    calibre versions
    Closes tickets: 887554
    . Fix a bug in the support for hours/minutes/seconds in datetime format strings
    Closes tickets: 887412
    . Treat an author_sort value of 'Unknown' the same way as unknown authors are
    treated in template processing
    . Detect SD card in Kobo Vox
    . Amazon metadata download: Workaround for change in Amazon website causing
    some books to have incorrect ratings downloaded
  New news sources
    Techtarget by Julio Map
* Mon Oct 24 2011 Sascha.Manns@open-slx.de
- updated to 0.8.23
- New Features:
  - Drivers for T-Mobile Move, new Pandigital Novel, New Onyx Boox and Freescale MX 515
  - SONY T1 driver: Support for periodicals and better timezone detection
  - Add a remove cover entry to the right click menu of the cover display in the right panel
- Bug Fixes:
  - Amazon metadata download: Fix for change in Amazon website that broke downloading metadata.
  - MOBI metadata: When reading titles from MOBI files only use the title in the PDB header if there is no long title in the EXTH header
  - Fix regression that broke use of complex custom columns in save to disk templates.
  - Fix regression that broke reading metadata from CHM files
  - Fix a bug that broke conversion of some zipped up HTML files with non ascii filenames on certain windows installs.
  - RTF Input: Fix bug in handling of paragraph separators.
  - Fix a regression that broke downloading certain periodicals for the Kindle.
  - Fix regression that broke updating of covers inside ebook files when saving to disk
  - Fix regression breaking editing the 'show in tag browser' checkbox in custom column setup editing
  - Fix typo that broke stopping selected jobs in 0.8.22
* Mon Oct 24 2011 Sascha.Manns@open-slx.de
- removed calibre-poppler.diff because it is already included in the Source
* Tue Oct  4 2011 Sascha.Manns@open-slx.de
- updated to 0.8.21
- New Features
  - A Tips and Tricks blog at http://blog.calibre-ebook.com to introduce
    less well known calibre features in a simple way
  - News download: Add list of articles in the downloaded issue to the
    comments metadata of the generated ebook. Makes it possible to
    search for a particular article in the calibre library.
  - Toolbar buttons: You can now also right click the buttons to bring
    the popup of extra actions, in addition to clicking the small arrow
    next to the button.
  - Amazon metadata download plugin: Add option to download metadata
    from amazon.es
  - Driver for Vizio and iRobot A9 Android tablets
  - When switching to/starting with a library with a corrupted database,
    offer the user the option of rebuilding the database instead of erroring out.
  - Template language: Add list_equals function
  - Add a special output profile for the PocketBook 900 as it does not
    resize images correctly by itself
- Bug fixes
  - A Tips and Tricks blog at http://blog.calibre-ebook.com to introduce
    less well known calibre features in a simple way
  - News download: Add list of articles in the downloaded issue to the
    comments metadata of the generated ebook. Makes it possible to search for
    a particular article in the calibre library.
  - Toolbar buttons: You can now also right click the buttons to bring the popup
    of extra actions, in addition to clicking the small arrow next to the button.
  - Amazon metadata download plugin: Add option to download metadata from
    amazon.es
  - Driver for Vizio and iRobot A9 Android tablets
  - When switching to/starting with a library with a corrupted database, offer
    the user the option of rebuilding the database instead of erroring out.
  - Template language: Add list_equals function
  - Add a special output profile for the PocketBook 900 as it does not resize
    images correctly by itself
* Mon Sep 26 2011 vuntz@opensuse.org
- Update calibre-poppler.diff after discussion with upstream
  poppler.
* Mon Sep 26 2011 coolo@suse.com
- add work around for new poppler version
* Mon Sep 26 2011 coolo@suse.com
- update to 0.8.20
  new features:
  - MOBI Output: Map a larger set of font names to
    sans-serif/monospace font in the MOBI file
  - Get Books: Allow searching on the DRM column in the results.
  - Manage tags/series/etc dialog: Add a was column to show the
    old value when changing values.
  - Template language: Add new functions to manipulate language codes
  bug fixes:
  - MOBI Output: Don't set cdetype when option to enable sharing
    instead of syncing is specified. This fixes the option.
  - Conversion pipeline: Fix crash caused by empty <style> elements.
  - Get Books: Fix Woblink store
  - MOBI Input: Correctly handle MOBI files that have been passed
    through a DRM removal tool that leaves the DRM fields in the header.
  - Fix typo preventing the updating of metadata in MOBI files
    serverd by the content server
  - Get Books: Handle non ASCII filenames for downloaded books
  - When generating the title sort string and stripping a leading
    article, strip leading punctuation that remains after removing the article
  - Fix downloading metadata in the Edit metadata dialog could
    result in off by one day published dates, in timezones behind GMT
  - Fix handing of title_sort and custom columns when creating a BiBTeX catalog.
  - TXT Markdown Input: Change handling of _ to work mid word.
  - Fix Check library reporting unknown files ad both missing an unknown
  - Search/Replace: Permit .* to match empty tag like columns.
* Tue Sep 20 2011 Sascha.Manns@open-slx.de
- updated to 0.8.19
- New Features:
  o Driver for Sony Ericsson Xperia Arc
  o MOBI Output: Add option in Preferences->Output Options->MOBI
    Output to enable the share via Facebook feature for calibre
    produced MOBI files. Note that enabling this disables the sync
    last read position across multiple devices feature.
  o Content server: Update metadata when sending MOBI as well as EPUB files
  o News download: Add an auto_cleanup_keep variable that allows
    recipe writers to tell the auto cleanup to never remove a specified element
  o Conversion: Remove paragraph spacing: If you set the indent size
    negative, calibre will now leave the indents specified in the input document
- Bug Fixes:
  o Fix regression in 0.8.18 that broke PDF Output
  o MOBI Output: Revert change in 0.8.18 that marked news downloads
    with a single section as blogs, as the Kindle does not auto archive them
  o PDF output on OSX now generates proper non image based documents
  o RTF Input: Fix handling of internal links and underlined text
  o Fix language sometimes not getting set when downloading metadata in the edit metadata dialog
  o Fix regression that broke killing of multiple jobs
  o Fix bug processing author names with initials when downloading metadata from ozon.ru.
  o Fix a memory leak in the Copy to library operation which also fixes the metadata.db being held open in the destination library
  o Keyboard shortcuts: Allow use of symbol keys like >,*,etc.
  o EPUB Output: When splitting be a little cleverer about discarding 'empty' pages
* Wed Aug 31 2011 Sascha.Manns@open-slx.de
- reported incorrect-fsf-adress to upstream with Bug lp#837986
  (https://bugs.launchpad.net/calibre/+bug/837986
* Wed Aug 31 2011 Sascha.Manns@open-slx.de
- updated to version 0.8.16
- New Features
  o News download: Add algorithms to automatically clean up downloaded
    HTML
  o Add an option to Preferences->Look and Feel->Cover Browser to show the
    cover browser full screen. When showing the cover browser in a
    separate window, you can make it fullscreen by pressing the F11 key.
  o Show the languages currently used at the top of the drop down list of
    languages
  o When automatically computing author sort from author's name, if the
    name contains certain words like Inc., Company, Team, etc. use the
    author name as the sort string directly. The list of such words can be
    controlled via Preferences->Tweaks.
  o Add a search for individual tweaks to Preferences->Tweaks
  o Drivers for a few new android phones
- Bug Fixes
  o Fix line unwrapping algorithms to account for some central
    European characters as well.
  o Switch to using more modern language names/translations from the
    iso-codes package
  o Allow cases insensitive entering of language names for convenience.
  o When adding a text indent to paragraphs as part of the remove spacing
    between paragraphs transformation, do not add an indent to paragraphs
    that are directly centered or right aligned.
  o Conversion pipeline: More robust handling of case insensitive tag and
    class css selectors
  o MOBI Output: Add support for the start attribute on
    tags
  o When adding books that have no language specified, do not
    automatically set the language to calibre's interface language.
  o Fix use of tag browser to search for languages when calibre is
    translated to a non English language
  o When downloading news, set the language field correctly
  o Fix languages field in the Edit metadata dialog too wide
  o Fix setting of languages that have commas in their names broken
  o FB2 Input: When convert FB2 files, read the cover from the FB2 file
    correctly.
* Sat Aug 20 2011 Sascha.Manns@open-slx.de
- updated to version 0.8.15
- New Features:
  o Add a 'languages' metadata field.
  o Get Books: Add XinXii store.
  o Metadata download plugin for ozon.ru, enabled only when user selects
    russian as their language in the welcome wizard.
  o Bambook driver: Allow direct transfer of PDF files to Bambook devices
  o Driver for Coby MID7015A and Asus EEE Note
  o Edit metadata dialog: The keyboard shortcut Ctrl+D can now be used to
    trigger a metadata download. Also show the row number of the book
    being edited in the titlebar
  o Add an option to not preserve the date when using the 'Copy to
    Library' function (found in Preferences->Adding books)
- Bug Fixs:
  o Linux binary: Use readlink -f rather than readlink -e in the launcher
    scripts so that they work with recent releases of busybox
  o When bulk downloading metadata for more than 100 books at a time,
    automatically split up the download into batches of 100.
  o When deleting books from the Kindle also delete 'sidecar' .apnx and
    .ph1 files as the kindle does not clean them up automatically
  o Fix a subtle bug in the device drivers that caused calibre to lose
    track of some books on the device if you used author_sort in the send
    to device template and your books have author sort values that differ
    only in case.
  o Fix scene break character pattern not saved in conversion preferences
  o Keyboard shortcuts: Fix a bug triggered by some third party plugins
    that made the keyboard preferences unusable in OS X.
  o Search box: Fix completion no longer working after using Tag Browser
    to do a search. Also ensure that completer popup is always hidden when
    a search is performed.
  o Fix pressing Enter in the search box causes the same search to be
    executed twice in the plugins and keyboard shortcuts preferences
    panels
  o Catalog generation: Fix error creating epub/mobi catalogs on non UTF-8
    windows systems when the metadata contained non ASCII characters
* Sun Aug 14 2011 Sascha.Manns@open-slx.de
- New Features:
  o Make the keyboard shortcuts used by the main calibre interface user
    customizable, via Preferences->Advanced->Keyboard
  o When switching libraries, if the library no longer exists, give the
    user a chance to specify a new location for the library, in case it
    was moved, before forgetting it.
  o Template language: Add strcat and strlen builtin functions.
- Bug fixes:
  o The various options to control how automerging works when adding books
    now also apply when copying a book from one library to another.
  o Ebook viewer: Respond to key presses even when the book display area
    does not have keyboard focus
  o Allow integer and float column values to go to -999999. -1000000 is
    the value of 'undefined'.
  o Fix in calibre browser not working for the Open books store in Get
    Books.
  o Fix regression in 0.8.13 that caused incorrect title/author for
    downloaded news if you turned off reading metadata from file contents
    in Preferences->Adding books
  o Save to disk: When saving to a single directory, handle the case of
    the save to disk template containing path separators inside template
    expression correctly.
  o Get Books: Always read metadata from the file contents, ignoring the
    setting in Preferences->Adding books
  o Fix merge_metadata to not overwrite non-text fields ('bool', 'int',
    'float', 'rating', 'datetime') that have a value of zero/false instead
    of None.
* Wed Aug 10 2011 Sascha.Manns@open-slx.de
- New Features
  o Add a new action 'Pick Random Book' that can be added to the toolbar
    via Preferences->Toolbars.
  o Driver for Droid X2
  o PDF metadata: Support reading/writing of tags from the Keywords field
    in PDF files.
  o MOBI Input: Speedup reading of HUFF/CDIC compressed files
  o MOBI Output: Add a command line option --extract-to that uses the
    inspect MOBI tool to extract the created MOBI file to the specified
    directory
  o Template language: Add a few new functions to manipulate lists
    (list_difference, list_intersection, list_sort)
  o Make the Manage Tags/Publishers/etc. dialog show a column with counts
    for each item, to easily sort by number of items
  o MOBI Output: Generate navpoints for items at every level in the TOC,
    not just the deepest level
- Bug Fixes
  o MOBI Output: Remove option to choose masthead font as the font
    selection control causes crashes on some windows systems
  o MOBI Output: Fix bug that caused paragraphs that had only a non
    breaking space as text before the first child element to be removed.
  o Display undefined dates properly in the Book details panel.
  o Fix regression that broke deleting of books from first generation
    Kobos with un-upgraded firmware
  o Get books: Fix Gutenberg store and improvements to chitanka.info and
    e-knigni.net
  o News download: Support https proxies
  o Check library did not know about original_* files
  o Fix crash caused by having very large numbers of authors > 100 for a
    book
* Fri Jul 29 2011 Sascha.Manns@open-slx.de
- New Features
  o Content server: Return the correct last modified date when serving
    ebook files. Also allow getting of book metadata as /get/opf/
  o Driver for the COBY MP977
  o Get Books: Remove epub bud store. Add Ozon.ru and e-knigni.net stores.
  o Fix broken amazon UK and DE stores.
  o Add a new tweak to Preferences->Tweaks that allows auto generation of
    series numbers when importing books with a series name, but no number
- Bug Fixes
  o Fix a regression in 0.8.11 that broke calibre on linux systems that
    use a file system encoding that cannot support cyrillic characters
  o Fix long titles not wrapping in cover browser
  o When adding books, handle the case of files without read permission
    more gracefully.
  o When changing metadata in EPUB files do not use the opf: namespace
    prefix on newly created elements. Apparently, FBReaderJ doesn't
    understand XML namespaces.
  o Prevent metadata download from returning published dates earlier than
    101 A.D.
  o Fix a bug where dates before 101AD in the database could cause errors
  o Fix an error in the book details panel if the user sets the default
    author link to blank
* Wed Jul 27 2011 Sascha.Manns@open-slx.de
- updated to Version 0.8.11
  - New Features
    o When doing a conversion from some format to the same format, save the
    original file
    o Conversion pipeline: Add an option to control the height of the blank
    lines inserted by calibre
    o Drivers for bq DaVinci, Samsung Galaxy ACE GT-S5830 and Medion
    e-reader
    o Get Books: Add stores Chitanka and Bookoteka. Remove epubbuy.de at
    store's request
    o Content server: Add a link at the bottom of the mobile interface to
    switch to the full interface.
    o Update the kindle icon shown when a Kindle is connected to use a
    picture of the Kindle 3
    o MOBI Output: When converting epub documents that have a start element
    in their guide, use it to mark the starting position at which the MOBI
    file will be opened.
    o News download: Add a default Accept header to all requests
  - Bug Fixes
    o Fix regression that broke loading translations from .po files in the
    working directory
    o Fix conversion dialog not allowing series numbers larger than 9999
    o Conversion pipeline: When adding/removing entries to the manifest,
    ignore unparseable URLs instead of erroring out on them
    o SD Card in Azbooka not being detected
    o Conversion pipeline: Strip out large blocks of contiguous space (more
    than 10000 contiguous blanks) as these slow down the conversion
    process and are almost always indicative of an error in the input
    document.
    o ebook-convert: Abort if a keyboard interrupt is raised during parsing
    o Regex builder: Show a nicer error message when the user has the file
    open in another program on windows.
    o When converting in the GUI, set all identifiers present in the book's
    metadata in the output file, if the output format supports them.
* Wed Jul 20 2011 Sascha.Manns@open-slx.de
- updated to Version 0.8.10
  - New Features
  * Add a right click menu to the cover browser. It allows you to view a
    book, edit metadata etc. from within the cover browser. The menu can
    be customized in Preferences->Toolbars
  * Allow selecting and stopping multiple jobs at once in the jobs window
  * When editing metadata directly in the book list, have a little pop up
    menu so that all existing values can be accessed by mouse only. For
    example, when you edit authors, you can use the mouse to select an
    existing author.
  * Get Books: Add ebook.nl and fix price parsing for the legimi store
  * Drivers for Samsung Infuse and Motorola XPERT
  * Tag Browser: Make hierarchical items work in group searched terms.
  - Bug Fixes
  * Allow setting numbers larger than 99 in custom series columns
  * Fix a bug that caused the same news download sent via a USB connection
  * to the device on two different days resulting in a duplicate on the
    device
  * Ensure English in the list of interface languages in Preferences is
    always listed in English, so that it does not become hard to find
  * SNB Output: Fix bug in handling unicode file names
  * Fix sorting problem in manage categories. Fix poor performance problem
  * when dropping multiple books onto a user category.
  * Remove 'empty field' error dialogs in bulk search/replace, instead
    setting the fields to their default value.
  * Fix regression that broke communicating with Kobo devices using
    outdated firmware
  * LRF Input: Fix conversion of LRF files with non ascii titles on some
    windows systems
* Mon Jul 11 2011 Sascha.Manns@open-slx.de
- updated to Version 0.8.9
  - New Features
  * Kobo Touch: Display Preview Tag for book previews on the device
  * Improved display of grouped search terms in Tag Browser
  * When adding HTML files to calibre, add an option to process links in
  breadth first rather than depth first order. Access it via
  Preferences->Plugins and customize the HTML to ZIP plugin
  * Conversion pipeline: Add option to control if duplicate entries are
  allowed when generating the Table of Contents from links.
  * Metadata download: When merging results, if the query to the xisbn
  service hangs, wait no more than 10 seconds. Also try harder to
  preserve the month when downlaoding published date. Do not throw away
    isbnless results if there are some sources that return isbns and some
  that do not.
  * Get Books: Remove OpenLibrary since it has the same files as
  archive.org. Allow direct downloading from Project Gutenberg.
  * Add functions to the template language that allow getting the last
  modified time and size of the individual format files for a book. Also
    add a has_cover() function.
  - Bug Fixes
  * Fix true/false searches dont work on device views
  * Fix renaming of collections in device views
  * Fix regression that broke the use of the device_db plugboard
  * Kobo driver: Hide Expired Book Status for deleted books. Also fix
  regression that broke connecting to Kobo devices running very old
    firmware.
  * Fix bug in 0.8.8 that could cause the metadata.db to be left in an
  unusable state if calibre is interrupted at just the wrong moment or
  if the db is stored in dropbox
  * Fix sorting of composite custom columns that display numbers.
* Sun Jul  3 2011 Sascha.Manns@open-slx.de
- added automatic osc add for the new Sourcepackage into
  generate-tarball.sh
* Sun Jul  3 2011 Sascha.Manns@open-slx.de
- updated to Version 0.8.8
- New Features
  o Make author names in the Book Details panel clickable. Clicking them
    takes you to the wikipedia page for the author by default. You may
    have to tell calibre to display author names in the Book details panel
    first via Preferences->Look & Feel->Book details. You can change the
    link for individual authors by right clicking on the author's name in
    the Tag Browser and selecting Manage Authors.
  o Get Books: Add 'Open Books' as an available book source
  o Get Books: When a free download is available for a search result, for
    example, for public domain books, allow direct download of the book
    into your calibre library.
  o Support for detecting and mounting reader devices on FreeBSD.
  o When creating a composite custom column, allow the use of HTML to
    create links and other markup that display in the Book details panel
  o Add the swap_around_comma function to the template language.
  o Drivers for HTC G2, Advent Vega, iRiver Story HD, Lark FreeMe and
    Moovyman mp7
  o Quick View: Survives changing libraries. Also allow sorting by series
    index as well as name.
  o Connect to iTunes: Add an option to control how the driver works
    depending on whether you have iTunes setup to copy files to its media
    directory or not. Set this option by customizing the Apple driver in
    Preferences->Plugins. Having iTunes copy media to its storage folder
    is no longer neccessary. See
    http://www.mobileread.com/forums/showthread.php?t=118559 for details
    Remove the delete library functionality from calibre, instead you can
    now remove a library, so calibre will forget about it, but you have to
    delete the files manually
- Bug Fixes
  o Fix a regression introduced in 0.8.7 in the Tag Browser that could
    cause calibre to crash after performing various actions
  o Fix an unhandled error when deleting all saved searches
  o Fix row numbers in a previous selection being incorrect after a sort
  o operation.
  o Fix ISBN identifier type not recognized if it is in upper case
  o Fix a regression in 0.8.7 that broke reading metadata from MOBI files
    in the Edit metadata dialog.
  o Fix handling of filenames that have an even number of periods before
    the file extension.
  o Fix lack of thread saefty in template format system, that could lead
    to incorrect template evaluation in some cases.
  o Fix conversion to PDB when the input document has no text
  o Fix clicking on first letter of author names generating incorrect
    search.
  o Also fix updating bulk metadata in custom column causing unnneccessary
    Tag Browser refreshes.
  o Fix a regression in 0.8.7 that broke renaming items via the Tag
    Browser
  o Fix a regression in 0.8.7 that caused the regex builder wizard to fail
    with LIT files as the input
* Wed Jun 29 2011 toms@suse.de
- Added suggestion from bnc#702918 to support Sony prs350 devices
  Thanks to Mathias Homann!
- Localization files are integrated into a locales.zip which makes
  it difficult to install into separate locale directory.
  Furthermore, it seems to be interconnected with other functions
  which makes it a lot of work to remove that.
  => Leave it in the locale.zip for the time being
* Sun Jun 26 2011 Sascha.Manns@open-slx.de
- updated to version 0.8.7
- New Features
  o Connect to iTunes: You now need to tell iTunes to keep its own copy of
    every ebook. Do this in iTunes by going to Preferences->Advanced and
    setting the 'Copy files to iTunes Media folder when adding to library'
    option. To learn about why this is necessary, see:
    http://www.mobileread.com/forums/showthread.php?t=140260
  o Add a couple of date related functions to the calibre template
    langauge to get 'todays' date and create text based on the value of a
    date type field
  o Improved reading of metadata from FB2 files, with support for reading
    isbns, tags, published date, etc.
  o Driver for the Imagine IMEB5
  o Show the currently used network proxies in Preferences->Miscellaneous
  o Kobo Touch driver: Show Favorites as a device collection. Various
    other minor fixes.
  o Content server now sends the Content-Disposition header when sending
    ebook files.
  o Allow search and replace on comments custom columns.
  o Add a new action 'Quick View' to show the books in your library by the
    author/tags/series/etc. of the currently selected book, in a separate
    window. You can add it to your toolbar or right click menu by going to
    Preferences->Toolbars.
  o Get Books: Add libri.de as a book source. Fix a bug that caused some
    books downloads to fail. Fixes to the Legimi and beam-ebooks.de stores
- Bug Fixes
  o Fix a memory leak that could result in the leaking of several MB of
    memory with large libraries
  o Fix the read metadata from format button in the edit metadata dialog
    using the wrong timezone when setting published date
  o Generating catalog: Fix occassional file in use errors when generating
    catalogs on windows
  o Fix clicking on News in Tag Browser not working in non English
    locales.
  o HTML Input: Fix a regression in 0.8.6 that caused CSS stylesheets to
    be ignored
  o Fix a regression that caused restore database to stop working on some
    windows sytems
  o EPUB Output: Convert tags with text in them into  as ADE cannot handle them.
* Tue Jun 14 2011 toms@suse.de
- Removed calibre-cssutils.diff patch as it is integrated in the
  sources now
* Mon Jun 13 2011 saigkill@opensuse.org
- uploaded source for 0.8.4 but the l18n Patch and the CSS Patch needs
  to be updated. But i haven't enough experience to do that.
* Tue Jun  7 2011 saigkill@opensuse.org
- updated to version 0.8.4
- New Features:
  o New and much simpler interface for specifying column coloring via
    Preferences->Look & Feel->Column Coloring
  o Driver for Trekstor eBook Player 5M, Samsung Galaxy SII I9100,
    Motorola Defy and miBuk GAMMA 6.2
  o Get Books: Add EpubBud, WH Smits and E-book Shoppe stores
  o When deleting 'all formats except ...', do not delete if it leaves a
    book with no formats
  o Change default toolbar to make it a little more new user friendly. The
    icons have been re-arranged and now the text is always visiblke by
    default. You can change that in Preferences->Look & Feeel and
    Preferences->Toolbar
  o Windows installer: Remember and use previous settings for installing
    desktop icons, adding to path, etc. This makes the installer a little
    slower, complaints should go to Microsoft.
  o Template language: Add str_in_list and on_device formatter functions.
  o Make debugging templates a little easier
  o Allow the user to specify formatting for number type custom columns
- Bug fixes:
  o Fix typo in NOOK TSR driver that prevented it from working on windows
  o Fix quotes in identifiers causing Tag Browser to be blank.
  o Speedup auto complete when there are lots of items (>2500) the
    downside being that non ASCII characters are not sorted correctly. The
    threshold can be controlled via Preferences->Tweaks
  o RTF Output: Fix handling of curly brackets
  o Fix searching in Get Books not working with non ASCII characters
  o Fix excessive memory consumption when moving very large files during a
    metadata change
  o Fix series index being overwritten even when series is turned off in
    bulk metadata download
  o Fix regression in templates where id and other non standard fields no
    longer worked.
  o EPUB Output: Fix crash caused by ids with non-ascii characters in them
  o Try to preserve the timestamps of files in a ZIP container
  o After adding books always select the most recently added book.
* Tue May 31 2011 fsundermeyer@opensuse.org
- spec file changes:
  * added dependencies on python(-devel) >= 2.7.1
  * obsoletes calibre07
* Sat May 14 2011 saigkill@opensuse.org
- updated to version 0.8.1
- New Features:
  o Add Amazon DE, Beam EBooks, Beam DE, Weightless Books, Wizards Tower
    Books to the list of ebook stores searched by Get Books
  o TXT output: All new Textile output with much greater preservation of
    formatting from the input document
  o Migrate metadata plugin for Douban Books to the 0.8 API
  o Driver for Dell Streak on windows
  o Add menu items to Get Books action to search by title and author of
    current book
  o Add title_sort as available field to CSV/XML catalogs
  o Add a context menu to the manage authors dialog
  o Add a button to paste isbn into the identifiers field in the edit
    metadata dialog automatically
- Bug Fixes:
    o Amazon metadata download plugin: Fix links being stripped from
    comments. Also fix ratings/isbn not being parsed from kindle edition
    pages.
    o Fix one source of segfaults on shutdown in the linux binary builds.
    o Allow the use of condensed/expanded fonts as interface fonts
    o EPUB Input: Ignore missing cover file when converting, instead of
    erroring out.
    o Fix custom identifier being erased by metadata download
    o Fix regression that broke various things when using Japanese language
    calibre on windows
    o RTF Input: Handle null color codes correctly
    o ODT Input: Handle inline special styles defined on  tags.
    o Fix error when pressing next previous button with an empty search in
    the Plugins preferences
    o Ignore 'Unknown' author when downloading metadata.
    o Fix timezone bug when setting dates in the edit metadata dialog
    o Fix ebook-convert not recognizing output paths starting with ..
* Sun May  1 2011 saigkill@opensuse.org
- updated to version 0.7.59
- New Features:
    o Support for converting and reading metadata from Plucker format
    PDB files
    o The metadata that is displayed in the book details panel on the right
    is now completely configurable via Preferences->Look & Feel
    o Add a column that shows the date when the metadata of a book record
    was last modified in calibre. To see the column, right click on the
    column headers in calibre and select Show column->Modified. Note that
    the dates may be incorrect for books added with older versions of
    calibre.
    o Add command line option to shutdown running calibre
    o CHM Input: Store extracted files in the input/ sub dir for easy
    debugging when --debug-pipeline is specified
    o Add a popup menu to the 'Create saved search button' to allow easy
    deleting of saved searches
- Bug Fixes:
    o Fix regression that broke converting to LIT in 0.7.57
    o Conversion pipeline: Remove encoding declarations from input HTML
    documents to guarantee that there is only a single encoding
    declaration in the output HTML.
    o Correctly parenthesize searches that are used to make search
    restrictions
    o Fix ratings in save to disk templates not being divided by 2
    o TXT to EPUB: Underlined words (following quotes?) fail to become
    italics
    o Fix template function source code unavailable when not running calibre
    from source
    o Fix adding html books from the top of a deep folder hierarchy very
    slow
    o Only set language in MOBI metadata if it is not null
    o Fix 'count-of' searches (e.g., tags:#>3).
    o Fix regression that broke connection to iTunes in some cases
    o Fix buggy regex that made converting PDFs with the string
  * ***************** very slow
    o Fix Ctrl+L shortcut to lookup word not working in ebook viewer
    o Fix regression that broke searching on boolean columns
    o Fixes a bug in 0.7.58 that caused too small fonts when
    converting to MOBI for the Kindle. Apologies.
    o Apple driver: Handle invalid EPUBs that do not contain an OPF file
* Mon Apr 25 2011 bjorn.lie@gmail.com
- Removed unnecessary dep on hal - bnc(#689588)
* Sat Apr 23 2011 saigkill@opensuse.org
- updated to version 0.7.57
- New Features
    o Launch worker processes on demand instead of keeping a pool of them in
    memory. Reduces memory footprint.
    o Use the visual formatting of the Table of Contents to try to
    automatically create a multi-level TOC when converting/viewing MOBI
    files.
    o Add a new function booksize() to the template language to get the
    value of the size column in calibre.
    o Add support for using metadata plugboards with the content server
    (only with the epub format)
    o Change default algorithm for automatically computing author sort to be
    more intelligent and handle the case when the author name has a comma
    in it
    o Show cover size in the tooltips of the book details panel and book
    details popup window
- Bug Fixes
    o Dragging and dropping a cover onto the book details panel did not
    change the cover size
    o Fix non-escaped '|' when searching for commas in authors using
    REGEXP_MATCH
    o Fix ratings in templates being multiplied by 2
    o Fix adding a comma to custom series values when using completion.
    o CHM Input: Another workaround for a Microsoft mess.
    o Fix job count in the spinner not always being updated when a job
    completes
    o Changing case only of a title does not update title sort
* Wed Apr 20 2011 toms@suse.de
- Updated to version 0.7.56
- New Features
  o This is primarily a bug fix release that fixes a bug in 0.7.55
    that caused calibre to rescan the files on the device every
    time the device is connected. If you updated to 0.7.55 it is
    highly recommended you update to 0.7.56
  o Device driver for Coby Kyros
  o  Remove the quick access to search options from next to the
    search bar, as we now have a separate search highlights toggle
    button
  o MOBI Output: Ensure that MOBI files always have 8KB worth of
    null bytes at the end of record 0. This appears to be necessary
    for Amazon to be able to add DRM to calibre generated MOBI files
    sent to their publishing service.
  o Add a tool to inspect MOBI files. To use: calibre-debug -m file.mobi
- Bug Fixes
  o Fixed regression taht caused calibre to rescan files on the device
    on every reconnect
  o Fix donate button causing the toolbar to be too large on OS X
  o MOBI Input: Fix detection of Table of Contents for MOBI files that
    have a page break between the location designated as the Table of
    Contents and the actual table of contents.
    => Closes tickets: 763504 [External link]
  o Comic Input: Fix handling of some CBZ files that have wrongly encoded
    non ASCII filenames on windows.
    => Closes tickets: 763280 [External link]
  o PML Input: Fix multi-line chapter title causing a spurious page break
    => Closes tickets: 763238 [External link]
  o EPUB Input: Speed up processing of files with very large manifest/spines
    Fix regression that broke cover:False searches in 0.7.55
- Improved news sources
    Suedduetsche Zeitung
    Irish Times
    Big Oven
    NSPM
* Sun Apr 10 2011 saigkill@opensuse.org
- updated to version 0.7.54
- New Features
    o New output format, HTMLZ which is a single HTML file with its
    associated images/stylesheets in a zipped up file
    o When dealing with ZIP/RAR archives, use the file header rather than
    the file extension to detrmine the file type, when possible. This
    fixes the common case of CBZ files being actually cbr files and vice
    versa
    o Support for the Motorola Atrix
    o Allow the icons in the toolbar to be turned off completely via
    Preferences->Look & Feel
    o When downloading metadata use the gzip transfer encoding when possible
    for a speedup.
- Bug Fixes
  o Conversion pipeline: Workaround for bug in lxml that causes a massive
    mem leak on windows and OS X when the input document contains non
    ASCII CSS selectors.
  o Conversion pipeline: Handle inline
* Sat Apr  2 2011 saigkill@opensuse.org
- updated to version 0.7.53
- New Features
    o Email delivery: You can now specify a subject that calibre will use
    when sending emails per email account, configured in
    Preferences->Sending by email. The subject is a template of the same
    kind used in Save to Disk, etc. So you can specift the
    title/authors/series/whatever in the template.
    o Apple driver: When an iDevice is detected, inform the user about the
    Connect to iTunes method instead of trying to connect directly to the
    device, as the latter can be buggy. See
    http://www.mobileread.com/forums/showthread.php?t=127883 for details
    o SONY driver: Search for books on the device in all directories not
    just database/media/books. This can be turned off by customizing the
    o SONY plugin in Preferences->Plugins
    o EPUB Output: Remove any margins specified via an Adobe page template
    in the input document. This means that the margins specified in
    calibre are more likely to be the actual margins used.
    o When reading metadata from filenames, allow publisher and published
    date to be read from the filename
    o Remove the option to show a second tool bar from Preferences->Look &
    Feel. Instead go to Preferences->Toolbars and add items to the second
    toolbar to control exactly what is visible there.
    o Add a tweak that can be used to have the calibre content server listen
    for IPv6 connections.
    o When clicking Next or Previous in the edit metadata dialog, then
    active book in the main book list is also changed
    o Remember the previously used setting for Match all/Match any under the
    o Tag Browser when calibre restarts
    o FB2 Output: Option to set the FB2 genre explicitly.
    o Plugin developers: calibre now has a new plugin API, see
    http://calibre-ebook.com/user_manual/creating_plugins.html Your
    existing plugins should continue to work, but it would be good to test
    them to make sure.
- Bug Fixes
    o Fix text color in the search bar set to black instead of the system
    font color
    o Workaround for Word bug where Word uses gb2312 as the encoding when
    exporting CHinese docs to HTML istead of gbk
    o Make sorting on the device view faster and more robust.
    o E-book viewer: Fix viewer losing place in very long single file
    documents when window resized.
    o MOBI Output: Workaround for Amazon's MOBI renderer not rendering top
    margins on ul and ol tags.
    o EPUB Input: Workaround for invalid EPUBs produced by someone named
    'ibooks, Inc.'.
    o RTF Input: Handle RTF files with too many levels of list nesting.
* Wed Mar 30 2011 saigkill@opensuse.org
- removed sed hack for wrong-end-of-line-encoding. Looks like it isn't
  longer needed.
* Wed Mar 30 2011 saigkill@opensuse.org
- updated to version 0.7.52
- Bug Fixes
    o Fixes a typo in 0.7.51 that broke the downloading of some news.
    Apologies.
* Fri Mar 25 2011 saigkill@opensuse.org
- updated to version 0.7.51
- New Features
    o Conversion: Detect and remove fake page margins that are specified as
    a margin on (nearly) every paragraph.
    o Windows build: All the python code and recipes are now put into zip
    files. This should decrease the amount of time the windows installer
    spends 'calculating free space'
    o OSX and Linux: Add a setting in Preferences->Behavior to control the
    priority with which calibre worker processes run. This setting was
    already available on windows.
    o Driver for HTC Thunderbolt, T-Mobile Optimus, Archos 43 and Blackberry
    OS6
    o A new 'authors type' custom column
    o When building calibre from source note that calibre now absolutely
    requires python >= 2.7
    o Add the keyboard shortcut: Ctrl+Shift+R to restart calibre in debug
    mode
- Bug Fixes
    o Fix dragging and dropping lots of books from the book list to the Tag
    Browser was broken
    o Change the shebang in the calibre launcher script on linux to
    explicitly use python2 rather than python
    o When adding formats do not corrupt the added file if the user tries to
    add an existing format to itself
    o Fix drag and drop to add files that contain the # character in the
    filename
    o Tag editor shouldn't add empty tags
    o MOBI Input: Handle MOBI files that have a too large 'number of
    records' field in their headers.
    o News download: Update RSS feedparser module to latest version
    o Various fixes to the zipfile module in calibre to handle 64 bit
    zipfiles and bring it up to date with the zip file module in the
    python stdlib
    o News download: Handle titles with ASCII control codes in them.
    o Make search hierarchies show simple names instead of compound ones.
    o Fix commas in author names being converted to pipe symbols in the book
    details window
    o Fix PocketBook can't always find epub cover image to create thumbnail
* Fri Mar 18 2011 saigkill@opensuse.org
- updated to version 0.7.50
- added short fix for RPMLINTs "wrong-end-of-line-encoding"
- New Features
    o Add 'Read a random book' to the view menu
    o Add option to show composite columns in the tag browser.
    o Add a tweak in Preferences->Tweaks to control where news that is
    automatically uploaded to a reader is sent.
    o Do not also show text in composite columns when showing an icon
    o Add a menu item to clear the last viewed books history in the ebook
    viewer
    o Kobo driver: Add support for the 'Closed' collection
    o Add rename/delete saved search options to Tag browser context menu
    o Make searches in the tag browser a possible hierarchical field
    o Allow using empty username and password when setting up an SMTP relay
- Bug Fixes
    o Fix regression in 0.7.49 that broke deleting of news downloads older
    than x days.
    o Restore the ability to remove missing formats from metadata.db to the
    o Check Library operation
    o EPUB metadata: Read ISBN from Penguin epubs that dont correctly
    specify it
    o Conversion pipeline: Handle the case where the ncx file is incorrectly
    given an HTML mimetype
    o Make numpad navigation keys work in viewer
    o Fix ratings not being downloaded from Amazon
    o Content server: Add workaround for Internet Explorer not supporting
    the ' entity.
    o Conversion pipeline: When detecting chapters/toc links from HTML
    normalize spaces and increase maximum TOC title length to 1000
    characters from 100 characters.
    o Fix regression that broke Search and Replace on custom fields
    o Fix regression that caused currently selected row to be unfocussed int
    he device view when updataing metadata
    o Coversion S&R: Do not strip leading and trailing whitespace from the
    search and replace expressions in the GUI
* Sat Mar 12 2011 saigkill@opensuse.org
- updated to version 0.7.49
- New Features
  - News download: More flexible news downlaod scheduling. You can now
    schedule by days of the week, days of the month and an interval, which
    can be as small as an hour for news sources that change rapidly
  - Improved support for dragging and dropping cover images directly from
    web browsers into calibre.
  - Add shortcuts of Alt+Left and Alt+Right for the next and previous
    buttons in the edit metadata dialog.
  - When adding a GUI plugin, prompt the user for where the plugin should
    be displayed
  - Conversion: When using the Level x Table of Contents options, support
    the case when the level 1,2,3 items are spread over multiple HTML
    files.
  - Support for the Optimus V
  - FB2 Input: Support for tables
  - Display a checkmark/cross next to 'true' and 'false' items in custom
    columns. Controlled via Preferences->Add a custom column
  - Catalog generation: Reuse cover from existing catalog, allows the use
    of a custom cover for catalogs
  - When setting covers in calibre, resize to fit within a maximum size of
    (1200, 1600), to prevent slowdowns due to extra large covers. This
    size can be controlled via Preferences->Tweaks.
- Bug Fixes
  - Fix long standing bug that caused errors when saving books to disk if
    the book metadata has certain chinese/russian characters on windows.
  - The fix required some changes to how unicode paths are handled in
    calibre, so it might have broken something else. If so, please open a
    ticket.
  - Custom recipes: Store custom recipes in the calibre config directory
    instead of the library database. This allows scheduling of custom
    recipes to work with multiple libraries. Note that you may have to
    re-schedule any existing custom recipes.
  - Restore the ability to do search and replace on ISBN. Use the
    'identifiers' field with type isbn to do this
  - Fix amazon metadata download plugin not working with ISBN-13 and
    social metadata not downloading if the supplied ISBN 10 is not for an
    edition available on Amazon
  - Workaround for openlibrary blocking the user agent used by calibre,
    preventing cover downloads from that site
  - FB2 Output: Add sequence to metadata. Fix bugs with author names. Fix
    bug where  elements were put inside tags.
  - Conversion pipeline: If the input HTML document uses uppercase tag and
    attribute names, convert them to lowercase
  - RTF Input: Fix space after unicode quote character being incorrectly
    removed
  - Fix regression that broke the ebook-device command line program in the
    previous release
  - Fix custom columns with numbers not allowing entry of positive numbers
    of 64-bit machines
  - Fix regression that caused focus to be lost when editing metadata in
    the device view
  - CHM Input: If an input encoding is specified, use it rather than
    trying to detect the encoding of the text in the CHM file.
  - Fix regression that caused the viewer to forget its window size and
    other attributes when launched from within calibre, after calibre is
    restarted.
  - News download: Fix regression that caused the delay parameter in
    recipes to not actually delay downloads.
  - Conversion pipeline: When converting the :first-letter pseudo CSS
    selector to a  follow W3C rules for handling leading punctuation
    characters.
  - Fix regression that caused clicking saved searches in the Tag Browser
    to not work
  - Comic Input: Fix conversion failing when output profile is set to
    Tablet Output
  - Replace leading periods in all path components generated by calibre
    with underscores
  - Search and replace preferences: Prevent very long strings from causing
    the wizard button to get pushed off the screen
  - Content server: Fix regression that caused various metadata to be
    missing in the book details view.
  - Apple driver: Ignore invalid EPUBs when sending to iTunes
* Mon Mar  7 2011 saigkill@opensuse.org
- updated to version 0.7.48
- New Features
  - Changes to the internal database structure used by calibre
  - Launch of a new website that catalogues DRM free ebooks.
    http://drmfree.calibre-ebook.com
  - News download: Add an option to keep at most x issues of a particular
    periodical in the calibre library. Use the Advanced tab in the Fetch
    news dialog for your news source to set this option.
  - You can now right click on the cover in the book details panel to
    copy/paste a new cover.
  - Add an entry to the add books drop down menu to easily add formats to
    an existing book record
  - Tag browser: Clicking on a nested category now searches for the
    category alone. Clicking twice searches for the category and all its
    descendants and so on.
  - Add a button to the Manage authors dialog to copy author sort values
    to author
  - Decrease startup times on large libraries by using a faster algorithm
    to parse stored dates
  - Add quick create links to easily create custom columns of commonly
    used types to the add custom column dialog
  - Allow drag drop of images to change cover in book details window.
  - Device susbsytem: Create a drive info file named driveinfo.calibre in
    the root of each device drive for USB connected devices. This file
    contains various useful data. API Change: The open method of the
    device plugins now accepts an extra parameter library_uuid which is
    the id of the calibre library connected tot eh device
- Bug Fixes
  - Conversion pipeline: Fix regression in 0.7.46 that caused loss of some
    CSS information when converting HTML produced by Microsoft Word. Also
    remove empty tags from microsoft namespaces when parsing HTML
  - Try harder to ensure that the worker log temporary files are deleted
    in windows
  - CHM Input: Handle CHM files that dont specify a topics file.
  - Fix regression that caused memory leak in Tag Browser. This would show
    up as the memory usage of calibre increasing when switching libraries.
  - Fix bug that caused preferences->behavior to not show the output
    format set by the welcome wizard, and instead default to showing EPUB
  - Fix bug that caused wrong books to be deleted from library if you
    choose 'delete from library and device' while the library is sorted by
    the On device column
  - MOBI Input: Ignore all ASCII control codes except CR, NL and Tab.
* Mon Feb 28 2011 saigkill@opensuse.org
- update to version 0.7.47
- New Features
    o Tag Browser: Support the creation of nested User Categories
    o Disable Kent District Library plugin to download series information.
    o The website could not handle the load calibre's 2 million users put on
    o it. You can manually re-enable it if you really want series
    information, but it is very slow
    o Drivers for the Wexler T7001, Archos 7, Wink and Xperia X10
    o Comic Input: Add option to not add links to individual pages to the
    o Table of Contents when converting CBC files
    o EPUB Output: Try to ensure that the cover image always has an
    id='cover' to workaround Nook cover reading bug.
    o ODT input: Update odfpy library to latest version, adds support for
    bookmarks
    o EPUB Output: Remove unnecessary CSS page breaks as they confuse the
    latest release of iBooks
- Bug Fixes
    o Fix regression in 0.7.46 that broke creating date and composite custom
    columns
    o Linux binary build: Fix ImageMagick trying to load system modules
    instead of bundled modules
    o Kobo driver: Handle missing firmware version file
    o ODT Input: Do not force the background color to white.
    o MOBI Input: Do not speciy text-align for every paragraph. Fixes
    text-align inheritance issues for newer MOBIs with nested divs.
    o EPUB Output: Do not set the file-as attribute on title elements in the
    o OPF as the current OPF spec does not support file-as. Instead use a
    calibre extension to OPF.
    o Content server: Fix regression that broke browsing User Categories via
    OPDS
    o Update the book details panel after adding books incase automerge is
    turned on and the current book is affected
    o FB2 Output: Fix paragraph spacing sometime incorrect.
    o Tag Browser: Fix generation of search query for authors with quote
    characters in their names
    o Fix bug that could cause download of cover/social metadata from Amazon
    to sometimes fail
    o LRF Input: Workaround for broken LRF files from BookDesigner that have
    incomplete TextStyle elements
* Wed Feb 23 2011 saigkill@opensuse.org
- updated to Version 0.7.46
- New Features:
  - Replace LibraryThing cover download plugin with a new plugin to
    download covers from Amazon
  - Kindle driver: Add an option to turn off sending page number
    information. Also add an option to use a more accurate but slower
    algorithm to calculate page numbers.
  - E-book viewer: Maintain a list of recently opened books (to see the
    list click the arrow next to the open button
  - Improve performance of device connection with huge libraries.
  - Add a button ot the search preferences to clear search history.
  - Device driver customization: Allow user to tell calibre to send any
  - ebook format to the device rather than just the list of formats that
  - calibre thinks the device will support
  - Metadata search and replace: Allow case changes and also fix search
    and replace when the destination field is a tags like field
  - FB2 Input: Add support for super and sub-scripts
  - When converting non english texts to english for filenames, use the
    users currect calibre interface language. This allows
  - Japanese/Korean/Vietnamese characters to be correctly converted.
  - Previously they were assumed to be Chinese.
  - Content server: Make the authors/series/tags/publisher/etc. in the
    book details box clickable so that similar books can be found easily.
  - Dragging from book list: Only start drag if user clicks on an already
    selected item. Makes multi-selecting with the mouse easier
  - Move the grouped search terms option from tweaks to the Search
  - Customization prefrences. Also allow grouped search terms to be
    displayed in the Tag browser
  - When adding .txt files, if they reference images, autoconvert them to
    a txtz file containing all referenced images. This is simliar to the
    way HTML files are converted to ZIP
  - MOBI Output: Partially support CSS vertical-align length values,
    converting them to  or  tags. Also support vertical-align for images
  - TXT Input: New paragraph-type option (off) to disable modifying the
    paragraph structure.
  - Device driver for the Kendo/Yifang M7 and the Wolder Mibuk Life
  - For people building calibre from source, note that calibre now
    requires SIP >= 4.12 to build
- Bug fixes:
  - Fix main memory and storage card for Cybook Orizon being swapped with
    some firmwares
  - Fix regression that broke deleting items from the Manage X dialogs.
  - Disable driver for Huawei android tablet/phones as Huawei for some
    reason seems to think that using the same USB ids for devices and USB
    sticks is a good idea. This would cause calibre to try to connect to
    the USB stick as a device continuously
  - MOBI Output: Normalize unicode strings when writing metadata to MOBI
    files as the Kindle cannot handle non-normalized unicode.
  - Fix regression that broke completion of tags with special characters
  - Conversion pipeline: Discard invalid CSS generated by Microsoft
    products before parsing. Should improve performance when converting
  - HTML from Word in particular.
  - Fix completion popups in the edit metadata dialog partially obscuring
    text in windows 7
  - Allow the left panel of the tweaksdialog to be resized
  - Fix reported number of books in library sometimes incorrect when using
    restrictions
  - PML Output: Don't write Cn tags when we are within a heading. Put
    images in DropBook required image subfolder. Remove Cn tags written
    inside of x and Xn tags.
  - Kobo driver: Handle Kobo databases that contain corrupted strings that
  - cannot be decoded from UTF-8
  - Adding from ISBN: Show a progress dialog for record creation as well
    as metadata download.
  - PDB Input: Fix some TOCs not being detected
  - Heuristics: Fix italicize patterns sometime breaking HTML tags.
  - When trying to detect the encoding of html, do not use more than the
    first 50KB so that detection is not too slow
  - Fix regresion that caused calibre to loose track of whether the
    content server is running if the content server is started from the
    preferences
  - Smarten punctuation: Handle non breaking spaces used as indents when
    converting opening quotes
  - Catalog generation: Do not abort on author sort mismatches when
    generating an EPUB catalog
  - When editing emtadata by clicking on the book list, remove leading and
    trailing whitespace
  - Fix typo that removed the date format tweaks from the new style tweaks
    interface
  - TXTZ Input: Fix images being lost
  - TXT Input: Rename none formatting-type to plain to correspond to the
    output option.
  - Conversion pipeline: Correctly handle align attribute on img tags.
  - Fix regression that caused completion in authors/series/tags fields on
  - OS X to return extra text.
  - Heuristics processing: Fix bug in italicize regeps that could cuase a
    scenebreak consisting of multiple underscores to be prefixed by the
    word None.
* Wed Feb 16 2011 fsundermeyer@opensuse.org
- Another spec file fix (requirement should have been libicu rather
  than icu)
- Now all requirements noted on the calibre home page should be
  matched. As a consequence, calibre will only install on
  openSUSEFactory, since it requires libicu >= 4.4.0. That
  requirement cannot be matched on 11.3, since OpenOffice and
  others require libicu 4.2.x
* Tue Feb 15 2011 fsundermeyer@opensuse.org
- version numbers for python-sip-devel and python-sip differ;
  corrected versiion number in Buildrequires for python-sip-devel
  to >= 4.12
- added more missing dependencies and minimum versions according to
  http://calibre-ebook.com/download_linux
* Tue Feb 15 2011 fsundermeyer@opensuse.org
- added missing minimal version number ( >= 4.12.1 ) to python-sip
  Require statements in spec file
* Sun Feb 13 2011 saigkill@opensuse.org
- updated to Version 0.7.45
  o New Features
    o Add plugin to download series information from the Kent District Library
    o Kindle driver: When uploading MOBI files to the device, upload page
    number information as well (used by the not yet released Kindle 3.1 firmware)
    o When automatically sending news to device, send to main memory
    preferentially, if it has enough space.
    o Allow customization of which metadata fields are searched by default (click
    the preferences icon next to the search box)
    o New format TXTZ: which is a zip file containing the TXT file and associated
    images + metadata. calibre can convert to and from this format and
    read/write metadata to it.
    o New option to control how automerge handles duplicate formats
    when adding books to your calibre library. See Preferences->Adding
    books
    o Driver for Nokia X6, Nexus S, WiBook, MyTouch 4G and Huawei
    Ideos S7
    o Nicer interface for editing tweaksAdd tweak to remove yellow
    lines from edges of book listCompletion: Restore adding of comma
    at end after completion for tags type fields.
    o Add a tweak to control if an & is added after completion for author
    type fieldsTurn search as you type off by default for searching the
    book list. You can turn it on by clicking the preferences button
    next to the search bar.
    o TXT Input: Add option to remove indents and fix bug where spaces were
    not retained properly.
  o Bug Fixes
    o Fix a regression in 0.7.44 that could cause setting authors to fail
    in windows when the author name is very long
    o E-book viewer: Fix bug that could cause the bottom of chapters to
    get cut-off if the topmost element had a large top margin.
    o Fix regression that caused a spurious error message after moving a
    library. Also ensure that the entries in the Copy to Library menu
    are updated after a library is moved/renamed/deleted.
    o PML Input: New handling of t and T tags. T's that do not start the
    line are ignored. t's that start and end the line use a margin for
    the text block
    o News download: Remove all invalid ASCII control characters from
    article descriptions as they cause XML parsing to fail
    o MOBI Output: Fix bug that was discarding non breaking spaces at
    the start of a paragraph when they were followed immediately by a tag.
    o LIT Input: Fix a regression in handling LIT files that contain
    txt rather than html data
    o Fix bug in search box in the plugins dialog
    o Fix renaming of categories via the Tag Browser
    o Content server: Do not send mobile version to iPad
    o Fix undefined publication date appearing in book jacket as 101
    o Heuristics: Fix issue with invalid markup from italicize patterns.
    o TXT Input: De-hyphenate textile and markdown inpu as well. Fix inline toc not showing all items.
    o RTF Input: More encoding token splitting fixes.
    o Fix regression that broke the convenience Email to xxx entry in the connect share menu.
    o Fix editing of series type custom columns in the book list.
* Fri Feb 11 2011 fsundermeyer@opensuse.org
- added missing (Build)Requires: sqlite3 / sqlite3-devel to
  spec file
* Wed Feb  9 2011 saigkill@opensuse.org
- updated to version 0.7.44
  - New Features
    o Nook Color driver: Send downloaded news to the My Files/Magazines
    folder on the Nook Color. Also when getting the list of books on the
    device look at all folders in My Files, not just My Files/Books.
    o MOBI Output: Use the book uuid as the ASIN field and set cdetype to
    o EBOK to allow Amazon furthest read tracking to work with calibre
    generated MOBI files.
    o Comic input: Add an option to override the image size in the generated
    comic. Useful if you have a device whose screen size is not coverred
    by one of the available output profiles.
    o Add a restore database option to the Library maintenance menu in the
    GUI
    o TXT Output: Allow output in the textile markup language
    o PML Output: Create multi-level Table of Contents
    o Driver for the Archos 7O
    o Search and Replace in the Bulk metadata dialog can now operate on the
    title_sort field as well
    o Allow changing the case of authors/tags/series etc. via the edit
    metadata dialog
    o Connect/share menu: Re-organize to make it a little less easy to
    select email and delete instead of just email by mistake
    o Heuristics: Improved Scene break detection and add option to control
    what scene breaks are replaced by.
    o SONY driver: Add option to not preserve aspect ratio of cover
    thumbnails.
    o BiBTeX catalog: Add on device column when available
    o Add search to the plugin preferences dialog
  - Bug Fixes
    o Fix a bug that could cause fiels to be lost when changing metadata on
    east asian windows installs if the title and/or author is very long.
    o Tag browser: Fix searching with items in a user category not owrking
    if the main category is hidden
    o Make completion for author/series/tags/etc. fields less disruptive
    o Fix regression that broke the content server when user
    categories/custom columns are present
    o Catalog generation: Handle user supplied templates more robustly
    o Move the Tags to apply to newly added books option into
    Preferences->Adding books
    o Workaround for bug in Qt on OS X that caused crashes when reading
    metedata from two or more EPUB files with HTML covers that used
    o embedded fonts. Now the embedded fonts are ignored on OS X.
    o Fix regression that broke the use of the group searched terms tweak
    o Fix template program regression triggered by recursively calling the
    processor
    o Fix mimetype sent by content server for PDB files
    o OPF: Write title_sort as a calibre custom metadata field rather than
    as a file-as attribute on the title. This conforms to the OPF spec
    o SONY driver: Fix thumbnails being sent to SD card are sent to the
    wrong location. Also use correct thumbnail size so that the SONY does
    not regenerate the thumbnail on disconnect
    o Do not discard the result of a conversion if the user opens the edit
    metadata dialog while the conversion is running
    o CHM Input: When the chm file lacks a hhc, lookf for index.html instead
    o EPUB Input: Filter some invalid media types from the spine
    o RTF Input: More encoding handlig fixes.
    o Linux binary build: Restore functioning of CALIBRE_DEVELOP_FROM, which
    was accidentally removed a few versions ago
    o RTF Output: Retain html headings as rtf headings when converting to
    rtf. Also fix output of italics.
    o LIT Input: Fix regression that broke handling of LIT files that
    contain txt data instead of html
    o MOBI Input: Handle more non printing ASCII codes
    o Handle empty cover files more gracefully
    o Catalog geenration: Fix error when Pocketbook is connected and trying
    to geenrate catalog
    o Heuristics: Italicize common cases, reduce false positives.
    o Fix regression that caused reporting of device connection errors to
    break
* Fri Jan 28 2011 saigkill@opensuse.org
- updated to version 0.7.43
- New Features
  o Ask for confirmation when stopping running jobs
  o Combine the database integrity check and library check into a single
    menu item. Also nicer implementation of the db integrity check.
  o BiBTeX Catalog: Add option to include file paths in the catalog.
  o Create 'generic' output profiles and generic devices in the welcome
    wizard
  o Bulk metadata edit: Custom column widgets all have an apply checkbox
    next to them.
  o Only use LibraryThing to download metadata if the user provides a
    library thing username and password. Since LT doesn't like web
    scraping
  o Allow renaming of user categories in the manage categories dialog.
  o Also allow searching for books in a category from the Tag Browser by
    right clicking ona a category
  o Folder device plugin: Add option to disable the use of sub folders
  o Allow saving/loading of search and replace expressions in the bulk
    metadata edit dialog.
  o Remeber previously used regular expression in the add books
    preferences dialog
  o Search and replace wizard: Cache the previously used input document.
  o Pressing Esc clears the current search in the main book list
  o Preselct right formats when using send specific format to device
  o Regex wizard gets find next and previous match buttons
- Bug Fixes
  o Do not allow customization of user interface plugins until calibre is
    restarted
  o EPUB Output: When using preserve cover aspect ratio, use the actual
    image sizes in the SVG template as otherwise ADE doesn't fully
    preserve the aspect ratio
  o Fix completion on a word with a trailing space causing the first
    letter to be duplicated in the edit metadata dialog
  o PML Input: PML x and Xn tags don't indent properly in TOC. Also handle
    invalid T markup and retain soft scene breaks
  o TXT Input: Retain whitespace at the beginning of lines. Don't preserve
    spaces in heuristic processing. Detect and retain soft scene breaks.
  o Fix Adding empty book - cover browser doesn't update
  o When generating author sort string ignore trailing Inc.
  o When converting HTML/ZIP files do not leave temporary files that are
    only deleted on application shutdown.
  o Don't crash if the prefs stored in the db are corrupted
  o Catalog generation: Do not use inline-block CSS as apparently Adobe
  o Digital Editions cannot handle it.
  o Fix extra spaces being inserted into TOC title when reading TOC from
    OPF guide element.
  o Remember window size for bulk metadata edit and catalog generation
    dialogs
  o Heuristics, italicize common cases: Enhance pattern matching to match
    punctuation after pattern.
  o Fix regression in converting HTML files that have ASCII-encoded non
    unicode characters inside their
* Sun Jan 23 2011 saigkill@opensuse.org
- updated to version 0.7.42
- New Features
  o 0.7.42 is a re-release of 0.7.41, because conversion to MOBI was
    broken in 0.7.41
  o Conversions: Replace the remove header/footer options with a
    more geenric search replace option, that allows you to not
    only remove but also replace text
  o Conversion: The preprocess html option has now become a new
    'Heuristic Processing' option which allows you to control
    exactly which heuristics are used
  o Conversion: Various improvements to Heuristic Processing
    (used to be preprocess HTML)
  o When adding empty books to calibre, optionally set the
    author to the author of the currently selected book
  o Device drivers for the Archos 101, SmatQ T7 and Acer Lumiread
  o Catalog generation: Make By Authors optional
  o Allow bulk editing of Date and Published columns.
  o Add a little button to clear date and published values to
    the edit metadata dialogs
  o When adding books by ISBN, allow the specification of special
    tags that will be added to the new book entries
  o Completion on multiple authors
  o Add AZW to default list of internally viewed formats, a I am
    tired of getting tickets about it
  o Nicer error message when catalog generation fails
  o Add capitalize option to context menus in the edit metadata dialog
- Bug Fixes
  o RTF Input: Fix regression in 0.7.40 that broke conversion of some
    old style RTF files
  o Fix Tag editor forgets position
  o When converting books in the calibre GUI, override metadata from
    the input document, even when empty.
  o Fix memory leak when switching libraries
  o RTF Output: Fix incorrent spacing between letters.
  o Catalog generation: Add composite columns to Merge Comments
    eligible types
  o Add a confirmation when closing the add a custom news source
    dialog.
  o Another workaround for LibraryThing UA sniffing that was
    preventing series metadata download, sigh.
  o PD Novel driver: Put books on the SD card into the eBooks folder
  o When shortening filepaths to conform to windows path length
    limitations, remove text from the middle of each component instead
    of the ends.
  o Make completion in most places case insensitive
  o Fix regression that caused the N key to stop working when editing
    a Yes/no column
  o Email: Fix bug when connecting to SMTP relays that use MD5 auth
  o MOBI Output: Fix bug that could cause a link pointing to the start
    of a section to go to a point later in the section is the section
    contained an empty id attribute
  o When auto converting books and the device is unplugged, do not
    raise an error.
  o Ebook-viewer: Display cover when viewing FB2 files
  o MOBI Input: Special case handling of emptu div tags with a defined
    height used as paragraph separators.
  o Fix sorting of author names into sub categories by first letter in
    the Tag Browser when the first letter has diacritics
  o Fix regression in 0.7.40 that caused commas in author names to
    become | when converting/saving to disk
  o Fix view specific format on a book with no formats gives an error
* Fri Jan 21 2011 toms@suse.de
- Fixed vulnerability bug bnc#664505:
  VUL-0: calibre: XSS and file disclosure (also mentioned in the
  changelog entry below)
- Updated to 0.7.40:
  New Features
  * A new 'highlight matches' search mode
    "There is now a checkbox next to the search bar named
    'Highlight'. If you check it, searching will highlight all
    matched books instead of filtering the book list to all
    matched books."
  * RTF Input: Improved support for conversion of images. The bug
    where some images were shrunk should no longer happen
  * Template language: Allow you to create your own formatting
    functions. Accessible via Preferences->Advanced->Template
    functions
  * News download: Convert various HTML 5 tags into <div> to
    support readers that cannot handle HTML 5 tags
  * RTF metadata: Add support for publisher and tags.
    Closes tickets: 6657 [External link]
  * BibTeX catalog: Add support for custom columns
  * TXT Input: Support for textile markup
  * Various minor tweaks to improve usability of Preferences->
    Plugins
  * TXT Output: Convert <hr> to scene break marker.
  * Support for the Archos 70
  * SONY Driver: Add an option to automatically refresh the
    covers on every connect. Accessible via: Preferences->
    Plugins->Device interface plugins
  * Add access to the larger template editor from plugboards via
    context menu.
  * Speed improvement when connecting a large library to a device
  * Speedup when searching on multiple words in a large library
  * TXT Input: Add a heauristic formatting processor
  Bug Fixes
  * Fix bug that caused automatic news removal to remove any book
    that has a tag that contains the word 'news' instead of only
    books that have the tag News
  * Refactor the downloading social metadata message box to allow
    canceling.
    Closes tickets: 8234
  * Kobo drive does not deal with Null value in DateCreated column
    Closes tickets: 8308
  * MOBI Input: Fix regression that caused images placed inside svg
    tags to be discarded
  * Fix selecting Tablet output profile would actually select the
    Samsung Galaxy S profile
  * Catalog generation: Fix a condition that could cause TOCs to
    not be properly generated in MOBI format catalogs
    Closes tickets: 8295
  * Zip file reading: Be more tolerant when a zip file has a damaged
    file directory
  * RTF Input: Various code cleanups. Go back to trying to handle
    unicode mappings without pre-processing. This will mean that some
    RTF files that used to convert, won't anymore. Please open
    tickets and attach them.
    Closes tickets: 8171
  * ImageMagick: When identifying an image don't read the entire image
  * FB2 Output: Add cover to FB2 metadata.
  * Fix inability to customize builting recipe when more than one
    recipe has the same name
    Closes tickets: 8281
  * RTF Input: Fix regression that broke the Preprocess HTML option
  * Fix XSS vulnerability in content server.
    Closes tickets:
  * TXT Output: Clean up and produce consistant output. Spacing around
    headings. Headings are not indented when using the remove
    paragraph spacing option.
  * Catalog generation: Handle invalid covers gracefully
  * Email settings: Before displaying the email test dialog warn the
    user that it will expose their email password
  * PDB Output: Fix regression that caused some PDB files to not work
    with other software
    Closes tickets: 8231
  New news sources
  * Yakima Herald and Tri-City Herald by Laura Gjovaag
  * Wichita Eagle by Jason Cameron
  * Pressthink and Zero Hedge by Darko Miletic
  * tyzden by zemiak
  * El Correo by desUBIKado
  * Cicero by mad
  * El Publico by Gerardo Diez
  Improved news sources
  * Financial Times UK
  * Globe and Mail
  * Wired Daily
  * MIT Technology Review
  * MSNBC
  * expansion.com
  * New York Times
  * Heraldo de Aragon
  * Exiled online
* Fri Jan 14 2011 fsundermeyer@opensuse.org
- reformatted complete calibre.changes file:
  openSUSE:Factory requires a linewidth < 70
  (refer to the dashed lines for linewidth)
* Thu Jan 13 2011 fsundermeyer@opensuse.org
- removed Require: python-django-tagging since it is no longer
  needed (searched the calibre sources for "tagging" and "django")
- added packages that are only required, to BuildRequires, too,
  because
  Requires should always be a subset of BuildRequires. If there
  are packages that are only Required
  * there is no way to check whether these packages are available
    in the given repositories unless you install the package (the
    build environment only contains packages from the given
    repositories and the project
  * the project's repository might become inconsistent, because
    Required packages do not block a build. So a package might get
    published, although a Required package does not build
* Wed Jan 12 2011 fsundermeyer@opensuse.org
- another Requires fix
* Wed Jan 12 2011 fsundermeyer@opensuse.org
- fixed Requires; made Buildrequires/Requires section in spec file
  readable
* Wed Jan 12 2011 fsundermeyer@opensuse.org
- added a patch so calibre works with python-cssutils 0.9.8
  (needs to be removed once calibre officially switches to the new
  python-cssutils version)
- fixed a minor spec-file error
* Tue Jan 11 2011 fsundermeyer@opensuse.org
- general project changes:
  * removed all packages alre3ady provided by targets
  * remaining packages only build for the targets where they are
    needed
  * python packages now all link to devel:languages:python
  * podofo now links to graphics
  * removed obsolete 11.1 build target
  * removed 11.3 KDE_Factory build target
- calibre changes:
  * fixed various issues in the spec file - now builds for Factory
  * cleaned up the spec file
  * added rpmlintrc (no need to remove all the shebangs)
  * generate-tarball.sh uses a tmp dir now and is less verbose
  * updated to new version 0.7.38
    Changelog see http://calibre-ebook.com/whats-new
* Fri Jan  7 2011 saigkill@opensuse.org
- added %%%%dir %%%%{_datadir}/locale/* for 11.1 & 11.2
* Fri Dec 24 2010 saigkill@opensuse.org
- updated to 0.7.35
- New Features
  o Add a simple to use Rich text editor for comments to the
    edit metadata dialog.
  o E-book viewer: Add a right click menu item 'Inspect'
    that allows you to inspect the underlying HTML/CSS
    source of the currently displayed content
  o When deleting books from the library if a device is
    connected and the books are also present on the device
    ask the user if the books should be deleted from the
    device, the library, or both.
  o Add device drivers for Trekstore eBook Player 7, Sanda
    Bambook, ALuratek Color, Samsung Galaxy, LG Optimus,
    Motorola Droid 2 and Sunstech EB700
  o Add an entry to the menu of the calibre library button
    to select a random book from your calibre library
  o SONY driver: Add a couple of special extra collections
    for all books by author and all books by title, to
    workaround the broken sorting on newer SONY models. To
    enable these collections, go to
    Preferences->Plugins->Device Interface plugins and
    customize the SONY plugin.
  o Edit metadata dialog: When downloading metadata, make
    the table of matching books sortable
  o Add a success message after a database integrity check
    completes successfully
  o Search and replace: When using regular expression mode,
    add a special input field '{template}' that allows use
    the templating language to create complex input
    fields. Also allow setting of series_index by search and
    replace using the same syntax as in the book list,
    namely, Series Name [series number]
  o Bulk metadata edit: Add option to automatically set
    cover from the cover present in the actual ebook files
  o E-book viewer: Show format of current book in the title
    bar.
  o Add a tweak to control how author names are displayed in
    the Tag Browser and Content Server
  o FB2 Output: Restore sectionizing functionality
- Bug Fixes
  o When in narrow layout, reserve 40%% of available width in
    the book details panel for series/formats/etc and use
    the rest for comments
  o PDB Input: Fix failure to block-indent PML sections
  o Tag browser: When renaming items dont reset the library
    view and try not to scroll the Tag Browser itself
  o Conversion pipeline: Fix broken link rewriting for
    inline CSS embedded in HTML
  o Fix regression in 0.7.34 that broke recipes using
    extra_css to link to SONY device fonts
  o SONY driver: Don't upload thumbnails as they slow down
    post disconnect processing on older models
  o Content server: Fix a bug that allowed remote users to
    read arbitrary png/gif/js/css/html files
  o On X11 initialize fontconfig in the GUI thread as Qt
    also uses fontconfig internally and fontconfig is not
    thread safe. Fixes a few random crashes on calibre
    strartup
  o When using the remove specific format actions, only show
    available formats in the selected books
  o Linux binary build: If setting system default locale
    fails, try setting locale to en_US.UTF-8 instead
  o Have the title sort tweak respected everywhere
  o PocketBook 701 driver: Swap the main memory and card
    drives on windows
  o Fix regression in templating that caused series_index to
    be shown even when book had no series
  o Content server: Fix regressiont hat broke browsing by
    rating
  o Content server OPDS feeds: Fix parsing of author names
    as XML
* Sat Dec 18 2010 saigkill@opensuse.org
- updated to 0.7.34
- New Features
  o Page turn animations in the e-book viewer
  o Conversion pipeline: Add an option to set the minimum line
    height of all elemnts as a percentage of the computed font
    size. By default, calibre now sets the line height to 120%% of
    the computed font size.
  o Large speedup in startup times and post metadata edit wait
    for large libraries
  o Allow changing the font used in the calibre interface via
    Preferences->Look and feel
  o Allow editing of the title sort value for a book via the
    edit metadata dialog
  o Disable the cover cache. This means that if you are running
    calibre on an underpowered machine, you might notice some slow
    down in the cover browser. On the other hand, calibre's memory
    consumption is reduced.
  o You can now restart calibre in debug mode by clicking the
    arrow next to the Preferences button. In debug mode, after you
    quit calibre, a diagnostic log will popup
  o When creating a new calibre library add an option to copy
    the custom column, saved searches, etc from the current
    library.
  o Add more tweaks to control how the next available series
    number is calculated.
  o Add a tweak to control layout of the custom metadata tab in
    the edit metadata dialog
  o Apple driver: Set series number as track number on windows
    when sending books to iTunes
  o Drivers for PocketBook 701 and Samsung E65
  o E-book viewer: Add option to have the mouse wheel flip pages
  o Add a load_resources method to the InterfaceAction and
    Plugin classes to facilitate loading of resources from plugin
    ZIP files
  o E-book viewer: Add option to not remember position in book
    when quitting.
  o When sorting the book list, keep the current book visible
    after the sort completes.
  o EPUB Output: Add an option to flatten the EPUB file
    structure, specially for FBReaderJ.
  o EPUB Output: Ensure all files inside the generated EPUB have
    unique filenames, to support broken EPUB readers like Stanza,
    Aldiko, FBReader and Sigil
  o FB2 Output: Add support for some 2.1 style tags.
  o Bulk metadata edit: Add options to delete cover/generate
    default cover.
  o Fix a regression in 0.7.33 that broke updating covers in
    ebook files when saving to disk.
  o Don't refresh the Tag browser if it is hidden. Speeds up
    metadata editing with large libraries, if you hide the Tag
    Browser.
  o MOBI Output: Add option to ignore margins in input document
  o Kobo driver: Add support for 1.8.x firmware
-Bug Fixes
  o Fix various memory leaks introduced in the last couple of
    releases
  o EPUB metadata: When rendering first page as the cover,
    handle embedded svg correctly.
  o Disable multiple library support when the
    CALIBRE_OVERRIDE_DATABASE_PATH env var is set
  o Content server: Fix bug that could cause saved search based
    restrictions to not exclude all books
  o Topaz metadata: Read metadata correctly from Topaz files
    that have MOBI file extensions
  o MOBI Input: Handle the (rare) MOBI files that do not specify
    per paragraph text indents correctly.
  o MOBI metadata reader: Handle invalid PRC files with spurious
    image_offset headers
  o Fix drag/drop of new cover to book detail panel does not
    update cover browser
  o Do not open the book details dialog when double click on the
    scrollbars in the book details panel
  o Templates: Fix {tags} not working when no tags are present
  o HTML metadata: Fix regression that broke parsing of some
    meta tags
  o Preferences: Add tooltips to buddy labels as well.
  o Content server: Fix handling of root URL when using
  - -url-prefix
  o Ensure that the default encoding used by python is never
    ASCII (needed when running a non frozen version of calibre on
    linux)
* Sun Dec 12 2010 toms@suse.de
- SPEC: Added build requirements for libicu-devel
* Fri Dec 10 2010 saigkill@opensuse.org
- updated to version 0.7.33
- New Features
  o Language sensitive sorting
  o Add an action to merge only formats and leave metadata alone
    (Shift+Alt+M)
  o Add a tweak to control which custom columns are displayed in
    the Book details panel.
  o Implement a more sophisticated 'functional programming'
    template language. See the User Manual for details.
  o Speed up deleting of large numbers of books and show
    progress while doing so
  o Adding books: Dont refresh the Tag Browser while adding
    multiple books. Should speed up the adding of large numbers of
    books.
  o Edit metadata dialog: When trying to download metadata, if
    there are multiple matches indicate which matches have a cover
    and summary in the list. Also add an option to automatically
    download the cover of the selected match.
  o Drivers for the HTC Legend and Samsung Epic
  o FB2 Output: Convert SVG images in the input document to
    raster images
  o News download: Localize the navigation bars in the
    downloaded news to the language the user has selected for
    their calibre interface
- Bug Fixes
  o Various fixes to the Title Case function
  o Content server: Fix --url-prefix being ignored for links at
    the Top level
  o News download: When generating periodicals for the SONY use
    the local timezone in the SONY specific metadata
  o Fix bug in cover cache that could cause it to keep a large
    number of covers in memory. Showed up when adding large
    numbers of books to calibre.
  o Adding books: Run in the main thread to prevent unfortunate
    interactions with the metadata backup. Also fix regression
    that broke the Abort button.
  o Fix a crash on OS X if OK is clicked inthe edit metadata
    button while downloading a cover
  o E-book viewer: Fix a regression that prevented booksmarks
    from working with some EPUB files
  o Save to disk: Refactor to not open a database connection in
    the worker process. Also fix a bug that could lead to save
    failures not being reported.
  o Fix regression in 0.7.32 that broke opening formats in the
    ebook viewer from the edit metadata dialog
  o FB2 Output: Generate output 100%% compliant with the FB2 spec
  o Fix Saved search dropdown box looses selected search
  o TXT Output: Fix an issue where the br to space conversion
    was not being handled properly.
* Sat Dec  4 2010 saigkill@opensuse.org
- updated to version 0.7.32
- New Features
  o All new linux binary build. With updated libraries and
    replacing cx_Freeze with my own C python launcher code.
  o Edit metadata dialog: Add Next and Previous buttons and show
    cover size in tooltip
  o A new custom column type: Enumeration. This column can take
  one of a user defined set of values.
  o PML Output: Add option to reduce image sizes/bit depth to
    allow PML Output to be used with DropBook
  o TXT Output: Add option to generate Markdown output. Turn
    tags into spaces.
  o Add a count function to the template language. Make
    author_sort searchable.
  o Various consistency and usability enhancements to the search
    box.
  o Driver for samsung fascinate and PocketBook 902
  o FB2 Output: Add option to create FB2 sections based on
    internal file structure of input file (useful for EPUB files
    that have been split on chapter boundaries). Also add options
    to mark h1/h2/h3 tags as section titles in the FB2 file.
  o Metadata jacket: Add publisher information to jacket.
  o Catalog generation: Allow use of custom columns as well as
    tags to indicate read books. Note that your previously saved
    read books setting will be lost.
  o Bulk metadata edit dialog: Add an Apply button to allow you
    to perform multiple operations in sequence
  o Allow drag and drop of books onto user categories. If you
    drag a book from a particular column (say authors) and drop it
    onto a user category, the column value will be added to the
    user category. So for authors, the authros will be added to
    the user category.
  o Check Library can now check and repair the has_cover cache
  o Allow GUI plugins to be distributed in ZIP files. See
    http://www.mobileread.com/forums/showthread.php?t=108774
  o Allow searching by the number of
    tags/authors/formats/etc. See User Manual for details.
  o Tiny speed up when loading large libraries and make various
    metadata editing tasks a little faster by reducing the number
    of times the Tag Browser is refreshed
- Bug Fixes
  o E-book viewer: Fix broken backwards searching
  o Fix custom ratings column values being displayed incorrectly
    in book details area
  o Fix book details dialog not using internal viewer to view
    ebooks
  o MOBI Output: When the input document does not explicitly
    specify a size for images, set the size to be the natural size
  of the image. This works around Amazon's *truly wonderful*
    MOBI renderer's tendency to expand images that do not have a
    width and height specified.
  o Conversion pipeline: Fix bug that caused height/width
    specified in %%/em of screen size to be incorrectly calculated
    by a factor of 72./DPI
  o Conversion pipeline: Respect max-width and max-height when
    calculating the effective size of an element
  o Conversion pipeline: Do not override CSS for images with the
    value of the img width/height attributes, unless no CSS is
    specified for the image
  o E-book viewer: Resize automatically to fit on smaller
    screens
  o Use the same MIME database on all platforms that calibre
    runs on, works around python 2.7's crazy insistence on reading
    MIME data from the registry
  o Kobo driver: Allow html, txt and rtf documents to be deleted
  o Always overwrite title/author metadata when downloading
    metadata for books added by ISBN
  o Nook Color profile: Reduce screen height to 900px
  o Fix regression that broke RTF conversion on some linux
    systems
  o Fix bug that could break searching after copying and
    deleting a book from the current library
* Sat Nov 27 2010 toms@suse.de
- spec file: Added export of CFLAGS variable
- update to 0.7.31
- Bug Fixes
  * Fix various regressions in the calibre windows build caused
    by the switch to python 2.7. If you are on windows and
    upgraded to 0.7.30, it is highly recommended that you
    upgrade to 0.7.31. If you are not on windows, you can ignore
    0.7.31
    Closes tickets: 7685, 7694, 7691
* Sat Nov 27 2010 saigkill@opensuse.org
- update to 0.7.30
- New Features
  o Support for Acer Lumiread and PocketBook Pro 602
  o When importing by ISBN also allow the specification of a
    file to be imported.
  o E-mail sending: Email sends are now regular jobs that can be
    accessed from the jobs list. Also when sending using
    gmail/hotmail send at most one email every five minutes to
    avoid trigerring their spam controls. Failed sends are now
    retried one more time, automatically.
  o Content server: When a category contains only one item, go
    directly to the book list instead of forcing the user to click
  on that one item
  o E-mail sending: Allow unencrypted connections to SMTP relay
  o Improve startup times for large libraries by caching the
    has_cover check
  o Update windows binary build to use python 2.7
  o Metadata and cover download plugins from Nicebooks (disabled
    by default)
- Bug Fixes
  o MOBI Input: Fix bug in cleanup regex that broke parsing of
    escaped XML declarations.
  o Content server: Fix bug when user has custom
    categories/columns with non ascii names
  o RTF Output: Handle non breaking spaces correctly
  o Conversion pipeline: When rasterizing SVG images workaround
    incorrect handinlg of percentage height specifications in
    QSvgRenderer.
  o News download: Update version of feedparser used to parse
    RSS feeds.
  o Tag Browser: Allow user to restore hidden categories by a
    right click even is all categories have been hidden
  o TXT/RTF Output: Handle XML processing instructions embedded
    in content correctly.
  o MOBI Input: Workarounds for lack of nesting rules between
    block and inline tags
  o E-book viewer: Load all hyphenation patterns to support
    multi-lingual books
  o E-book viewer: Fix incorrect lang names being used in
    hyphenation
  o Check to see that the result file from a conversion is not
    empty before adding it, protects against the case where the
    conversion process crashes and the GUI adds a zero byte file
    to the book record
  o E-book viewer: More sophisticated algorithm to resize images
    to fit viewer window. Should preserve aspect ratio in more
    cases
  o Remove unneccessary calls to set_path when creating book
    records. Speeds up record creation by about 30%% on my system
  o Speedup for bibtex catalog generation.
  o Kobo driver: Fix missing table in deleting books process for
    Kobo WiFi and Kobo-O 1.8 Beta
  o RTF Input: Preserve scene breaks in the form of empty
    paragraphs. Preprocessing: Improvements to chapter detection
  o Fix custom recipe not sorted by title
  o Kobo driver: Fix bug in managing the Im_Reading category on
    windows
* Sat Nov 20 2010 saigkill@opensuse.org
- update to 0,7,29
- New Features
  o OSX binary build is now based on Qt 4.7. Also, the build is
    now Intel only and requires at least OS X 10.5.2. If you are
  on a PowerPC machine or an older OS X version, do not upgrade
  o Content server: Allow direct navigation to a set of books in
    the book list.
  o OS X: When deleting books, put the files into the recycle
    bin instead of deleting them permanently
  o Add button to easy configure Hotmail as email relay. Also
    improve usability of easy config buttons
  o Kobo driver: Support Currently_Reading category
  o Catalog generation: Thumbnail caching, wishlist, improved
    description layout.
  o Support for the Cybook Orizon
- Bug Fixes
  o Fix restore to defaults in preferences incorrectly setting
    PDF unwrap factor to 0.0
  o PDF Input: Fix unwrapping of accented characters
  o Do not display dialogs asking for confirmation or showing
    conversion errors when calibre is minimized to system tray
  o calibre server: Fix regression that broke digest
    authentication when the calibre interface language was set to
    non English
  o EPUB Output: Do not raise an error for invalid embedded
    fonts in the input document.
  o RTF Input: Improved conversion of tables, with support for
    border styles on table cells
  o E-book viewer: Fix regression that broke hyphenation. Also
    add more language patterns for hyphenation
  o SONY driver: Fix cover thumbnails being uploaded to wrong
    directory on windows
  o Fix UnicodeDecodeError when displaying a failed metadata
    fetch message
  o Bulk metadata edit: Speed up remove all tags operation
  o MOBI Output: Specify image sizes in pixels instead of em to
    accomodate Amazon's @#$%%#@! MOBI renderer
  o Fix bug preventing customizing of builtin recipes if they
    are not ascii encoded
  o SONY XML cache: Handle case where XML db contains reference
    to a file that does not exist gracefully
* Sat Nov 13 2010 saigkill@opensuse.org
- Update to 0.7.28
- New Features:
  o Update the version of the grahical toolkit (Qt 4.7.1) used
    in the calibre binary builds on windows and linux. This should
    result in a significant speed up for the calibre ebook viewer
  o Driver for Nook Color, Eken M001
  o Add a tweak to turn off double clicking to open viewer
  o Catalog generation: Add indication when a book has no
    formats
  o Advanced search dialog: Add a tab to allow searching
    particular metadata fields easily
  o Conversion pipeline: When using the Level x Table of
    Contents expressions, if a tag is empty but has a non-empty
    title attribute, use that instead of ignoring the tag
- Bug Fixes:
  o Comic metadata reader: Sort filenames aplhabetically when
    choosing an image for the cover
  o Bulk convert dialog: Hide useless restore defaults button.
  o Conversion pipeline: Handle input documents that encode null
    bytes as HTML entities correctly
  o Fix some SONY readers not being detected on windows
  o MOBI Input: Fix images missing when converting MOBI news
    downloads created with Mobipocket reader
  o ODT Input: Handle hyperlinks to headings that have truncated
    destination specifiers correctly
  o Sony driver: Ignore invalid strings when updating XML
    database
  o Content Server: Add day to displayed date in /mobile book
    listing
  o MOBI Input: Do not generate filenames with only extensions
    if the MOBI file has no internal name
  o MOBI Input: Handle files that has the record sizes set
    incorrectly to a long integer
  o Fix not enough vertical space for text in the preferences
    dialog category listing
  o Remove 'sort' from Search and replace destination fields and
    add it to source fields. S&R is no longer marked experimental
  o Edit metadata dialog: Save dialog geometry on reject as well
    as on accept
  o E-book viewer: Fix clicking entries in TOC that point to the
    currently loaded flow not scrolling view to the top of the
    document
  o Fix bug in regex used to extract charset from  tags
  o MOBI Output: Add support for the  tag
* Mon Nov  8 2010 saigkill@opensuse.org
- Update to 0.7.27
  - New Features
  o The book list behavior has changed
  o Added a new HTML output format plugin, which converts the
    input document to a ZIP file. The zip file contains HTML
    pages suitable for display in a website
  o Support for iRiver Cover Story and Digma Q600
  o Add a search button (labelled Go!) to explicitly run a
    search with the text currently in the quick search box
  o Add author to the calibre geenrated book jacket
  o Add the title of the destination book to the merge dialog
    warning message
  o calibre-server: Make auto reload control separate from
  - -devlop with a new command line option --auto-reload
- Bug Fixes
  o Fix book details panel not being updated after a
    delete-merge
  o Fix clicking in the search box launches a search if you
    have search as you type enabled
  o Use a browser widget to display book details for more
    robustness and better performance when vieweing large HTML
    comments
  o Fix cover browser not updated after copy to library and
    delete
  o Fix regression that broke sending non calibre EPUB files to
    the iPad. Also handle failure to set cover in iTunes
    gracefully
  o News download: Workaround lack of thread safety in python
    mechanize, causing corrupted network packets (degrading
    network performance) on Ubuntu Maverick 64bit kernels
  o Convert comments to HTML for book details panel in separate
    thread to make scrolling through the book list faster when
    large comments are present
  o calibre-server: Fix regression that broke --daemonize
  o EPUB Input: Handle ncx files that have  elements with no
    content correctly.
  o SNBOutput: Fixed a bug in handling pre tag
  o MOBI Output: Don't ignore hidden anchors.
  o Fix switching libraries and generating a catalog could
    generate a catalog for the wrong library
  o MOBI Output: Fix regression that broke conversion of
    anchors inside superscripts/subscripts.
  o Content server: Fix various minor bugs
  o Amazon metadata download plugin: Make it more robust and
    add option to auto convert HTML to text
  o Re-arrange send to device menu to make it harder to
    accidentally trigger the send and delete actions
* Sun Oct 31 2010 saigkill@opensuse.org
- updated to 0.7.26
- New Features
  o Check library: Allow wildcards in ignore names field
- Bug Fixes
  o Fix regression in 0.7.25 that broke reading metadata from
    filenames.
  o Fix regression in 0.7.25 that caused original files to be
    mistakenly removed when adding books recursively
  o Fix long series/publisher causing edit metadata in bulk
    dialog to become very large
  o Only add SONY periodical code to downloaded news if output
    profile is set to one of the SONY reader profiles. This is
    needed because the ever delightful Stanza crashes and burns
    when an EPUB has the periodical code
* Tue Oct 26 2010 saigkill@opensuse.org
- updated to 0.7.24
- New Features:
  o Content server: New interface that allows browsing via
    categories, similar to the Tag Browser in the calibre
    interface.
  o Support for the SNB e-book format, used by the Bambook
    e-book reader
  o Driver for the Wifi Kobo
  o Edit metadata dialog: If metadata is downloaded
    successfully, set focus to download cover button
  o News download system: Allow recipes with optional
    subscriptions
  o Templates: Improve the smarten function
  o Linux device mounting: Use udisks, if it is available, to
    mount devices, so that I no longer have to hear bug reports
    from users using distro packages that have crippled
    calibre-mount-helper. You can turn off udisks by setting the
    environment variable CALIBRE_DISABLE_UDISKS=1
  o Implement Drag'n'drop to tags in user categories
  o Ebook viewer: Add command line option to start in full
    screen mode
  o Set completion mode on search boxes to popup completion
  o Update version of jQuery used in content server and
    viewer. Required a little hackery in the viewer, hopefully
    nothing broke
- Bug Fixes:
  o Linux device drivers: Ignore read only partition exported by
    the device
  o E-book viewer: Fix scrolling down with mouse wheel not
    always reaching bottom in windows
  o Smarten punctuation: Fix bug in handling of comments and
* Tue Oct 12 2010 saigkill@opensuse.org
- updated to 0.7.23
- New Features:
  o Drag and drop to Tag Browser. You can use this to
    conveniently add tags, set series/publisher etc for a group of
    books
  o Allow switching of library even when a device is connected
  o Support for the PD Novel running Kobo
  o Move check library integrity from preferences to drop down
    menu accessed by clicking arrow next to calibre icon
  o Nicer, non-blocking update available notification
  o E-Book viewer: If you choose to remeber last used window
    size, the state of the Table of Contents view is also
    remembered
  o Allow moving as well as copying of books to another library
  o Apple devices: Add support for plugboards
  o Allow DJVU to be sent to the DR1000
- Bug Fixes:
  o Searching: Fix search expression parser to allow use of
    escaped double quotes in the search expression
  o When saving cover images don't re-encode the image data
    unless absolutely neccessary. This prevents information loss
    due to JPEG re-compression
  o Fix regression that broke setting of metadata for some
    MOBI/AZW/PRC files
  o Fix regression in last release that could cause download of
    metadata for multiple files to only download the metadata for
    a few of them
  o MOBI Output: More tweaking of the margin handling to yield
    results closer to the input document.
  o Device drivers: Fix regression that could cause geenration of
    invalid metadata.calibre cache files
  o Fix saving to disk with ISBN in filename
  o Fix another regression in the ISBNdb.com metadata download
    plugin
  o Fix dragging to not interfere with multi-selection. Also dont
    allow drag and drop from the library to itself
  o CHM input: handle another class of broken CHM files
* Mon Oct  4 2010 saigkill@opensuse.org
- updated to 0.7.22
- New Features
  o Drag and drop books from your calibre library
  o There were many minor bug fixes for various bugs caused by
    the major changes in 0.7.21. So if you have updated to 0.7.21,
    it is highly recommended you update to 0.7.22
  o Driver for the VelocityMicro ebook reader device
  o Add a tweak to control how articles in titles are processed
    during sorting
  o Add a new format type 'device_db' to plugboards to control
    the metadata displayed in book lists on SONY devices.
- Bug Fixes
  o Fix ISBN not being read from filenames in 0.7.21
  o Fix instant Search for text not found causes unhandled
    exception when conversion jobs are running
  o Fix removing a publisher causes an error in 0.7.21
  o MOBI Output: Fix some images being distorted in 0.7.21
  o Fix regression that broke bulk conversion of books without
    covers in 0.7.21
  o Fix regression that broke add and set_metadata commands in
    calibredb in 0.7.21
  o Workaround for Qt bug in file open dialogs in linux that
    causes multiple file selection to ignore files with two or
    more spaces in the file name
  o Conversion pipeline: Fix regression in 0.7.21 that broke
    conversion of LIT/EPUB documents that specified no title in
    their OPF files
  o Fix regression that broke iPad driver in 0.7.21-
* Sun Oct  3 2010 saigkill@opensuse.org
- updated to 0.7.21
- New Features
  o Automatic backup of the calibre metadata database
  o Virtual columns
  o calibre templates now much more powerful
  o Metadata plugboards: Allow you to perform sophisticated
    transformations on the metadata of a book when exporting it
    from the calibre library.
  o User defined columns are now fully integrated into calibre
  o Driver for the jetBook Mini
  o Add tweaks to control which custom columns the content
    server displays.
  o Bulk downloading of metadata/covers now shows progress and
    can be canceled
  o New plugin to download covers from douban.com. It is
    disabled by default and must be enabled via
    Preferences->Advanced->Plugins->Cover download plugins
  o Add option to change titles to title case in the Bulk
    metadata edit dialog
  o Add option to bulk metadata edit dialog to force series
    renumbering to start with a specified value
- Bug Fixes
  o Fix various bugs that could lead to stale files being left
    in the calbre library when editing title/author metadata on
    windows
  o Fix various regression in the preprocess and de-hyphenation
    code that broke conversion of some files, especially PDF
  ones.
  o Alex driver: Fix books not being placed in sub
    directories. Send covers. And allow sending of FB2
  o MOBI Output: Fix bug that could caused left margins in the
    MOBI file to have twice the size of the left margins in the
    input document, when viewed on the pathetic Kindle MOBI
    renderer
  o MOBI Input: Interpret blockquotes as having a left margin of
    2em not 1em to reflect recent Amazon practice
  o MOBI Output: Remove transparencies from images. Pathetic
    Kindle MOBI renderer strikes again
  o Revert removal of inline toc from news downloaded in MOBI
    format as this makes it unusable with the pathetic Kindle For
    PC application
  o Content server: Remove special characters from filenames in
    download links to accomodate broken browsers like the one in
    the Kindle
  o Conversion pipeline: When rescaling images, dont replace gif
    image data with jpeg data
  o EPUB Input: Ignore OPF files in the EPUB whose names start
    with a period
  o RTF Output: Handle a larger set of broken images in the
    input document
  o epub-fix: Handle dates before 1900
  o Welcome wizard: Prevent the user from choosing a non empty
    folder as her calibre library
  o Automatically enable the Douban metadata download plugins if
    the user choose chinese as the interface language in the
    welcome wizard
  o Linux DBUS notifier: Fix causing freezes on some DBUS
    implementations
  o Workaround for windows limitation when reading from network
    sockets. Should fix issues with large files in calibre
    libraries on network shares.
* Sun Sep 26 2010 saigkill@opensuse.org
- updated to version 0.7.20
- New Features
  o Tweak epub feature.
  o Add button to Edit metadata dialog to trim borders from the
    cover
  o Kobo driver: Add support for setting the ReadStatus to Read
    and correctly deal with empty collections
  o Improved algorithm for removal of hyphens during
    pre-processing
  o EPUB metadata: Don't read timestamp value from epubs as I am
    sick of closing bugs about adding books and having the Date
    not be today.
  o After bulk edit metadata, reselect previously selected
    books.
- Bug Fixes
  o Fix regression in 0.7.19 that broke the By Author and By
    Title category listing in Stanza/Aldiko feeds.
  o MOBI Output: Fix regression that broke sections list in
    downloaded periodicals on Kindle for non-english news sources
  o News download: Rationalize cover processing.
  o Cover cache: load images only in the GUI thread to prevent
    stale files being leftover by set_path due to Windows file
    locking
  o Database: Make renaming of folders on case change more
    robust
  o When adding/replacing files to/in EPUB files, set the GPF
    bit for all files in the archive, to prevent unzip from
    complaining in linux
  o Plugin loading: Handle encoding declarations in .py files
    correctly
  o MOBI input: Another corner case
  o IPC: Store results file in the calibre temp dir and also
    dont die if for some reason removing result file fails. Should
    make adding/saving more robust
  o Database: Fix regression that caused has_cover to create
    empty directories unneccessarily
  o Detection of Alex on unix
  o News download: Don't add inline table of contents when
    downloading news for the Kindle
  o Add prologue and epilogue to default chapter detection regex
  o Kobo driver: Fix issue where books that are read were
    getting their status reset to Unread
  o Device drivers: Fix occassional false positive when matching
    books on device with books in the calibre library
  o Content server: Making serving of large files more
    efficient.
  o GUI device detection: Handle case when user yanks connected
    device before device connection handler is called.
  o Strip leading/trailing whitespace when setting metadata
    using the edit metadata dialog
  o KOBO: Editing the Im_Reading list with SD Card installed
    fixed
* Sat Sep 18 2010 saigkill@opensuse.org
- uppdated to 0.7.19
- New Features
  o The ability to perform search and replace via regular
    expressions in the Bulk Edit metadata dialog
  o Add an option to have calibre automatically convert straight
    quotes to curly quotes. Also handles em/en-dashes
    and ellipses. Found under 'Look & Feel' in the conversion
    options
  o Greatly improve sorting performance on large libraries.
  o Drivers for the SONY PRS-350/PRS-650 and the Sovos E-reader
  o Kobo driver: Add management of the I'm Reading list on Kobo
    via an Im_Reading tag in calibre. See
    http://www.mobileread.com/forums/showthread.php?t=98906 for
    details
  o Conversion pipeline: Add an option to control how hard line
    breaks are removed during preprocessing. See the Structure
    Detection section in the conversion options
  o In the Edit metadata dialog, indicate whether the author
    sort value matches the author value, using a background color
  o Add an option to split the toolbar into two toolbars in
    Preferences->Interface->Look and Feel
  o EPUB Output: Improved design of the 'jacket' page created by
    calibre when using the 'Insert metadata at start of book'
  option
  o PDF Input: Improve line unwrapping, handling of
    hyphens/dashes and quotes. Also handle more specially encoded
    non ASCII characters
- Bug Fixes
  o Fix regression in filename shortening that caused loss of
    filename extension
  o Fix various regressions that could be triggered when using
    search restrictions and/or multi-sorts and connecting a device
  o Database: Fix possible race condition in windows when
    changing title/author during move of book files, that could
    lead to old files not being deleted
  o Conversion pipeline: Don't die if rescaling of image raises
    an exception, just ignore and continue
  o Database: Update has_cover cache when setting/removing
    covers so that the search returns correct results. Also fix an
    exception that could occur when adding books with a db that
    has been upgraded from very old SQL.
  o Workaround for bug that affects some windows installs
    causing white backgrounds on default covers to be rendered as
    yellow
  o Fix handling of non-ASCII chars when rendering series in
    default EPUB cover
  o Fix --start-in-tray switch displays hidden windows in
    metacity, xfwm4 and compiz
  o Conversion pipeline: When setting margins on  explicitly set
    padding to 0 to override and existing padding in the input
    document
  o CHM Input: Ignore missing image files in the input document
  o News download: Fix bug that could break some downloads in
    non ASCII locales
  o TXT Output: When using preserve spaces, output tab
    characters as a sequence of four non-breaking spaces as some
    readers dont handle the 09 char code.
  o PDB Input: Fix bug in conversion of TOC in some PML files
* Sat Sep 11 2010 saigkill@opensuse.org
- updated to 0.7.18
- New Features
  o All new Preferences dialog, with nicer layout and the
    ability to restore settings to defaults
  o Add series info when available to generated cover. Also
    auto-resize the logo on the cover to ensure all text fits
  o On device column: Now indicates when multiple copies of the
    same book are present on the device
  o Driver for the Gemei GM2000
  o Extract fb2 files from zip container when adding to
    calibre. Can be disables by disabling the Archive Extract file
    type plugin.
  o Switch to using raster icons for a small speedup in startup
    time
- Bug Fixes
  o On device column: Fix matching bug when multiple books in
    the library have the same title and author
  o Content server: Use /mobile version for Kindle browser
  o E-book viewer: When adding a bookmark, a default name is
    generated
  o Hide visible menus before clearing toolbar.
  o Batch conversion: Don't overwrite the insert page break
    before setting
  o Catalog generation: Fixed improper title display in catalog
    when title contains ':'. Added 'ondevice' field to CSV/XML
    catalog output (only with connected
    device|folder|iTunes). Added optional 'Series' section to
    generated catalogs with hyperlinks between books and
    series. Tweaks to catalog formatting.
  o Fix regression when checking database integrity with custom
    columns introduced in 0.7.17
  o Sending email: Ignore geenric records when trying to resolve
    domain
  o Fix a bug where the open state of the splitter was not being
    saved on shutdown if the splitter had been closed at startup
    and was opened by dragging the center line
  o MOBI Output: Fix bug generating index when chapter names
    contained non ASCII characters
  o PDF Input: Fix handling of more non ascii characters
  o Content server: Triple AJAX timeout for main book list to 30
    seconds
  o Use ImageMagick instead of Qt to generate thumbnails when
    sending covers to device. Should fix corrupted nook covers on
    some windows installs
  o FB2 Output: Improve creation of sections and fix a couple of
    bugs that could result in invalid output
* Sat Sep  4 2010 saigkill@opensuse.org
- updated to 0.7.17
- New Features
  o Content server: Show custom column data in the book listing
  o Add preference to automatically set a tag when adding books
    (Preferences->General)
  o Add a tweak to create compound search terms. Show error
    message in tooltip when user inputs an invalid search query.
  o Managing multiple libraries: Allow renaming/deleting
    libraries from the Choose library menu
  o Searching on series index is now possible. See the User
    Manual for details.
- Bug Fixes
  o Fix regression in 0.7.16 that broke conversion of HTML files
    with preprocess turned on
  o MOBI Output: When converting an input document that
    specifies an inline TOC in the  but not in the , add it
    correctly. Fixes #6661 (Conversion to MOBI fails to create
    TOC)
  o JetBook driver: Only use JetBook naming scheme for txt, pdf
    and fb2 files.
  o Copy to library action now respects merge preferences
  o Fix bug in email sending when using an SSL connection
  o Kobo driver: Fix bug that prevented metadata caching from
    working correctly
  o Fix regression in 0.7.16 that caused calibre to forget its
    preferences on each restart for new installs on linux
  o News downloads: Cut off long downloaded from URLs
* Sat Aug 28 2010 saigkill@opensuse.org
- updated to 0.7.16
- New Features
  o Driver for the Kindle 3
  o Users can now customize what actions appear in the toolbar
    and context menus via Preferences->Interface->Toolbars
  o Draw a thin broder around the cover in the edit metadata
    dialog.
  o Create (almost) all temporary files in a subdirectory so as
    not to clutter up temp directory
  o FB2 Output: Add option to try to generate FB2 sections from
    the TOC. This may or may not work, depending on the file, so
    use with care.
  o Add an option to remove all tags from selected books in the
    bulk metadata editor.
  o Add a tweak to control how the dates in the Date column are
    formatted.
- Bug Fixes
  o Fix regression in 0.7.15 that broke the Similar books action
    and the add books to library from device action
  o Add ZIP and RAR to the input format order preferences.
  o Update podofo in all binary builds to 0.8.2. Should fix bug
    where setting metadata in some PDF files would cause file
    truncation.
  o Add/remove header wizard: When running on PDF input, replace
    non breaking spaces with normal spaces, since it is hard to
    write regexps to match non breaking spaces with the regex
    builder wizard.
  o Fix crash is user tries to switch libraries whiel a device
    is being detected
  o Title sort now ignores leading quite character. Only applies
    to newly added books.
  o Conversion pipeline: Don't fail if parsing extra css raises
    an exception. Instead just ignore it.
  o SONY driver: Use the tz field (available in newer readers)
    to set timestamps correctly, when available.
  o Shortening file paths: Handle the case of very long
    filenames with periods in them.
* Tue Aug 24 2010 saigkill@opensuse.org
- placed python-django-tagging, python-imaging and python-genshi to
  our Repository.
- added ImageMagick, python-django-tagging, python-imaging and
  python-genshi to Requires.
* Tue Aug 24 2010 saigkill@opensuse.org
- placed python-cherrypy to our Repo
- added python-cherrypy to Requires and BuildRequires
* Tue Aug 24 2010 saigkill@opensuse.org
- placed python-pypdf into our Repository
- added python-pypdf as Requires and BuildRequires
* Mon Aug 23 2010 saigkill@opensuse.org
- removed calibre-rpmlintrc
- linked python-odfpy to home:thomas-schraitle:calibre
- added python-odfpy to Requires and BuildRequires
* Mon Aug 23 2010 toms@suse.de
- Require liberation-fonts
* Sun Aug 22 2010 saigkill@opensuse.org
- Update to 0.7.15:
  * New Features
  o Multiple library support: Various improvements to make using
    multiple calibre libraries easier.
  o Content server: Allow setting a restriction so that the
    server shares only some of the books in the library.
  o Speed up metadata editing. Small speed up for single book
    editing and major speedup for bulk editing.
  o Drivers for the Kogan and Spectra e-book readers and the
    Samsung Captivate
  o Allow calibredb to manage saved searches stored in the
    library.
  o Add a tweak to automatically connect to a folder on
    startup. Accessible via Preferences->Advanced->Tweaks
  o You can specify a restriction based on a saved search to be
    applied on calibre startup
  o All actions in toolbar/context menus have been refactored to
    become plugins
  * Bug Fixes
  o Content server: Fix Saved Search and User Category handling
    in the OPDS feeds.
  o Fix regression that broke reading covers from CBR files
  o Fix regression in 0.7.13 that broke Comic Input when image
  output format was set to JPEG
  o Fix Comic Input default settings not being used when bulk
    converting comics
  o SONY driver: Fix series order being lost when metadata
    management is set to manual
  o Fix behavior of Tag Browser and search restictions when
    switching libraries
  o Do not allow the user to override the default tweaks or the
    hyphenate javascript. Also if a file is not found, do not use
    the user location as the default base.
  o Catalog generation: Changed default regex for genre tags to
    allow punctuation within genre tags.
  o Linux environment: Use a temporary dir as the config
    directory if write access to the normal config directory is
    unavailable. Can be overriden by using the
    CALIBRE_CONFIG_DIRECTORY environment variable
  o Jobs window now remebers its size and can be launched by a
    keyboard shortcut (Alt+Shift+J)
  o Fixing regression that broke clicking on links in the Book
    Details window
  o Parallel job management: Do not allow new jobs to start when
    all cores are used.
  o Fix a bug that could cause the jobs window to show details
    for the wrong job
  o Workaround for PyQt4/util-linux conflict on gentoo
* Mon Aug  9 2010 saigkill@opensuse.org
- Update to 0.7.13:
  * New Features
  o Add a button to the edit metadata dialog to generate a cover
    based on the book metadata
  o When using series or title in a save template to generate a
    file path, remove leading prepositions. This behavior can be
    controlled via a tweak.
  o News download: When downloading news for the Kindle, do not
    add date to the title, to allow the Kindle's periodical
    archiving to work.
  o Content Server OPDS feeds: Grouping of items by first
    alphabet is now case-insensitive.
  o Do not allow the user to use save to disk to save files into
    the calibre library
  o Switch to a new C based API for using ImageMagick. More
    robust and a minor speedup when doing image manipulations
  o Move cover downloading to a plugin based API. You can now add
    new cover sources to calibre using plugins.
  * Bug Fixes
  o Content server OPDS feeds: Handle the case when the author
    field is blank
  o TXT Input: Strip out illegal chars from txt files.
  o Save to disk/send to device templates: Always render
    {series_index} as an empty string when the book has no series.
  o PD Novel driver: Remove covers when deleting books
* Fri Aug  6 2010 toms@suse.de
- Corrected SPEC file:
  Used chmod to remove any x flag for the recipes files in
  resources/recipes/
* Sat Jul 31 2010 saigkill@opensuse.org
- Updated to Version 0.7.12:
  * New Features
  o EPUB metadata: When setting metadata in an EPUB file, if it
    has a well defined image based cover, update it
  o Support for Droid X, Samsung Vibrant and Promedia ebook
    reader
  o Add entry to Connect/share menu to conveniently stop and
    start the Content Server
  o News download: Make the navbars on the section index pages
    more useful, adding links to net and previous section
  o Add a button to reset confirm dialogs to
    Preferences->General
  * Bug Fixes
  o Fix crash in edit metadata dialog if you click OK before
    cover download completes
  o Kobo driver: Show a warning when the user tries to
    export/view .kobo files. Also add support for the new sofroot
    vendor id
  o Update check. Do not be fooled by a redirecting proxy when
    checking for new version
  o Add book count to tooltip of library button in toolbar
  o Content server: When serving OPDS feeds send the correct
    content-type header.
  o PDF Output: Don't insert blank pages before every individual
    HTML file in the ebook.
  o Fix saving of cover when path to book folder contains non
    ascii characters
  o Fix regression that broke showing send to actions for
    multiple email accounts
  o Fix bug in handlling of hexadecimal entities
  o SONY driver: More fixes to handle broken media.xml files
  o Linux installer: Fix rendering of viewer icon and restrict
    all icons to 128x128 since GNOME can't handle large icons
  o RTF Input: Fix handling of hard linebreaks
  o RTF Output: Fix regression that broke rendering of bold and
    italic text-
  o Fix a typo that caused a harmless error message after
    setting preferences
  o Linux build system: No longer search for poppler-qt4
    libraries as they are not needed
* Sun Jul 25 2010 saigkill@opensuse.org
- updated to Version 0.7.10:
  * New Features
  o Allow user customization of static resources such as icons
    and templates
  o Split the 'Send to device' button into two buttons,
    'Connect/share' and 'Send to device'. The new 'Send to device'
    button will now only be available when a device is connected.
  o Store column layout, saved searches and user categories
    seprately per calibre library. This makes it possible to
    easily switch between libraries with different custom column
    setups
  o See the last modofied date for each format in the edit
    metadata dialog via a tooltip
  o PD Novel driver: Add support for uploading cover thumbnails
    to device
  o More sophisticated metadata extraction from HTML files
  * Bug Fixes
  o Fix problems with a few windows installs caused by the
    upgrade to Qt 4.6.3 in the previous release. These would
    manifest as a not working Add Books button, or deletes not
    actually deleting files, etc.
  o Restore configurability of toolbar, which was temporarily
    removed in 0.7.9. You can once again set icon size via
    Preferences->Interface
  o Fix regression in iTunes driver in 0.7.9 when sending series
    info
  o Search: Fix parsing of search terms that contain a word that
    starts with 'and' or 'or' and is not the first word
  o When merging records also merge metadata in custom columns
  o When scrolling to show a particular row, handle the case
    when the first column is a custom column
  o Fix SD card detection for The Augen Book
  o CHM Input: Fix a couple of bugs that could cause crashes
  o Conversion pipeline: Handle zero width elements with non
    zero indents gracefully
* Mon Jul  5 2010 toms@suse.de
- Corrected spec file:
  * Corrected version number
  * Removed calibre-src.calibre.linux.py.diff
* Sun Jul  4 2010 saigkill@opensuse.org
  Updated to Version 0.7.7:
- New Features
  o Support for the Nokia E52
  o Searching on the size column
  o iTunes driver: Add option to disable cover fetching for
    speeding up the fetching of large book collections
- Bug Fixes
  o SONY driver: Only update metadata when books are sent to
    device.
  o TXT Input: Ensure the generated html is splittable
  o Fix infinite loop in default cover generation.
  o HTML Input: Fix a parsing bug that was triggered in rare
    conditions
  o HTML2Zip plugin: Do not replace ligatures
  o iTunes driver: Fix transmission of non integral series numbers
  o Simplify implementation of cover caching and ensure cover
    browser is updated when covers are changed
  o PDF metadata: Fix last character corrupted when setting
    metadata in encrypted files.
  o PDF metadata: Update the version of PoDoFo used to set
    metadata to 0.8.1. Hopefully that means more PDF files will work
  o Device drivers: Speedup for dumping metadata cache to devices
  on Windows XP
  o EPUB Output: Ensure that language setting is conformant to the
    specs
  o MOBI Output: Fix a memory leak and a crash in the palmdoc
    compression routine
  o Metadata download: Fix a regressiont at resulted in a failed
    download for some books
* Mon Jun 28 2010 saigkill@opensuse.org
  Update to Version 0.7.6:
- New Features:
  o Add support for the new firmware of the Azbooka
  o A few speedups for calibre startup, should add up to a few
    seconds of startup time on slower machines
  o Support for the Sweem MM300
  o Add keyboard shorcut for Download metadata and covers
- Bug Fixes:
  o Fix regression in 0.7.5 that broke conversion of malformed
    HTML files (like those Microsoft Word outputs)
  o Don't download tags from librarything, as the tagging there
    is not very good
  o Add mimetype for FB2 so that it can be served by the content
    server
  o Ensure cover is not resized to less than the available space
    in the Edit Meta Information dialog
  o SONY driver: Only update collections when sending book to
    device for the first time
  o calibre should now work on windows when the location for the
    library contains non-ascii characters
  o Cover browser once again distorts instead of cropping covers
    that have an incorrect aspect ratio
  o ISBNDb metadata plugin: Fix bug causing only first page of
    results to be fetched
  o Move iTunes driver to the bottom so that it doesn't interfere
    with device detection for people that have iphones and an
    ereader plugged in
* Sat Jun 26 2010 saigkill@opensuse.org
  Updated to Version 0.7.5:
- New Features
  o New driver for the Kobo featuring closer integration with the
    device.
  o Support for the Dell Streak, Eken Android tablet and the
    Astak Mentor EB600
  o New series type custom column
  o Add option in Send to device menu to connect to iTunes
    without any iDevice (experimental)
  o iPad driver: Make setting iTunes Category from series
    optional. News download now optimizations for iPad output.
  o Add option to disable book cover animation
  o Edit meta information dialog: Remember last used size and
    splitter position.
  o Metadata download: If any results have a published date,
    ensure they all do
  o SONY driver: Add a preference setting in
    Preferences->Add/Save->Send to device to control how
    colelctions are managed on the device by calibre
  o Metadata download: Filter out non book results. Also sort
    results by availability of covers for the isbn
  o Bulk editing for device collections in the device view via
    the context menu
- Bug Fixes
  o When converting books using the calibre GUI, set the language
    of the output book to be the same as the language of the User
    Interface, instead of undefined. Fixes use of dictionary in
    iBooks
  o PDF Output: Fix setting top/bottom margnis has no effect
  o Conversion pipeline: Fix typo causing remove footer regex to
    always fail
  o Handle device being yanked with queued device jobs gracefully
  o Conversion pipeline: Handle deeply nested XML structures
  o Conversion pipeline: Fix handling of lists with a specified
    left margin
  o Restore workaround for ADE buggy rendering of anchors as
    links. However, make it overridable by extra CSS
  o Fix LibraryThing metadata download plugin
  o Fix multiple ratings displayed in Tag Browser for some legacy
    databases
  o Fix invocation of postprocess file type plugins plugins
  o HTML Input: Handle @import directives in linked css files.
  o HTML Input: Handle absolute paths in resource links on
    windows correctly.
  o E-book viewer: Handle font-face rules specify multiple
    families to be substituted
  o Cover browser: Set aspect ratio of covers to 3:4 instead of
    2:3. Crop rather than distort covers whoose aspect ratio is
    different from this. Antialias the rendering of the central
    cover
  o Reset Tag browser if the text in the search box is edited
  o Fix detection of SD card in Samsung Galaxy windows driver-
* Sun Jun 20 2010 saigkill@opensuse.org
  Updated to Version 0.7.4:
- Bug Fixes
  o Fix regression in 0.7.3 that broke creating custom columns of
    rating or text types
  o Fix cover browser breaking if you click on a book in the book
    list while cover browser is animated
  o Fix a bug that could be triggered with the new book details
    pane if a book has a zero size cover
  o SONY driver: Fix bug preventing the editing of collections in
    the device view
* Fri Jun 18 2010 saigkill@opensuse.org
  Updated to Version 0.7.3:
- New Features:
  o The Tag Browser now display an average rating for each item
  o Editable author sort for each author
  o When downloading metadata, also get series information from
    librarything.com
  o Redesign of the Book Details pane
  o New User Interface layouts
  o You can now add books directly from the device to the calibre
    library by right clicking on the books in the device views
  o iPad driver: Create category from series preferentially, also
    handle series sorting
  o SONY driver: Add an option to use author_sort instead of
    author when sending to device
  o Hitting Enter in the search box now causes the search to be
    re-run
  o Boox driver: Make destination directory for books customizable
  o Add plugin to download metadata from douban.com. Disabled by
    default.
  o OS X/linux driver for PocketBook 301
  o Support for the Samsung Galaxy and Sigmatek EBK52
  o On startup do not focus the search bar. Instead you can acces
    the search bar easily by pressing the / key or the standard
    search keyboard shortcut for your operating system
- Bug Fixes:
  o iPad driver: Various bug fixes
  o Kobo Output profile: Adjust the screen dimensions when
    converting comics
  o Fix using Preferences when a device is connected causes items
    in device menu to be disabled
  o CHM Input: Skip files whoose names are too long for windows
  o Brighten up calibre icon on dark backgrounds
  o Ignore 'Unknown' in title/autors when downloading metadata
  o Fix regression that broke various entries in the menus -
    Preferences, Open containing folder and Edit metadata
    individually
  o EPUB metadata: Handle comma separated entries in  tags
    correctly
  o MOBI Output: Fix underlines not being rendered
  o EPUB Output: Remove workaround for old versions of Adobe
    Digital Editions' faulty rendering of links in html. calibre no
    longer forces links to be blue and underlined
  o Fix a bug that could cause the show pane buttons to not show
    hidden panes
  o Fix Tag Editor does not reflect recently changed data in Tag
    Catagory Text Box
  o Content server: Fix sorting of books by authors instead of
    author_sort in the main and mobile views
  o Cover cache: Resize covers larger than 600x800 in the cover
    cache to reduce memory consumption in the GUI
  o EPUB Output: Default cover is generated is now generated as a
    JPEG instead of PNG32, reducing size by an order of magnitude.
  o Cover Browser: Scale text size with height of cover
    browser. Only show a reflection of half the cover. Also restore
    rendering quality after regression in 0.7.1
  o Book list: Do not let the default layout have any column wider
    than 350 pixels
* Tue Jun  8 2010 toms@suse.de
  Updated to version 0.7.1:
- New Features
  * Content server: Add option to control category grouping in
  oPDS feeds
  * Make the book details pane occupy the full lower part of the
    window
  * Add true and false searches for date based columns
- Bug Fixes
  * iPad driver: Various bug fixes.
  * SONY driver: Fix Launcher partition being detected as storage
    card in linux
  * Fix news downloading breaking on windows systems with local
    encoding other than UTF-8.
  * SONY driver: Fix problem caused by null titles
  * Make the new splash screen not always stay on top
  * When setting an image with transparent pixels as the book
    cover, overlay it on a white background first. Fixes
    transparent covers getting random backgrounds.
  * Content server: Fix stanza integration when entering the
    server URL my hand
- Improved news sources
  * Gizmodo
  * Vreme
* Sat Jun  5 2010 toms@suse.de
- Updated to version 0.7.0
  * User Interface improvements
  * Device driver improvements
  * Performance improvements
  * Improvements in the conversion and metadata engines
  * Creation of catalogs
  * E-book viewer improvements
  * USB syncing with the iPad
  * Incompatible changes
- SPEC file changes:
  * removed udev rule
  * Recreated calibre-no-update-manpage.diff
* Sat May 29 2010 saigkill@opensuse.org
- updated to version 0.6.55
- New Features
  o Support for the Nokia E71X
  o EPUB Output: Generate a default one entry TOC if no TOC is
    present. This allows the EPUB to pass epubcheck and work on the
    Kobo
  o Kobo driver: Add support for storage card
  o PDF Output: Improved cover and comic handling
  o EPUB metadata: When setting authors, always move the new
    dc:creator element to the top so broken implementations don't
    get confused
- Bug Fixes
  o Make the HTML shown in the regex builder closer to that
    actually processed by the conversion pipeline.
  o Fix tab ordering in Bulk edit meta information dialog
  o EPUB Input: Ignore __MACOSX directories inside the EPUB file
  o EPUB Input: Raise an appropriate error for DTBook EPUB files
  o EPUB Output: Use correct SVG code when not preserving aspect
    ratio for covers
  o Use PNP drive number based sorting on windows when the device
    has identical main memory and card ids
* Sun May 16 2010 saigkill@opensuse.org
- changed BuildRequires to newer podofo version
* Sun May 16 2010 saigkill@opensuse.org
- update to version 0.6.53
- New Features
  o Clean up GUI initialization and add support for restoring
    corrupted databases automatically
  o Make proxy detection more robust on windows and OS X. calibre
    now queries OS X Network Settigns if no environment variables
    are set. Also handle proxies with a trailing slash correctly
  o Add EPUB advanced formatting demo to User Manual
  o Support for the Booq Avant, Azbooka and the Samsung GT-I5700
  o Backwards search in the E-book viewer
  o calibredb: Add ability to create empty books in the
    database.
  o Conversion pipeline: Support for the :first-letter pseudo
    selector
  o Interpret a Keyboard interrupt (Ctrl+C) as a request to quit
    the main GUI
  o CBC Input: Handle comics.txt encoded in UTF-16 with a BOM
- Bug Fixes
  o HTML Input: Fix silly bug in case sensitivity detection
  o Kobo driver: Show all sideloaded content on the device.
  o EPUB metadata: Fix bug with relative apths in encryption
    detection when reading cover
  o E-book viewer: Fix next page scrolling when current document
    is just a little more than a screenfull. Also use a more robust
    method to insert blank space at the end of the document when
    the last screenfull is partially empty.
  o EPUB metadata: Allow deletion of series/tags/isbn from EPUB
    files when Saving to Disk
  o Fix regression that caused temporary blank line at the bottom
  of the books list when adding duplicates
  o Add icon for RTF
  o Amazon metadata: If ISBN is not found, don't report an error
    message.
  o EPUB Input: Fix typo that caused incorrect processing of EPUB
    files with more than one identifier element and encrypted fonts
  o Fix bug that caused send to device to send multiple copies to
    the device if you had previously used Prefrences
  o Linux prs 500 udev rule: Use SUBSYSTEMS instead of the
    deprecated BUS
  o PML2PMLZ plugin: Actually compress the PML file stored in the
    PMLZ archive
  o SONY drivers: Fix regression that broke collection ordering
    by series when sending to device. And fix another rare error
    condition.
  o CHM Input: Regression that broke CHM conversion on OS X.
  o Fix PDB created in Dropbook not convertable by Calibre
* Tue May 11 2010 toms@suse.de
- Fixed man problem (again)
- Merged %%exclude pattern for calibre-uninstall from hgraeber
* Sat May  8 2010 saigkill@opensuse.org
- updated to Version 0.6.52
- New Features
  o Support for the Kobo Reader and the HTC Desire
  o PDB Input: Add support for PDB files created with incorrect
    encodings
  o EPUB Output: Make the file size splitting algorithm more
    intelligent. If a split results in a tree that is very small,
    choose another split point.
  o Add an entry to the Fetch News menu to fetch all scheduled
    news
  o MOBI Output: When inserting metadata, hide the searchable
    version of the tags (append with ttt). They are still
    searchable, but not visible.
- Bug Fixes
  o HTML Input: Handle case sensitive file systems on OS X
  o EPUB Output: When rescaling PNG images, write out the
    rescaled data in PNG format as ADE cannot handle JPEG data in
    a PNG file
  o SONY drivers: Fix corner case that could cause errors when
    transferring books with series to the device.
  o Allow users to set the content server port to < 1025 (system
    ports) with a warning.
  o Don't popup an error message when adding books if the cover
    is not a valid image
  o SONY drivers: Fix bug that prevented detection SD cards that
    had the Sony Reader/database folders, but no cache.xml
  o EPUB Input: Handle invalid EPUB files that have manifest
    entries pointing to non existent files
  o Fix the get cover/metadata from specific format buttons when
    the user has chosen to read metadata only from filenames
  o Conversion pipeline: More robust conversion of HTML tags to
    text when detecting structure
  o Fix 'Open containing folder' does not work if the path name
    contains '#'
* Wed May  5 2010 toms@suse.de
  SPEC:
- Corrected packager in calibre/src/calibre/utils/help2man.py
  from bz2 -> gzip
- "Renamed" file *.patch -> *.diff
* Mon May  3 2010 saigkill@opensuse.org
- fixed rpmlint Errors (Manpage bz2 Errors)
- disabled automatic information service
* Sun May  2 2010 saigkill@opensuse.org
- Updated to Version 0.6.51
- fixed broken build of openSUSE 11.1
* Wed Apr 28 2010 toms@suse.de
- Dealing with locale problems:
  . Fixed locale files: Use /usr/share/locale/LANG/LC_MESSAGE
    instead of /usr/share/calibre/...
  . Renamed locale messages.mo -> calibre.mo
  . Removed qt.qm. Depends on
    /usr/share/qt4/translations/qt_LANG.qm now
  TODO: Fix manpage warnings
* Tue Apr 27 2010 saigkill@opensuse.org
- updated to version 0.6.49
- changed tar.gz -> tar.bz2
* Tue Apr 20 2010 toms@suse.de
- tar.gz -> .tar.bz2
* Mon Apr 19 2010 saigkill@opensuse.org
- Updated to Version 0.6.48
- Added lang Package
- fixed some rpmlint Issues
* Sat Mar 13 2010 toms@suse.de
- Update 0.6.45 (11 Mar, 2010)
  New Features
  * Option for more aggressive duplicates detection when adding
    books
    Closes tickets: 5016
    "There is now an option in Preferences->Add/Save that will
    cause calibre to try to detect duplicates based on title
    and author similarity. If a duplicate is found, calibre
    will automatically merge files intot he existing entry,
    instead of creating a new one."
  * Support for setting metadata in Topaz files and getting pdf
    anntations from a Kindle
  * ODT Input: Fix handling of mixed ordered and un-ordered
    lists
  * Support for the Samsung Moment
    Closes tickets: 5077
  Bug Fixes
  * Fix generated list of formats when generating catalog in CSV
    format
    Closes tickets: 5092
  * CHM metadata: Fix unicode handling
    Closes tickets: 5080
  * Iriver story driver: Put uploads into the Books directory
  * Improved iRex DR800 support
    Closes tickets: 5082
  * When creating ZIP/EPUB files encode all file names in UTF-8
    and set the UTF-8 bit marker. When extracting from a
    ZIP/EPUB file, if the UTF-8 bit marker is not set, still
    assume that the file name is encoded in UTF-8. If UTF-8
    decoding fails try to detect character encoding using
    chardet. This is because  most ZIP/EPUB files calibre comes
    across seem to be utf-8  encoded.
  New news sources
  * TAZ DigiABO by Lars Jacob
  * Elsevier.nl by Darko Miletic
  * News Observer by Krittika Goyal
  * Comics.com by Starson17
* Thu Feb  4 2010 toms@suse.de
- Update 0.6.37 (01 Feb, 2010)
  New Features
  * E-book viewer: Add support for viewing SVG images
  * Add category of Recently added books when generating catalog
    in e-book format
  * OS X: Allow adding of books to calibre via drag and drop on
    the calibre dock icon
  * Add support for masthead images when downloading news for
    the Kindle
  * MOBI metadata: Allow setting of metadata in old PRC files
    without EXTH headers as well
    Bug Fixes
  * Changing the date in Dutch
    Closes tickets: 4732
  * Fix regression that broke sending files to unupdated PRS
    500s
  * MOBI Input: Ignore width and height percentage measures for
    <img> tags.
    Closes tickets: 4726
  * EPUB Output: Remove <img> tags that point to the internet
    for their images as this causes the ever delicate ADE to
    crash.
    Closes tickets: 4692
  * Comic Input: Handle UTF-8 BOM file names
    Closes tickets: 4721
  * Fix bug preventing the the use of indices when setting save
    tn title as text optional
  * Fix error while sending book with non-ascii character in
    title/author to device on linux
    Closes tickets: 4690
  * Fix reset cover in edit meta information dialog does not
    actually remove cover
    Closes tickets: 4731
  New news sources
  * Kamera Bild by Darko Miletic
  * The Online Photographer by Darko Miletic
  * The Luminous Landscape by Darko Miletic
  * Slovo by Abelturd
  * Various Danish newspapers by Darko Miletic
  * Heraldo de Aragon by Lorenzo Vigentini
  * Orange County Register by Lorenzi Vigentini
  * Open Left by Xanthan Gum
  * Michelle Malkin by Walt Anthony
  * The Metro Montreal by Jerry Clapperton
  * The Gazette by Jerry Clapperton
  * Macleans Magazine by Nick Redding
  * NY Time Sunday Book Review by Krittika Goyal
  * Various Italian newspapers by Lorenzo Vigentini
  Improved news sources
  * The Irish Times
  * Washington Post
  * NIN
  * The Discover Magazine
  * Pagina 12
* Mon Nov 16 2009 toms@suse.de
- Update 0.6.24 (16 Nov, 2009)
  * Device drivers: Ignore files on the device when there is a file
    system/file name encoding error
  * Add option to download only social metadata. Fixes #4015
    (Option to Update Only Parts of Metadata)
  * New recipe for The Havard Business Review
  * Conversion pipeline: Respect UTF-8/32 BOM mark when decoding
    files in addition to UTF-16 BOM. Fixes #4025 (ebook convert
    chokes on a complex CSS file)
  * Fix #4028 (Social Metadata Bulk Bug)
  * Fix #4022 (Incorrect Rating in Bulk)
  * calibredb list: Do not URL encode the href fields for the
    stanza output format
  * Update bundled odfpy library for conversion of ODT files to
    version 0.9.2
  * Fix #3944 (More than 2 rating stars not fit in the rating
    column after resize)
  * Fix pml parsing changes as they break PDB eReader input
    badly.
  * New recipe for Fokke en Sukke cartoon by kwetal
  * Output resolved conversion options in conversion log
  * Implement #3885 (Allow bulk swap Author and Title tags)
  * Restore all sections to the Guardian newspaper download
  * Bulk conversion: Add option to disable using per-book settings
    from a previous conversion
  * Improved recipe for The Philadelphia Inquirer
  * Social metadata download: If the user specifies that they
    don't want social metadata, don't get tags from the basic
    metadata sources either
* Mon Nov 16 2009 toms@suse.de
- Corrected Spec file and removed rpmlint warnings
  TODO: deal with language *.mo files
* Thu Nov 12 2009 toms@suse.de
- Updating to 0.6.21. RPM is not ready yet, just testing...
* Fri Aug  7 2009 toms@suse.de
- Update 0.6.5 (03 Aug, 2009):
  * PML Input: Various fixes
  * Fix #3057 (Viewer Cuts Off MOBI File)
  * EPUB Output: Pass through font-face rules. Fixes #3042
    (Calibre ignores extra_css in recipe)
  * Fix downloading of news that has non-English characters in its
    title on windows. Fixes #3005 (RSS Fetching from zaobao.com
    still fail)
  * Fix #3061 (TOC not created converting from FB2)
  * Fix #3059 (Blows up real good parsing a Mobipocket file)
  * Fix #3028 (Field "Published" below 1900 make catalog empty on
    iPhone)
  * Fix #3047 (Metadata on device, fall back to file name)
  * Fix detection of Be Book on windows when no storage card is
    present.
    Fixes #2974 (Be Book not reconized)
  * Stanza feed: Show newly added books first
  * Fix #3050 (FB2 Output error)
  * Switch to using poppler to read PDF metadata. Hopefully is
    faster/more stable. Fixes #3041 (version 0.6.3 doesnt delete
    temp files)
* Sun Aug  2 2009 toms@suse.de
  Update to version 0.6.4 (31 Jul, 2009):
  * Initial implementation of aq driver for the Irex Illiad
  * Add OS X support to the Illiad DR1000 driver
  * Fix #3019 (Problem converting prc to epub)
  * EPUB Output: Remove hyperlinks with no content as they cause
  rendering artifacts in browser based renderers
  * Fix #3010 (Special characters in tags are not escaped)
  * Handle author names that end with a period correctly when saving
  a single format to disk
  * Fix #2997 (Be Book)
  * Fix #3016 (lxml.etree._Element' object has no attribute 'href)
  * Fix #3022 (Receiving error during convert from pdf to any file)
  * Various fixes form conversion from PML and PDF
  * Improved Newsweek recipe (thanks to GRiker)
  * RTF Input: Support extraction of images (JPEG/PNG only)
  * Fix #3009 (PRS500 won't connect)
  * Refactor the device driver system to support devices from
  manufacturers that don't bother to assign unique ids to their
  devices. Preliminary drivers for CyBook? Opus (windows/os x) and
  Cool-er (windows only)
  * Implement searching the calibre catalog in the Stanza.
  Fixes #3014 (Support searching from stanza)
* Tue Jul 28 2009 toms@suse.de
  Update to version 0.6.2 (27 Jul, 2009);
  * EPUB Output: Fix default cover page to display correctly in
  Adobe Digital Editions
  * Make reading of metadata from files on the device configurable
  (via Preferences->Plugins->Device Interface plugins). If turned
  off, it will make loading the list of books on the device much
  faster. Also make storing of e-books into sub folders on the
  device configurable.
  * Add an output profile for the 5-inch Jet Book?. Fix #2950
  (ebook-meta.exe 0.6.0 doesn't work at all)
  * Fix #2920 (Ebook viewer not working)
  * Fix #2807 ("Reset Quick Search" button does not reset the status
  of the tag toggle switches)
  * Fix #2904 (created epub from odt file, tested in epubcheck,
  errors on images)
  * Fix #2954 (No header, extra line at bottom.)
  * Fix one final case that could cause 'Unknown' to show up in the
  authors list even when authors are specified
  * Fix #2953 (missing &#236;)
  * Make handling of malformed/fragmentary HTML more robust
  * EPUB Output: Fix generated OPF to be compatible with the asinine
  epubchecker. Also fix bug that was causing the default cover to
  use the date even when authors are present.
  SPEC file changes:
  * Requires now podofo and libpodofo0_6_99-devel
  * Requires python-qt4-devel >= 4.5.0
  * Added patch for src/calibre/utils/fonts/fontconfig.c
* Sun May 31 2009 toms@suse.de
  Update to version 0.5.14 (29 May, 2009)
  * New recipe for Electrolese by Oliver Niesner. Also updated
  recipes for Heise, Sueddeutsche and ZDnet
  * Fix #2515 (eBook Viewer cannot open TAZ epub file)
  * New recipe for PHD Cmics by Rafardeon
  * New recipe for Carta by Oliver Niesner
  * Updated recipe for The New Yorker
  * Fix #2497 (Scientific American recipe not working)
  * Fix #2489 (handle softbreaks in RTF files)
  * Implement #2478 (Updated recipe Vreme)
  * Fix title of Sueddeutsche recipe and fix generation of MAN pages
  in unicode environments
* Wed May 27 2009 toms@suse.de
  Update to version 0.5.13 (21 May, 2009)
  * Updated recipe ro the Times Online
  * Add genshi license
  * Fix Newsweek recipe for redesigned site
  * Fix #2449 (Crashing on mac os X 10.5.7 when cancel metadata search)
  * Fix #2450 (Crash on send to PRS-700)
  * New recipe for slashdot
  * Fix #2475 (Calibre 0.5.12 Conversion Error)
  * Fix #2465 (Calibre fails after running Globe Trotter? Connect on
  OS X 10.5)
  * Various Hungarian news recipes by Ezmegaz
  (Skipped versions 0.5.8 to 0.5.12)
* Fri Apr 17 2009 toms@suse.de
  Update to version 0.5.7 (15 Apr, 2009)
  * Handle periods better when reading metadata from filenames
  * New recipe for Moneynews by Darko Miletic
  * Updated recipes for Linux devices and Toms Hardware (German)
  * Implement #2096 (Move deleted books in the trash folder)
  * Allow single click fetching of covers in the Edit metadata
  dialog. Now calibre will automatically try to get the ISBN
  needed to fetch the cover based on title and author of the
  book.
  * Fix #2257 (Updated recipes with fixes for epub image problem)
  * Support for writing metadata to PDF files (thanks to John
  Schember)
  * New recipe for Der Standard by Gerhard Aigner
  * Fix #2258 (cancel button not wide enough)
  * Device drivers: Do not check for ebooks in subdirectories on
  devices that do not support subdirectories
  * Fix #2255 (calibre does not handle images with comma in their
  name)
  * New recipe for Hessisch Niedersächsische Allgemeine by Oliver
  Neissner
  * Speed up reading of metadata from MOBI files (thanks to John
  Schember)
  * Fix #2261 (Conversion metadata problem)
  * Implement #2277 (Remove empty feeds when fetching news with
  recipes)
  * New recipe for Die Presse by Gerhard Aigner
  * Fix #2252 (--profile should resize pictures too)
  * Fix #2273 (Little bug in Calibra Server)
  * Fix #2283 (Updated recipe Vreme)
  * Implement a --add-simple-plugin option for calibre-debug that
  makes it easy to add calibre plugins distributed as .py files
  * MOBI Output: Fix regression that was preventing the creation of
  pagebreaks between the contents of different HTML files in the
  input.
  * Fix #2256 (Interresting bug with epub format)
  * New recipe for NZZ Online by Darko Miletic
* Thu Apr  9 2009 toms@suse.de
  Update to version 0.5.6 (08 Apr, 2009)
  * Preliminary support for the Netronix EB600
  * MOBI Input: Strip null characters. Fixes #2242 (Calibre only
  converts first chapter of document)
  * Fix #2061 (Proper locale support)
  * Fix #2202 (Can't Manually Set Series to Book 0)
  * Speed up adding books to an already large collection
  * Fix #2240 (New Yorker download has issues)
  * Fix #2205 (Ebook viewer doesn't start if no book selected)
  * New recipe for the Arizona Star by Darko Miletic
  * New recipe for MSDN Magazine by Darko Miletic
  * Fix #2217 (New recipe: Corriere della Sera (Italian and English))
  * Remove recipe for The International Herald Tribune, since the
  paper no longer exists
  * Fix #2236 (Updated Tom's Hardware recipe)
  * Fix #2204 ("Delete news when sent" does not work)
* Tue Apr  7 2009 toms@suse.de
  Update to version 0.5.5 (02 Apr, 2009):
  * Fix stream descrambling in lrf2lrs
  * Fix bug causing dates for downloaded news to be in Spanish. Fixes
  [#2198] (Bug fix of recipe La Prensa - Nicaragua)
  * Fix regression in windows that was causing downloaded news to
  not have a cover
  * Fix #2200 (Recipe update: Exiled online)
  * Fix #2193 (PRS-700 epub flow_size crash)
* Wed Apr  1 2009 toms@suse.de
  Update to version 0.5.4 (01 April 2009):
  * Fix #2177 (Google ePub TOC)
  * Implement #2173 (New recipes)
  * Fix #2175 (Error when trying to open ebook viewer)
  * New recipe for La Prensa Nicaragua by Darko Miletic
  * Add a button to test email settings in the Preferences dialog,
  should help with debugging email problems.
  * Fix #2144 (Calibre not searching by title/author when using
  Google Books API)
  * Fix bug in ebook viewer that could cause it to hang wen finding
  a bookmark
  * Fix #2182 (I would like larger margins)
  * Fix nasty bug that was preventing the use of a mail server to
  send email
  * Fix #2168 (Recipe update - B92)
  * Fix #2186 (Remove eMail button does not work)
  * Fix #2174 (Error with epub viewer)
  * EPUB Output: Have the GUI use a UUID for package identifier when
  creating EPUBs
* Tue Mar 31 2009 toms@suse.de
  Update to version 0.5.3 (25 Mar, 2009):
  * Fix #2115 (Some Kindle Metadata Still Wrong)
  * Disable on-device editing of metadata in the GUI for devices
  that don't support it (all the non SONY devices)
  * MOBI Output: Fix Time recipe --> MOBI
  * Fix #2128 (Google Books Fetch Metadata Fails With Apostrophe In
  Title)
  * Calibre now depends on dnspython for email delivery. Also remove
  python 2.5 builds as it is no longer officially supported,
  though calibre will probably continue to run on it for a little
  while longer.
  * Fix #2152 (Typo in GUI)
  * Fix EPUB output of Spiegel Online
  * Fix error message in OSX when dragging and dropping a cover onto
  the edit metadata dialog
  * Fix #2137 (New recipes for Bosnian newspapers)
  * Fix #2121 (Remove before Add when editing tags in bulk)
  * Updated FAZ.NET recipe to produce EPUB that does not crash the
  SONY readers.
  * PDF Input: Replace non-breaking spaces with normal spaces. Fixes
  [#2104] (epub justification problems with converted pdf)
  * Support for email ebooks from calibre to your device. To use
  setup Email delivery in the preferences and then click the arrow
  next to the Send to Device button. Still experimental, so report
  bugs.
  * Implement #2151 (New recipe for new portal "24 sata")
  * Fix #2130 (Calibre Stops Reading MOBI Files)
  * Improved user feedback when downloading covers
  * Fix #2129 (.prc to MOBI causes TOC links to break)
* Wed Mar 25 2009 toms@suse.de
  Update to version 0.5.2 (19 Mar, 2009):
  * Fix #2100 (Zipped HTML to Epub conversion error)
  * New recipe for Adventure Gamers? by Darko Miletic
  * Disable the no subscription version of the NYTimes, since it no
  longer works
  * Don't add empty Table of Contents to MOBI files
  * New recipe for politico.com by Darko Miletic
  * Updated recipe for Sueddeutsche
  * Implement support for reading metadata from Amazon Topaz books
  * Fix #2066 (Attribute Error?: 'Book Header?' object has no
  attribute 'first_image_index')
  * Advertise the calibre Stanza server on Bonjour. Now accessing
  your calibre EPUB collection in Stanza should be automatic on
  your home network.
  * Fix #2058 (Calibre reads Kindle metadata wrong)
  * Re-arrange buttons to put the most frequently used ones first
  * Fix #2084 (Updated New Scientist recipe)
  * Fix #2076 (Error during Recursive Search)
  * Calibre now searches the Google Books database ina ddition to
  isbndb.com for book metadata
  * Fix #2098 (PRS-505 stating "Page Error!" when trying to open an
  ePub file)
  * New recipe for Instapaper by Darko Miletic
  * Fix #2074 (Clicking "table of contents" on a "lit")
  * Add vim like shortcuts to ebook-viewer for scrolling. Fixes
  [#2083] (Add Keyboard shorcuts to Viewer)
  * Fix #2101 (Croatian News recipe pack)
  * New recipe for Monde Durable by Darko Miletic
  * EPUB Output: Replace <center> tags with <div> tags since
  <center> is not valid XHTML
  * MOBI Output: Fix FAZ.NET feed conversion to MOBI
* Sun Mar 15 2009 toms@suse.de
  Update to version 0.5.1 (13 Mar, 2009):
  * Fix #2031 (Ebook viewer)
  * Advertise the calibre content server for Stanza via Bon Jour?,
  needs testing
  * New recipe for The Daily Mail UK by RufusA. Fix #998 (HTML2LRF
  and empty headings)
  * Fix regression with loading custom recipes that use future imports
  * Fix #2025 (Many LIT file covers detected sideways)
  * Add a no subscription needed version of the recipe for The Hew
  York Review of Books
  * Fix #2041 (Error fetching news la repubblica on MacOSX)
  * Fix #2038 (calibre built for Foresight Linux)
  * Fix #2034 (LRFMetaFile conflict on "objects")
  * Create RSS feed for calibre release. Also new recipe for The
  Register by vgrama
  * MOBI Input: Strip <street> and <address> tags as ADE refuses to
  hadle them gracefully when converted to EPUB
  * EPUB Output: Strip <form> tags since ADE runs screaming when it
  sees one.
  * Fixes #2029 (IHT resetting P505)
  * Implement #2036 (Add PDB support to the Stanza content server)
  * Fix #2051 (Can't input date before 14 September 1752)
* Sat Mar  7 2009 toms@suse.de
  Update to version 0.4.143 (06 Mar, 2009):
  * Fix #1998 ([ERROR] CSSStyleRule: No start { of style declaration
  found:)
  * MOBI Input:Fix extraction of Table of Contents for MOBI files
  that have their TOC at the start of the book instead of the end
  * RTF Input:Fix conversion of Euro symbol in CP-1252 encoded RTF
  files
  * Implement sub-sorting. So if you want to sort by author and then
  sub sort by series, you can now click first on series and then
  on author to acheive this. Implement #1810 (Advanced Sorting?)
  * Fix calibre.app to work correctly even when it is moved into a
  path that has spaces in it
  * Fix #1977 (Error on converting zip with html to ePUB u'invalid
  literal for float(): +2)
  * New recipe for El Universal by Darko Miletic
  * MOBI Input: Handle poor quality PRC files from Baen
  better. Images are now correctly extracted despite the missing
  image_offset and metadata embedded in the content is used when
  converting (though not when simply reading metadata as this
  would be too slow)
  * Fix #1981 (Problems whit unicone titles)
  * Fix #1983 (Schedule news download - user and password fields)
  * Fix #1995 (Type Error?: Argument must be string or unicode.)
* Wed Mar  4 2009 toms@suse.de
  Updated to version 0.4.142 (03 Mar, 2009):
  * Linux install:calibre_postinstall now installs desktop
  integration even for non-root user
  * Fix #1949 (Calibre hangs with 'Type Error?')
  * Fix #1938 (Error in lrs2lrf)
  * Fix #1933 (Text is not centered when converting from MOBI to
  LIT)
  * New recipe for Newstimes by Darko Miletic
  * MOBI Input:Improve detection of Table of Contents. Fixes #1936
  (Since Calibre 0.4.134 medatada in reader doesn't works)
  * Fix calibre holding file handles on the Cybook, preventing
  it from being ejected
  * New recipe for Soldiers by Darko Miletic
  * New recipe for The Onion, by Darko Miletic
  * MOBI Input:Fix #1921 (Mobi to Epub conversion)
  * Fix regression in config dialog when setting the save single
  format option
  * Fix #1960 (html2epub limits in number of files allowed)
  * Fix #1962 (calibre set_metadata not writing book field into
  database)
  * Implement support for LIT atoms
  * Fix #1940 (Setting cover image for mobi file via GUI broken)
* Thu Feb 26 2009 toms@suse.de
- SPEC: Changed RPM group to Productivity/Other to match with
- FBReader
- Updated to 0.4.141:
  * Refuse to set metadata in DRMed MOBI files as this can lead to
    files that dont work on the device
  * Implement #1929 (OSX: Meta Information? shall be accesible by
    hitting Command(Apple)+I)
  * Fix #1934 (Would like to assign a year (not a full date) to
    a title)
  * Fix #1886 (Value Error?: invalid literal for float(): size)
    and #1887
  * New recipe for La Mujer De mi Vida by Darko Miletic
  * Move MOBI output out of beta status, since it's pretty stable
  * Make PDF conversion on OSX more robust. Fixes #1927
    (PDF->MOBI traceback)
  * Fix #1926 (Author column sorts by original name instead of
    latest database entry)
  * Initial support for the Kindle 2
  * New recipe for Courrier International and updated Le Monde
    by Mathieu Godlewski
- Changes from Version 0.4.140 (23 Feb, 2009):
  * Updated recipe for New York Review of Books to use
    subscription based content
  * New recipes for E-Novine and Al Jazeera by Darko Miletic
  * Cybook Gen3:Fix thumbnail generation.
  * New recipe for Borba by Darko Miletic
  * Fix #1804 (calibredb list - with umlauts in title) and
    return valid metadata for PRC files that have no EXTH record
  * New recipe for Windows Super Site? by Hypernova
  * Fix handling of commas in author name when sending books
    to device. Fixes #1914 (author name scrambled?)
  * Fix bug causing add books to report spurious duplicates on
    OS X
  * Add support for sending Topaz books to the Kindle
* Tue Feb 24 2009 toms@suse.de
- Added python-setuptools into the list of required packages.
  Many thanks to Mike Fabian!
* Sun Feb 22 2009 toms@suse.de
- Added .desktop file with PNG graphics
- Fixed SPEC file, corrected indendation
- Fixed description
* Sat Feb 21 2009 toms@suse.de
- Updated to version 0.4.139 (20 Feb, 2009)
- Corrected SPEC and patch file
* Sat Feb  7 2009 toms@suse.de
- Initial package 0.4.134 (07 Feb, 2009)
